@@ -1,6 +1,6 @@
 #
 # Author:: Christopher Maier (<maier@lambda.local>)
-# Copyright:: Copyright (c) 2011 Opscode, Inc.
+# Copyright:: Copyright 2011-2016, Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,19 +16,19 @@
 # limitations under the License.
 #
 
-require 'chef'
-require 'chef/monologger'
-require 'chef/application'
-require 'chef/client'
-require 'chef/config'
-require 'chef/handler/error_report'
-require 'chef/log'
-require 'chef/rest'
-require 'mixlib/cli'
-require 'socket'
-require 'uri'
-require 'win32/daemon'
-require 'chef/mixin/shell_out'
+require "chef"
+require "chef/monologger"
+require "chef/application"
+require "chef/client"
+require "chef/config"
+require "chef/handler/error_report"
+require "chef/log"
+require "chef/http"
+require "mixlib/cli"
+require "socket"
+require "uri"
+require "win32/daemon"
+require "chef/mixin/shell_out"
 
 class Chef
   class Application
@@ -45,8 +45,7 @@ class Chef
       option :log_location,
         :short        => "-L LOGLOCATION",
         :long         => "--logfile LOGLOCATION",
-        :description  => "Set the log file location",
-        :default => "#{ENV['SYSTEMDRIVE']}/chef/client.log"
+        :description  => "Set the log file location"
 
       option :splay,
         :short        => "-s SECONDS",
@@ -60,6 +59,8 @@ class Chef
         :description  => "Set the number of seconds to wait between chef-client runs",
         :proc         => lambda { |s| s.to_i }
 
+      DEFAULT_LOG_LOCATION ||= "#{ENV['SYSTEMDRIVE']}/chef/client.log"
+
       def service_init
         @service_action_mutex = Mutex.new
         @service_signal = ConditionVariable.new
@@ -73,7 +74,7 @@ class Chef
         # Set the initial timeout to splay sleep time
         timeout = rand Chef::Config[:splay]
 
-        while running? do
+        while running?
           # Grab the service_action_mutex to make a chef-client run
           @service_action_mutex.synchronize do
             begin
@@ -186,16 +187,25 @@ class Chef
           Chef::Log.info "Starting chef-client in a new process"
           # Pass config params to the new process
           config_params = " --no-fork"
-          config_params += " -c #{Chef::Config[:config_file]}" unless  Chef::Config[:config_file].nil?
-          config_params += " -L #{Chef::Config[:log_location]}" unless Chef::Config[:log_location] == STDOUT
+          config_params += " -c #{Chef::Config[:config_file]}" unless Chef::Config[:config_file].nil?
+          # log_location might be an event logger and if so we cannot pass as a command argument
+          # but shed no tears! If the logger is an event logger, it must have been configured
+          # as such in the config file and chef-client will use that when no arg is passed here
+          config_params += " -L #{resolve_log_location}" if resolve_log_location.is_a?(String)
+
           # Starts a new process and waits till the process exits
-          result = shell_out("chef-client #{config_params}", :timeout => Chef::Config[:windows_service][:watchdog_timeout])
+
+          result = shell_out(
+            "chef-client.bat #{config_params}",
+            :timeout => Chef::Config[:windows_service][:watchdog_timeout],
+            :logger => Chef::Log
+          )
           Chef::Log.debug "#{result.stdout}"
           Chef::Log.debug "#{result.stderr}"
         rescue Mixlib::ShellOut::CommandTimeout => e
           Chef::Log.error "chef-client timed out\n(#{e})"
-          Chef::Log.error(<<-EOF) 
-            Your chef-client run timed out. You can increase the time chef-client is given 
+          Chef::Log.error(<<-EOF)
+            Your chef-client run timed out. You can increase the time chef-client is given
             to complete by configuring windows_service.watchdog_timeout in your client.rb.
           EOF
         rescue Mixlib::ShellOut::ShellCommandFailed => e
@@ -215,12 +225,12 @@ class Chef
 
       # Lifted from Chef::Application, with addition of optional startup parameters
       # for playing nicely with Windows Services
-      def reconfigure(startup_parameters=[])
+      def reconfigure(startup_parameters = [])
         configure_chef startup_parameters
         configure_logging
 
         Chef::Config[:chef_server_url] = config[:chef_server_url] if config.has_key? :chef_server_url
-        unless Chef::Config[:exception_handlers].any? {|h| Chef::Handler::ErrorReport === h}
+        unless Chef::Config[:exception_handlers].any? { |h| Chef::Handler::ErrorReport === h }
           Chef::Config[:exception_handlers] << Chef::Handler::ErrorReport.new
         end
 
@@ -231,7 +241,7 @@ class Chef
       # See application.rb for related comments.
 
       def configure_logging
-        Chef::Log.init(MonoLogger.new(Chef::Config[:log_location]))
+        Chef::Log.init(MonoLogger.new(resolve_log_location))
         if want_additional_logger?
           configure_stdout_logger
         end
@@ -241,7 +251,7 @@ class Chef
       def configure_stdout_logger
         stdout_logger = MonoLogger.new(STDOUT)
         stdout_logger.formatter = Chef::Log.logger.formatter
-        Chef::Log.loggers <<  stdout_logger
+        Chef::Log.loggers << stdout_logger
       end
 
       # Based on config and whether or not STDOUT is a tty, should we setup a
@@ -260,6 +270,11 @@ class Chef
         Chef::Config[:log_level] == :auto
       end
 
+      def resolve_log_location
+        # STDOUT is the default log location, but makes no sense for a windows service
+        Chef::Config[:log_location] == STDOUT ? DEFAULT_LOG_LOCATION : Chef::Config[:log_location]
+      end
+
       # if log_level is `:auto`, convert it to :warn (when using output formatter)
       # or :info (no output formatter). See also +using_output_formatter?+
       def resolve_log_level
@@ -293,22 +308,22 @@ class Chef
         begin
           case config[:config_file]
           when /^(http|https):\/\//
-            Chef::REST.new("", nil, nil).fetch(config[:config_file]) { |f| apply_config(f.path) }
+            Chef::HTTP.new("").streaming_request(config[:config_file]) { |f| apply_config(f.path) }
           else
-            ::File::open(config[:config_file]) { |f| apply_config(f.path) }
+            ::File.open(config[:config_file]) { |f| apply_config(f.path) }
           end
-        rescue Errno::ENOENT => error
+        rescue Errno::ENOENT
           Chef::Log.warn("*****************************************")
           Chef::Log.warn("Did not find config file: #{config[:config_file]}, using command line options.")
           Chef::Log.warn("*****************************************")
 
           Chef::Config.merge!(config)
-        rescue SocketError => error
-          Chef::Application.fatal!("Error getting config file #{Chef::Config[:config_file]}", 2)
+        rescue SocketError
+          Chef::Application.fatal!("Error getting config file #{Chef::Config[:config_file]}", Chef::Exceptions::DeprecatedExitCode.new)
         rescue Chef::Exceptions::ConfigurationError => error
-          Chef::Application.fatal!("Error processing config file #{Chef::Config[:config_file]} with error #{error.message}", 2)
+          Chef::Application.fatal!("Error processing config file #{Chef::Config[:config_file]} with error #{error.message}", Chef::Exceptions::DeprecatedExitCode.new)
         rescue Exception => error
-          Chef::Application.fatal!("Unknown error processing config file #{Chef::Config[:config_file]} with error #{error.message}", 2)
+          Chef::Application.fatal!("Unknown error processing config file #{Chef::Config[:config_file]} with error #{error.message}", Chef::Exceptions::DeprecatedExitCode.new)
         end
       end
 
@@ -319,5 +334,5 @@ end
 # To run this file as a service, it must be called as a script from within
 # the Windows Service framework.  In that case, kick off the main loop!
 if __FILE__ == $0
-    Chef::Application::WindowsService.mainloop
+  Chef::Application::WindowsService.mainloop
 end
