@@ -1,6 +1,6 @@
 #
-# Author:: John Keiser (<jkeiser@opscode.com>)
-# Copyright:: Copyright (c) 2012 Opscode, Inc.
+# Author:: John Keiser (<jkeiser@chef.io>)
+# Copyright:: Copyright 2012-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,8 +16,8 @@
 # limitations under the License.
 #
 
-require 'chef/log'
-require 'chef/chef_fs/path_utils'
+require "chef/log"
+require "chef/chef_fs/path_utils"
 
 class Chef
   module ChefFS
@@ -31,8 +31,10 @@ class Chef
       # out here:
       INFLECTIONS = {
         "acls" => "acl",
+        "client_keys" => "client_key",
         "clients" => "client",
         "cookbooks" => "cookbook",
+        "cookbook_artifacts" => "cookbook_artifact",
         "containers" => "container",
         "data_bags" => "data_bag",
         "environments" => "environment",
@@ -40,11 +42,39 @@ class Chef
         "nodes" => "node",
         "roles" => "role",
         "users" => "user",
-        "policies" => "policy"
+        "policies" => "policy",
+        "policy_groups" => "policy_group",
       }
-      INFLECTIONS.each { |k,v| k.freeze; v.freeze }
+      INFLECTIONS.each { |k, v| k.freeze; v.freeze }
       INFLECTIONS.freeze
 
+      # ChefFS supports three modes of operation: "static", "everything", and
+      # "hosted_everything". These names are antiquated since Chef 12 moved
+      # multi-tenant and RBAC to the open source product. In practice, they
+      # mean:
+      #
+      # * static: just static objects that are included in a traditional
+      #   chef-repo, with no support for anything introduced in Chef 12 or
+      #   later.
+      # * everything: all of the objects supported by the open source Chef
+      #   Server 11.x
+      # * hosted_everything: (the name comes from Hosted Chef) supports
+      #   everything in Chef Server 12 and later, including RBAC objects and
+      #   Policyfile objects.
+      #
+      # The "static" and "everything" modes are used for backup and
+      # upgrade/migration of older Chef Servers, so they should be considered
+      # frozen in time.
+
+      CHEF_11_OSS_STATIC_OBJECTS = %w{cookbooks cookbook_artifacts data_bags environments roles}.freeze
+      CHEF_11_OSS_DYNAMIC_OBJECTS = %w{clients nodes users}.freeze
+      RBAC_OBJECT_NAMES = %w{acls containers groups }.freeze
+      CHEF_12_OBJECTS = %w{ cookbook_artifacts policies policy_groups client_keys }.freeze
+
+      STATIC_MODE_OBJECT_NAMES = CHEF_11_OSS_STATIC_OBJECTS
+      EVERYTHING_MODE_OBJECT_NAMES = (CHEF_11_OSS_STATIC_OBJECTS + CHEF_11_OSS_DYNAMIC_OBJECTS).freeze
+      HOSTED_EVERYTHING_MODE_OBJECT_NAMES = (EVERYTHING_MODE_OBJECT_NAMES + RBAC_OBJECT_NAMES + CHEF_12_OBJECTS).freeze
+
       #
       # Create a new Config object which can produce a chef_fs and local_fs.
       #
@@ -111,10 +141,10 @@ class Chef
       #
       def initialize(chef_config = Chef::Config, cwd = Dir.pwd, options = {}, ui = nil)
         @chef_config = chef_config
-        @cwd = cwd
+        @cwd = File.expand_path(cwd)
         @cookbook_version = options[:cookbook_version]
 
-        if @chef_config[:repo_mode] == 'everything' && is_hosted? && !ui.nil?
+        if @chef_config[:repo_mode] == "everything" && is_hosted? && !ui.nil?
           ui.warn %Q{You have repo_mode set to 'everything', but your chef_server_url
               looks like it might be a hosted setup.  If this is the case please use
               hosted_everything or allow repo_mode to default}
@@ -122,9 +152,9 @@ class Chef
         # Default to getting *everything* from the server.
         if !@chef_config[:repo_mode]
           if is_hosted?
-            @chef_config[:repo_mode] = 'hosted_everything'
+            @chef_config[:repo_mode] = "hosted_everything"
           else
-            @chef_config[:repo_mode] = 'everything'
+            @chef_config[:repo_mode] = "everything"
           end
         end
       end
@@ -142,8 +172,8 @@ class Chef
       end
 
       def create_chef_fs
-        require 'chef/chef_fs/file_system/chef_server_root_dir'
-        Chef::ChefFS::FileSystem::ChefServerRootDir.new("remote", @chef_config, :cookbook_version => @cookbook_version)
+        require "chef/chef_fs/file_system/chef_server/chef_server_root_dir"
+        Chef::ChefFS::FileSystem::ChefServer::ChefServerRootDir.new("remote", @chef_config, :cookbook_version => @cookbook_version)
       end
 
       def local_fs
@@ -151,8 +181,8 @@ class Chef
       end
 
       def create_local_fs
-        require 'chef/chef_fs/file_system/chef_repository_file_system_root_dir'
-        Chef::ChefFS::FileSystem::ChefRepositoryFileSystemRootDir.new(object_paths, Array(chef_config[:chef_repo_path]).flatten, @chef_config)
+        require "chef/chef_fs/file_system/repository/chef_repository_file_system_root_dir"
+        Chef::ChefFS::FileSystem::Repository::ChefRepositoryFileSystemRootDir.new(object_paths, Array(chef_config[:chef_repo_path]).flatten, @chef_config)
       end
 
       # Returns the given real path's location relative to the server root.
@@ -166,61 +196,59 @@ class Chef
       # server_path('/home/jkeiser/chef_repo/cookbooks/blah') == '/cookbooks/blah'
       # server_path('/home/*/chef_repo/cookbooks/blah') == nil
       #
-      # If there are multiple paths (cookbooks, roles, data bags, etc. can all
-      # have separate paths), and cwd+the path reaches into one of them, we will
-      # return a path relative to that.  Otherwise we will return a path to
-      # chef_repo.
+      # If there are multiple different, manually specified paths to object locations
+      # (cookbooks, roles, data bags, etc. can all have separate paths), and cwd+the
+      # path reaches into one of them, we will return a path relative to the first
+      # one to match it.  Otherwise we expect the path provided to be to the chef
+      # repo path itself.  Paths that are not available on the server are not supported.
       #
       # Globs are allowed as well, but globs outside server paths are NOT
       # (presently) supported.  See above examples.  TODO support that.
       #
       # If the path does not reach into ANY specified directory, nil is returned.
       def server_path(file_path)
-        pwd = File.expand_path(Dir.pwd)
-        absolute_pwd = Chef::ChefFS::PathUtils.realest_path(File.expand_path(file_path, pwd))
+        target_path = Chef::ChefFS::PathUtils.realest_path(file_path, @cwd)
 
         # Check all object paths (cookbooks_dir, data_bags_dir, etc.)
+        # These are either manually specified by the user or autogenerated relative
+        # to chef_repo_path.
         object_paths.each_pair do |name, paths|
           paths.each do |path|
-            realest_path = Chef::ChefFS::PathUtils.realest_path(path)
-            if PathUtils.descendant_of?(absolute_pwd, realest_path)
-              relative_path = Chef::ChefFS::PathUtils::relative_to(absolute_pwd, realest_path)
-              return relative_path == '.' ? "/#{name}" : "/#{name}/#{relative_path}"
+            object_abs_path = Chef::ChefFS::PathUtils.realest_path(path, @cwd)
+            if relative_path = PathUtils.descendant_path(target_path, object_abs_path)
+              return Chef::ChefFS::PathUtils.join("/#{name}", relative_path)
             end
           end
         end
 
         # Check chef_repo_path
         Array(@chef_config[:chef_repo_path]).flatten.each do |chef_repo_path|
-          realest_chef_repo_path = Chef::ChefFS::PathUtils.realest_path(chef_repo_path)
-          if absolute_pwd == realest_chef_repo_path
-            return '/'
+          # We're using realest_path here but we really don't need to - we can just expand the
+          # path and use realpath because a repo_path if provided *must* exist.
+          realest_chef_repo_path = Chef::ChefFS::PathUtils.realest_path(chef_repo_path, @cwd)
+          if Chef::ChefFS::PathUtils.os_path_eq?(target_path, realest_chef_repo_path)
+            return "/"
           end
         end
 
         nil
       end
 
-      # The current directory, relative to server root
+      # The current directory, relative to server root.  This is a case-sensitive server path.
+      # It only exists if the current directory is a child of one of the recognized object_paths below.
       def base_path
-        @base_path ||= begin
-          if @chef_config[:chef_repo_path]
-            server_path(File.expand_path(@cwd))
-          else
-            nil
-          end
-        end
+        @base_path ||= server_path(@cwd)
       end
 
       # Print the given server path, relative to the current directory
       def format_path(entry)
-        server_path = entry.path
-        if base_path && server_path[0,base_path.length] == base_path
+        server_path = entry.respond_to?(:display_path) ? entry.display_path : entry.path
+        if base_path && server_path[0, base_path.length] == base_path
           if server_path == base_path
             return "."
-          elsif server_path[base_path.length,1] == "/"
+          elsif server_path[base_path.length, 1] == "/"
             return server_path[base_path.length + 1, server_path.length - base_path.length - 1]
-          elsif base_path == "/" && server_path[0,1] == "/"
+          elsif base_path == "/" && server_path[0, 1] == "/"
             return server_path[1, server_path.length - 1]
           end
         end
@@ -233,16 +261,17 @@ class Chef
         @object_paths ||= begin
           result = {}
           case @chef_config[:repo_mode]
-          when 'static'
-            object_names = %w(cookbooks data_bags environments roles policies)
-          when 'hosted_everything'
-            object_names = %w(acls clients cookbooks containers data_bags environments groups nodes roles policies)
+          when "static"
+            object_names = STATIC_MODE_OBJECT_NAMES
+          when "hosted_everything"
+            object_names = HOSTED_EVERYTHING_MODE_OBJECT_NAMES
           else
-            object_names = %w(clients cookbooks data_bags environments nodes roles users policies)
+            object_names = EVERYTHING_MODE_OBJECT_NAMES
           end
           object_names.each do |object_name|
             # cookbooks -> cookbook_path
-            singular_name = INFLECTIONS[object_name] or raise "Unknown object name #{object_name}"
+            singular_name = INFLECTIONS[object_name]
+            raise "Unknown object name #{object_name}" unless singular_name
             variable_name = "#{singular_name}_path"
             paths = Array(@chef_config[variable_name]).flatten
             result[object_name] = paths.map { |path| File.expand_path(path) }
