@@ -24,15 +24,14 @@ class Chef
           object
         end
 
-        #
-        # Takes a name like blah.json and removes the .json from it.
-        #
-        def remove_dot_json(name)
-          if name.length < 5 || name[-5,5] != ".json"
-            raise "Invalid name #{path}: must end in .json"
+        def remove_file_extension(name, ext = ".*")
+          if %w{ .rb .json }.include?(File.extname(name))
+            File.basename(name, ext)
+          else
+            name
           end
-          name[0,name.length-5]
         end
+        alias_method :remove_dot_json, :remove_file_extension
 
         #
         # Return true if minimize() should preserve a key even if it is the same
@@ -94,7 +93,7 @@ class Chef
         # name to recipe[name].  Then calls uniq on the result.
         #
         def normalize_run_list(run_list)
-          run_list.map{|item|
+          run_list.map do |item|
             case item.to_s
             when /^recipe\[.*\]$/
               item # explicit recipe
@@ -103,21 +102,23 @@ class Chef
             else
               "recipe[#{item}]"
             end
-          }.uniq
+          end.uniq
         end
 
         #
         # Bring in an instance of this object from Ruby.  (Like roles/x.rb)
         #
-        def from_ruby(ruby)
-          chef_class.from_file(ruby).to_hash
+        def from_ruby(path)
+          r = chef_class.new
+          r.from_file(path)
+          r.to_hash
         end
 
         #
         # Turn a JSON hash into a bona fide Chef object (like Chef::Node).
         #
         def chef_object(object)
-          chef_class.json_create(object)
+          chef_class.from_hash(object)
         end
 
         #
@@ -147,18 +148,18 @@ class Chef
         #   environment "desert"'
         #
         def to_ruby_keys(object, keys)
-          result = ''
+          result = ""
           keys.each do |key|
             if object[key]
               if object[key].is_a?(Hash)
                 if object[key].size > 0
                   result << key
                   first = true
-                  object[key].each_pair do |k,v|
+                  object[key].each_pair do |k, v|
                     if first
                       first = false
                     else
-                      result << ' '*key.length
+                      result << " " * key.length
                     end
                     result << " #{k.inspect} => #{v.inspect}\n"
                   end
@@ -185,14 +186,16 @@ class Chef
           result
         end
 
-        #
         # Verify that the JSON hash for this type has a key that matches its name.
-        # Calls the on_error block with the error, if there is one.
         #
-        def verify_integrity(object, entry, &on_error)
-          base_name = remove_dot_json(entry.name)
-          if object['name'] != base_name
-            on_error.call("Name must be '#{base_name}' (is '#{object['name']}')")
+        # @param object [Object] JSON hash of the object
+        # @param entry [Chef::ChefFS::FileSystem::BaseFSObject] filesystem object we are verifying
+        # @yield  [s] callback to handle errors
+        # @yieldparam [s<string>] error message
+        def verify_integrity(object, entry)
+          base_name = remove_file_extension(entry.name)
+          if object["name"] != base_name
+            yield("Name must be '#{base_name}' (is '#{object['name']}')")
           end
         end
 
