@@ -1,5 +1,5 @@
-require 'chef/chef_fs/file_system/base_fs_object'
-require 'chef/chef_fs/file_system/nonexistent_fs_object'
+require "chef/chef_fs/file_system/base_fs_object"
+require "chef/chef_fs/file_system/nonexistent_fs_object"
 
 class Chef
   module ChefFS
@@ -24,7 +24,7 @@ class Chef
             multiplexed_dirs.each do |dir|
               dir.children.each do |child|
                 if seen[child.name]
-                  Chef::Log.warn("Child with name '#{child.name}' found in multiple directories: #{seen[child.name].path_for_printing} and #{child.path_for_printing}")
+                  Chef::Log.warn("Child with name '#{child.name}' found in multiple directories: #{seen[child.name].path_for_printing} and #{child.path_for_printing}") unless seen[child.name].path_for_printing == child.path_for_printing
                 else
                   result << child
                   seen[child.name] = child
@@ -35,6 +35,21 @@ class Chef
           end
         end
 
+        def make_child_entry(name)
+          result = nil
+          multiplexed_dirs.each do |dir|
+            child_entry = dir.child(name)
+            if child_entry.exists?
+              if result
+                Chef::Log.debug("Child with name '#{child_entry.name}' found in multiple directories: #{result.parent.path_for_printing} and #{child_entry.parent.path_for_printing}")
+              else
+                result = child_entry
+              end
+            end
+          end
+          result
+        end
+
         def can_have_child?(name, is_dir)
           write_dir.can_have_child?(name, is_dir)
         end
