@@ -1,7 +1,7 @@
-require 'chef/application'
-require 'chef/chef_fs/path_utils'
-require 'chef/http/simple'
-require 'chef/json_compat'
+require "chef/application"
+require "chef/chef_fs/path_utils"
+require "chef/http/simple"
+require "chef/json_compat"
 
 class Chef
   class ConfigFetcher
@@ -12,12 +12,20 @@ class Chef
       @config_location = config_location
     end
 
+    def expanded_path
+      if config_location.nil? || remote_config?
+        config_location
+      else
+        File.expand_path(config_location)
+      end
+    end
+
     def fetch_json
       config_data = read_config
       begin
         Chef::JSONCompat.from_json(config_data)
       rescue Chef::Exceptions::JSON::ParseError => error
-        Chef::Application.fatal!("Could not parse the provided JSON file (#{config_location}): " + error.message, 2)
+        Chef::Application.fatal!("Could not parse the provided JSON file (#{config_location}): " + error.message, Chef::Exceptions::DeprecatedExitCode.new)
       end
     end
 
@@ -32,15 +40,15 @@ class Chef
     def fetch_remote_config
       http.get("")
     rescue SocketError, SystemCallError, Net::HTTPServerException => error
-      Chef::Application.fatal!("Cannot fetch config '#{config_location}': '#{error.class}: #{error.message}", 2)
+      Chef::Application.fatal!("Cannot fetch config '#{config_location}': '#{error.class}: #{error.message}", Chef::Exceptions::DeprecatedExitCode.new)
     end
 
     def read_local_config
       ::File.read(config_location)
-    rescue Errno::ENOENT => error
-      Chef::Application.fatal!("Cannot load configuration from #{config_location}", 2)
-    rescue Errno::EACCES => error
-      Chef::Application.fatal!("Permissions are incorrect on #{config_location}. Please chmod a+r #{config_location}", 2)
+    rescue Errno::ENOENT
+      Chef::Application.fatal!("Cannot load configuration from #{config_location}", Chef::Exceptions::DeprecatedExitCode.new)
+    rescue Errno::EACCES
+      Chef::Application.fatal!("Permissions are incorrect on #{config_location}. Please chmod a+r #{config_location}", Chef::Exceptions::DeprecatedExitCode.new)
     end
 
     def config_missing?
