@@ -1,8 +1,8 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Author:: Nuo Yan (<nuo@opscode.com>)
-# Author:: Christopher Brown (<cb@opscode.com>)
-# Copyright:: Copyright (c) 2009 Opscode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Author:: Nuo Yan (<nuo@chef.io>)
+# Author:: Christopher Brown (<cb@chef.io>)
+# Copyright:: Copyright 2009-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -18,12 +18,13 @@
 # limitations under the License.
 #
 
-require 'chef/config'
-require 'chef/mixin/params_validate'
-require 'chef/mixin/from_file'
-require 'chef/data_bag_item'
-require 'chef/mash'
-require 'chef/json_compat'
+require "chef/config"
+require "chef/mixin/params_validate"
+require "chef/mixin/from_file"
+require "chef/data_bag_item"
+require "chef/mash"
+require "chef/json_compat"
+require "chef/server_api"
 
 class Chef
   class DataBag
@@ -43,11 +44,11 @@ class Chef
 
     # Create a new Chef::DataBag
     def initialize(chef_server_rest: nil)
-      @name = ''
+      @name = ""
       @chef_server_rest = chef_server_rest
     end
 
-    def name(arg=nil)
+    def name(arg = nil)
       set_or_return(
         :name,
         arg,
@@ -57,9 +58,9 @@ class Chef
 
     def to_hash
       result = {
-        'name'       => @name,
-        'json_class' => self.class.name,
-        'chef_type'  => 'data_bag',
+        "name"       => @name,
+        "json_class" => self.class.name,
+        "chef_type"  => "data_bag",
       }
       result
     end
@@ -70,22 +71,27 @@ class Chef
     end
 
     def chef_server_rest
-      @chef_server_rest ||= Chef::REST.new(Chef::Config[:chef_server_url])
+      @chef_server_rest ||= Chef::ServerAPI.new(Chef::Config[:chef_server_url])
     end
 
     def self.chef_server_rest
-      Chef::REST.new(Chef::Config[:chef_server_url])
+      Chef::ServerAPI.new(Chef::Config[:chef_server_url])
     end
 
     # Create a Chef::Role from JSON
     def self.json_create(o)
+      Chef.log_deprecation("Auto inflation of JSON data is deprecated. Please use Chef::DataBag#from_hash")
+      from_hash(o)
+    end
+
+    def self.from_hash(o)
       bag = new
       bag.name(o["name"])
       bag
     end
 
-    def self.list(inflate=false)
-      if Chef::Config[:solo]
+    def self.list(inflate = false)
+      if Chef::Config[:solo_legacy_mode]
         paths = Array(Chef::Config[:data_bag_path])
         names = []
         paths.each do |path|
@@ -93,9 +99,10 @@ class Chef
             raise Chef::Exceptions::InvalidDataBagPath, "Data bag path '#{path}' is invalid"
           end
 
-          names += Dir.glob(File.join(Chef::Util::PathHelper.escape_glob(path), "*")).map{|f|File.basename(f)}.sort
+          names += Dir.glob(File.join(
+            Chef::Util::PathHelper.escape_glob_dir(path), "*")).map { |f| File.basename(f) }.sort
         end
-        names.inject({}) {|h, n| h[n] = n; h}
+        names.inject({}) { |h, n| h[n] = n; h }
       else
         if inflate
           # Can't search for all data bags like other objects, fall back to N+1 :(
@@ -104,14 +111,14 @@ class Chef
             response
           end
         else
-          Chef::REST.new(Chef::Config[:chef_server_url]).get_rest("data")
+          Chef::ServerAPI.new(Chef::Config[:chef_server_url]).get("data")
         end
       end
     end
 
     # Load a Data Bag by name via either the RESTful API or local data_bag_path if run in solo mode
     def self.load(name)
-      if Chef::Config[:solo]
+      if Chef::Config[:solo_legacy_mode]
         paths = Array(Chef::Config[:data_bag_path])
         data_bag = {}
         paths.each do |path|
@@ -119,8 +126,8 @@ class Chef
             raise Chef::Exceptions::InvalidDataBagPath, "Data bag path '#{path}' is invalid"
           end
 
-          Dir.glob(File.join(Chef::Util::PathHelper.escape_glob(path, name.to_s), "*.json")).inject({}) do |bag, f|
-            item = Chef::JSONCompat.from_json(IO.read(f))
+          Dir.glob(File.join(Chef::Util::PathHelper.escape_glob_dir(path, name.to_s), "*.json")).inject({}) do |bag, f|
+            item = Chef::JSONCompat.parse(IO.read(f))
 
             # Check if we have multiple items with similar names (ids) and raise if their content differs
             if data_bag.has_key?(item["id"]) && data_bag[item["id"]] != item
@@ -132,19 +139,19 @@ class Chef
         end
         return data_bag
       else
-        Chef::REST.new(Chef::Config[:chef_server_url]).get_rest("data/#{name}")
+        Chef::ServerAPI.new(Chef::Config[:chef_server_url]).get("data/#{name}")
       end
     end
 
     def destroy
-      chef_server_rest.delete_rest("data/#{@name}")
+      chef_server_rest.delete("data/#{@name}")
     end
 
     # Save the Data Bag via RESTful API
     def save
       begin
         if Chef::Config[:why_run]
-          Chef::Log.warn("In whyrun mode, so NOT performing data bag save.")
+          Chef::Log.warn("In why-run mode, so NOT performing data bag save.")
         else
           create
         end
@@ -156,7 +163,7 @@ class Chef
 
     #create a data bag via RESTful API
     def create
-      chef_server_rest.post_rest("data", self)
+      chef_server_rest.post("data", self)
       self
     end
 
