@@ -1,6 +1,6 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Copyright:: Copyright (c) 2008 Opscode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Copyright:: Copyright 2008-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -45,12 +45,12 @@ class Chef
         #   :default => default_value
         def initialize(platform_hash)
           @values = {}
-          platform_hash.each { |platforms, value| set(platforms, value)}
+          platform_hash.each { |platforms, value| set(platforms, value) }
         end
 
         def value_for_node(node)
           platform, version = node[:platform].to_s, node[:platform_version].to_s
-          # Check if we match a version constraint via Chef::VersionConstraint and Chef::Version::Platform
+          # Check if we match a version constraint via Chef::VersionConstraint::Platform and Chef::Version::Platform
           matched_value = match_versions(node)
           if @values.key?(platform) && @values[platform].key?(version)
             @values[platform][version]
@@ -76,11 +76,11 @@ class Chef
             keys = @values[platform].keys
             keys.each do |k|
               begin
-                if Chef::VersionConstraint.new(k).include?(node_version)
+                if Chef::VersionConstraint::Platform.new(k).include?(node_version)
                   key_matches << k
                 end
               rescue Chef::Exceptions::InvalidVersionConstraint => e
-                Chef::Log.debug "Caught InvalidVersionConstraint. This means that a key in value_for_platform cannot be interpreted as a Chef::VersionConstraint."
+                Chef::Log.debug "Caught InvalidVersionConstraint. This means that a key in value_for_platform cannot be interpreted as a Chef::VersionConstraint::Platform."
                 Chef::Log.debug(e)
               end
             end
@@ -106,11 +106,11 @@ class Chef
         end
 
         def set(platforms, value)
-          if platforms.to_s == 'default'
+          if platforms.to_s == "default"
             @values["default"] = value
           else
             assert_valid_platform_values!(platforms, value)
-            Array(platforms).each { |platform| @values[platform.to_s] = normalize_keys(value)}
+            Array(platforms).each { |platform| @values[platform.to_s] = normalize_keys(value) }
             value
           end
         end
@@ -134,8 +134,6 @@ class Chef
         end
       end
 
-
-
       # Given a hash similar to the one we use for Platforms, select a value from the hash.  Supports
       # per platform defaults, along with a single base default. Arrays may be passed as hash keys and
       # will be expanded.
@@ -168,8 +166,6 @@ class Chef
         has_platform
       end
 
-
-
      # Implementation class for determining platform family dependent values
       class PlatformFamilyDependentValue
 
@@ -193,7 +189,7 @@ class Chef
         def initialize(platform_family_hash)
           @values = {}
           @values["default"] = nil
-          platform_family_hash.each { |platform_families, value| set(platform_families, value)}
+          platform_family_hash.each { |platform_families, value| set(platform_families, value) }
         end
 
         def value_for_node(node)
@@ -212,7 +208,7 @@ class Chef
         private
 
         def set(platform_family, value)
-          if platform_family.to_s == 'default'
+          if platform_family.to_s == "default"
             @values["default"] = value
           else
             Array(platform_family).each { |family| @values[family.to_s] = value }
@@ -221,7 +217,6 @@ class Chef
         end
       end
 
-
       # Given a hash mapping platform families to values, select a value from the hash. Supports a single
       # base default if platform family is not in the map. Arrays may be passed as hash keys and will be
       # expanded
@@ -250,11 +245,26 @@ class Chef
         end
       end
 
+      # Shamelessly stolen from https://github.com/sethvargo/chef-sugar/blob/master/lib/chef/sugar/docker.rb
+      # Given a node object, returns whether the node is a docker container.
+      #
+      # === Parameters
+      # node:: [Chef::Node] The node to check.
+      #
+      # === Returns
+      # true:: if the current node is a docker container
+      # false:: if the current node is not a docker container
+      def docker?(node = run_context.nil? ? nil : run_context.node)
+        # Using "File.exist?('/.dockerinit') || File.exist?('/.dockerenv')" makes Travis sad,
+        # and that makes us sad too.
+        node && node[:virtualization] && node[:virtualization][:systems] &&
+          node[:virtualization][:systems][:docker] && node[:virtualization][:systems][:docker] == "guest"
+      end
+
     end
   end
 end
 
 # **DEPRECATED**
 # This used to be part of chef/mixin/language. Load the file to activate the deprecation code.
-require 'chef/mixin/language'
-
+require "chef/mixin/language"
