@@ -1,6 +1,6 @@
 #
 # Author:: Jay Mundrawala (<jdm@chef.io>)
-# Copyright:: Copyright (c) 2015 Chef Software, Inc.
+# Copyright:: Copyright 2015-2016, Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,12 +16,12 @@
 # limitations under the License.
 #
 
-require 'chef/util/powershell/ps_credential'
+require "chef/util/powershell/ps_credential"
 
 class Chef
   module DSL
     module Powershell
-      def ps_credential(username='placeholder', password)
+      def ps_credential(username = "placeholder", password) # rubocop:disable Style/OptionalArguments
         Chef::Util::Powershell::PSCredential.new(username, password)
       end
     end
