@@ -1,7 +1,7 @@
 #
-# Author:: John Keiser (<jkeiser@opscode.com>)
-# Author:: Seth Chisamore (<schisamo@opscode.com>)
-# Copyright:: Copyright 2011 Opscode, Inc.
+# Author:: John Keiser (<jkeiser@chef.io>)
+# Author:: Seth Chisamore (<schisamo@chef.io>)
+# Copyright:: Copyright 2011-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,8 +17,8 @@
 # limitations under the License.
 #
 
-require 'chef/win32/security'
-require 'chef/win32/file'
+require "chef/win32/security"
+require "chef/win32/file"
 
 class Chef
   class FileAccessControl
@@ -128,7 +128,7 @@ class Chef
       end
 
       def should_update_dacl?
-        return true unless ::File.exists?(file)
+        return true unless ::File.exists?(file) || ::File.symlink?(file)
         dacl = target_dacl
         existing_dacl = existing_descriptor.dacl
         inherits = target_inherits
@@ -161,7 +161,7 @@ class Chef
       end
 
       def should_update_group?
-        return true unless ::File.exists?(file)
+        return true unless ::File.exists?(file) || ::File.symlink?(file)
         (group = target_group) && (group != existing_descriptor.group)
       end
 
@@ -180,7 +180,7 @@ class Chef
       end
 
       def should_update_owner?
-        return true unless ::File.exists?(file)
+        return true unless ::File.exists?(file) || ::File.symlink?(file)
         (owner = target_owner) && (owner != existing_descriptor.owner)
       end
 
@@ -319,7 +319,7 @@ class Chef
 
       def target_group
         return nil if resource.group.nil?
-        sid = get_sid(resource.group)
+        get_sid(resource.group)
       end
 
       def target_inherits
@@ -328,7 +328,7 @@ class Chef
 
       def target_owner
         return nil if resource.owner.nil?
-        sid = get_sid(resource.owner)
+        get_sid(resource.owner)
       end
     end
   end
