@@ -1,6 +1,6 @@
 #
-# Author:: Adam Edwards (<adamed@getchef.com>)
-# Copyright:: Copyright (c) 2014 Opscode, Inc.
+# Author:: Adam Edwards (<adamed@chef.io>)
+# Copyright:: Copyright 2014-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,13 +16,13 @@
 # limitations under the License.
 #
 
-require 'chef/guard_interpreter'
+require "chef/guard_interpreter"
 
 class Chef
   class GuardInterpreter
     class ResourceGuardInterpreter < DefaultGuardInterpreter
 
-      def initialize(parent_resource, command, opts, &block)
+      def initialize(parent_resource, command, opts)
         super(command, opts)
         @parent_resource = parent_resource
         @resource = get_interpreter_resource(parent_resource)
@@ -42,9 +42,9 @@ class Chef
         # We need to make sure we check for Script first because any resource
         # that can get to here is an Execute resource.
         if @resource.is_a? Chef::Resource::Script
-          block_attributes = @command_opts.merge({:code => @command})
+          block_attributes = @command_opts.merge({ :code => @command })
         else
-          block_attributes = @command_opts.merge({:command => @command})
+          block_attributes = @command_opts.merge({ :command => @command })
         end
 
         # Handles cases like powershell_script where default
@@ -62,13 +62,16 @@ class Chef
 
       protected
 
-      def evaluate_action(action=nil, &block)
+      def evaluate_action(action = nil, &block)
         @resource.instance_eval(&block)
 
         run_action = action || @resource.action
 
         begin
-          @resource.run_action(run_action)
+          # Coerce to an array to be safe. This could happen with a legacy
+          # resource or something overriding the default_action code in a
+          # subclass.
+          Array(run_action).each { |action_to_run| @resource.run_action(action_to_run) }
           resource_updated = @resource.updated
         rescue Mixlib::ShellOut::ShellCommandFailed
           resource_updated = nil
@@ -85,16 +88,19 @@ class Chef
         resource_class = Chef::Resource.resource_for_node(parent_resource.guard_interpreter, parent_resource.node)
 
         if resource_class.nil?
-          raise ArgumentError, "Specified guard_interpreter resource #{parent_resource.guard_interpreter.to_s} unknown for this platform"
+          raise ArgumentError, "Specified guard_interpreter resource #{parent_resource.guard_interpreter} unknown for this platform"
         end
 
         if ! resource_class.ancestors.include?(Chef::Resource::Execute)
           raise ArgumentError, "Specified guard interpreter class #{resource_class} must be a kind of Chef::Resource::Execute resource"
         end
 
+        # Duplicate the node below because the new RunContext
+        # overwrites the state of Node instances passed to it.
+        # See https://github.com/chef/chef/issues/3485.
         empty_events = Chef::EventDispatch::Dispatcher.new
-        anonymous_run_context = Chef::RunContext.new(parent_resource.node, {}, empty_events)
-        interpreter_resource = resource_class.new('Guard resource', anonymous_run_context)
+        anonymous_run_context = Chef::RunContext.new(parent_resource.node.dup, {}, empty_events)
+        interpreter_resource = resource_class.new("Guard resource", anonymous_run_context)
         interpreter_resource.is_guard_interpreter = true
 
         interpreter_resource
