@@ -1,6 +1,6 @@
 #--
-# Author:: Daniel DeLeo (<dan@opscode.com>)
-# Copyright:: Copyright (c) 2013 Opscode, Inc.
+# Author:: Daniel DeLeo (<dan@chef.io>)
+# Copyright:: Copyright 2013-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,7 +16,7 @@
 # limitations under the License.
 #
 
-require 'chef/http/cookie_jar'
+require "chef/http/cookie_jar"
 
 class Chef
   class HTTP
@@ -27,21 +27,21 @@ class Chef
     # it, so it's included with Chef::REST
     class CookieManager
 
-      def initialize(options={})
+      def initialize(options = {})
         @cookies = CookieJar.instance
       end
 
-      def handle_request(method, url, headers={}, data=false)
+      def handle_request(method, url, headers = {}, data = false)
         @host, @port = url.host, url.port
         if @cookies.has_key?("#{@host}:#{@port}")
-          headers['Cookie'] = @cookies["#{@host}:#{@port}"]
+          headers["Cookie"] = @cookies["#{@host}:#{@port}"]
         end
         [method, url, headers, data]
       end
 
       def handle_response(http_response, rest_request, return_value)
-        if http_response['set-cookie']
-          @cookies["#{@host}:#{@port}"] = http_response['set-cookie']
+        if http_response["set-cookie"]
+          @cookies["#{@host}:#{@port}"] = http_response["set-cookie"]
         end
         [http_response, rest_request, return_value]
       end
