@@ -1,6 +1,6 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Copyright:: Copyright (c) 2009 Opscode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Copyright:: Copyright 2009-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,16 +16,16 @@
 # limitations under the License.
 #
 
-require 'chef/knife'
+require "chef/knife"
 
 class Chef
   class Knife
     class CookbookShow < Knife
 
       deps do
-        require 'chef/json_compat'
-        require 'uri'
-        require 'chef/cookbook_version'
+        require "chef/json_compat"
+        require "uri"
+        require "chef/cookbook_version"
       end
 
       banner "knife cookbook show COOKBOOK [VERSION] [PART] [FILENAME] (options)"
@@ -51,6 +51,10 @@ class Chef
         :description => "Show corresponding URIs"
 
       def run
+        cookbook_name, cookbook_version, segment, filename = @name_args
+
+        cookbook = Chef::CookbookVersion.load(cookbook_name, cookbook_version) unless cookbook_version.nil?
+
         case @name_args.length
         when 4 # We are showing a specific file
           node = Hash.new
@@ -59,34 +63,26 @@ class Chef
           node[:platform_version] = config[:platform_version] if config.has_key?(:platform_version)
 
           class << node
-            def attribute?(name)
+            def attribute?(name) # rubocop:disable Lint/NestedMethodDefinition
               has_key?(name)
             end
           end
 
-          cookbook_name, segment, filename = @name_args[0], @name_args[2], @name_args[3]
-          cookbook_version = @name_args[1] == 'latest' ? '_latest' : @name_args[1]
-
-          cookbook = rest.get_rest("cookbooks/#{cookbook_name}/#{cookbook_version}")
           manifest_entry = cookbook.preferred_manifest_record(node, segment, filename)
-          temp_file = rest.get_rest(manifest_entry[:url], true)
+          temp_file = rest.streaming_request(manifest_entry[:url])
 
           # the temp file is cleaned up elsewhere
           temp_file.open if temp_file.closed?
           pretty_print(temp_file.read)
 
         when 3 # We are showing a specific part of the cookbook
-          cookbook_version = @name_args[1] == 'latest' ? '_latest' : @name_args[1]
-          result = rest.get_rest("cookbooks/#{@name_args[0]}/#{cookbook_version}")
-          output(result.manifest[@name_args[2]])
+          output(cookbook.manifest[segment])
         when 2 # We are showing the whole cookbook data
-          cookbook_version = @name_args[1] == 'latest' ? '_latest' : @name_args[1]
-          output(rest.get_rest("cookbooks/#{@name_args[0]}/#{cookbook_version}"))
+          output(cookbook)
         when 1 # We are showing the cookbook versions (all of them)
-          cookbook_name = @name_args[0]
           env           = config[:environment]
           api_endpoint  = env ? "environments/#{env}/cookbooks/#{cookbook_name}" : "cookbooks/#{cookbook_name}"
-          output(format_cookbook_list_for_display(rest.get_rest(api_endpoint)))
+          output(format_cookbook_list_for_display(rest.get(api_endpoint)))
         when 0
           show_usage
           ui.fatal("You must specify a cookbook name")
@@ -96,7 +92,3 @@ class Chef
     end
   end
 end
-
-
-
-
