@@ -1,8 +1,8 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Author:: Christopher Brown (<cb@opscode.com>)
-# Author:: Daniel DeLeo (<dan@opscode.com>)
-# Copyright:: Copyright (c) 2009, 2011 Opscode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Author:: Christopher Brown (<cb@chef.io>)
+# Author:: Daniel DeLeo (<dan@chef.io>)
+# Copyright:: Copyright 2009-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -18,10 +18,10 @@
 # limitations under the License.
 #
 
-require 'forwardable'
-require 'chef/platform/query_helpers'
-require 'chef/knife/core/generic_presenter'
-require 'tempfile'
+require "forwardable"
+require "chef/platform/query_helpers"
+require "chef/knife/core/generic_presenter"
+require "tempfile"
 
 class Chef
   class Knife
@@ -57,7 +57,7 @@ class Chef
 
       def highline
         @highline ||= begin
-          require 'highline'
+          require "highline"
           HighLine.new
         end
       end
@@ -137,10 +137,10 @@ class Chef
         @presenter.interchange?
       end
 
-      def ask_question(question, opts={})
+      def ask_question(question, opts = {})
         question = question + "[#{opts[:default]}] " if opts[:default]
 
-        if opts[:default] and config[:defaults]
+        if opts[:default] && config[:defaults]
           opts[:default]
         else
           stdout.print question
@@ -163,19 +163,18 @@ class Chef
         end
       end
 
-
       # Hash -> Hash
       # Works the same as edit_data but
-      # returns a hash rather than a JSON string/Fully infated object
+      # returns a hash rather than a JSON string/Fully inflated object
       def edit_hash(hash)
         raw = edit_data(hash, false)
         Chef::JSONCompat.parse(raw)
       end
 
-      def edit_data(data, parse_output=true)
+      def edit_data(data, parse_output = true, object_class: nil)
         output = Chef::JSONCompat.to_json_pretty(data)
-        if (!config[:disable_editing])
-          Tempfile.open([ 'knife-edit-', '.json' ]) do |tf|
+        if !config[:disable_editing]
+          Tempfile.open([ "knife-edit-", ".json" ]) do |tf|
             tf.sync = true
             tf.puts output
             tf.close
@@ -185,13 +184,22 @@ class Chef
           end
         end
 
-        parse_output ? Chef::JSONCompat.from_json(output) : output
+        if parse_output
+          if object_class.nil?
+            Chef.log_deprecation("Auto inflation of JSON data is deprecated. Please pass in the class to inflate or use #edit_hash")
+            Chef::JSONCompat.from_json(output)
+          else
+            object_class.from_hash(Chef::JSONCompat.parse(output))
+          end
+        else
+          output
+        end
       end
 
       def edit_object(klass, name)
         object = klass.load(name)
 
-        output = edit_data(object)
+        output = edit_data(object, object_class: klass)
 
         # Only make the save if the user changed the object.
         #
@@ -217,16 +225,16 @@ class Chef
       def confirmation_instructions(default_choice)
         case default_choice
         when true
-          '? (Y/n) '
+          "? (Y/n) "
         when false
-          '? (y/N) '
+          "? (y/N) "
         else
-          '? (Y/N) '
+          "? (Y/N) "
         end
       end
 
       # See confirm method for argument information
-      def confirm_without_exit(question, append_instructions=true, default_choice=nil)
+      def confirm_without_exit(question, append_instructions = true, default_choice = nil)
         return true if config[:yes]
 
         stdout.print question
@@ -264,7 +272,7 @@ class Chef
       # append_instructions => Should print '? (Y/N)' as instructions
       # default_choice => Set to true for 'Y', and false for 'N' as default answer
       #
-      def confirm(question, append_instructions=true, default_choice=nil)
+      def confirm(question, append_instructions = true, default_choice = nil)
         unless confirm_without_exit(question, append_instructions, default_choice)
           exit 3
         end
