@@ -1,4 +1,4 @@
-require 'chef/chef_fs/knife'
+require "chef/chef_fs/knife"
 
 class Chef
   class Knife
@@ -8,33 +8,33 @@ class Chef
       category "path-based"
 
       deps do
-        require 'chef/chef_fs/file_system'
-        require 'highline'
+        require "chef/chef_fs/file_system"
+        require "highline"
       end
 
       option :recursive,
-        :short => '-R',
+        :short => "-R",
         :boolean => true,
         :description => "List directories recursively"
       option :bare_directories,
-        :short => '-d',
+        :short => "-d",
         :boolean => true,
         :description => "When directories match the pattern, do not show the directories' children"
       option :local,
-        :long => '--local',
+        :long => "--local",
         :boolean => true,
         :description => "List local directory instead of remote"
       option :flat,
-        :short => '-f',
-        :long => '--flat',
+        :short => "-f",
+        :long => "--flat",
         :boolean => true,
         :description => "Show a list of filenames rather than the prettified ls-like output normally produced"
       option :one_column,
-        :short => '-1',
+        :short => "-1",
         :boolean => true,
         :description => "Show only one column of results"
       option :trailing_slashes,
-        :short => '-p',
+        :short => "-p",
         :boolean => true,
         :description => "Show trailing slashes after directories"
 
@@ -44,9 +44,9 @@ class Chef
         patterns = name_args.length == 0 ? [""] : name_args
 
         # Get the top-level matches
-        args = pattern_args_from(patterns)
         all_results = parallelize(pattern_args_from(patterns)) do |pattern|
           pattern_results = Chef::ChefFS::FileSystem.list(config[:local] ? local_fs : chef_fs, pattern).to_a
+
           if pattern_results.first && !pattern_results.first.exists? && pattern.exact_path
             ui.error "#{format_path(pattern_results.first)}: No such file or directory"
             self.exit_code = 1
@@ -94,7 +94,7 @@ class Chef
             printed_something = true
           end
           output "#{format_path(result)}:"
-          print_results(children.map { |result| maybe_add_slash(result.name, result.dir?) }.sort, "")
+          print_results(children.map { |result| maybe_add_slash(result.display_name, result.dir?) }.sort, "")
         end
 
         exit self.exit_code if self.exit_code
@@ -129,17 +129,17 @@ class Chef
         else
           columns = HighLine::SystemExtensions.terminal_size[0]
         end
-        current_line = ''
+        current_line = ""
         results.each do |result|
           if current_line.length > 0 && current_line.length + print_space > columns
             output current_line.rstrip
-            current_line = ''
+            current_line = ""
           end
           if current_line.length == 0
             current_line << indent
           end
           current_line << result
-          current_line << (' ' * (print_space - result.length))
+          current_line << (" " * (print_space - result.length))
         end
         output current_line.rstrip if current_line.length > 0
       end
