@@ -1,6 +1,6 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Copyright:: Copyright (c) 2008 Opscode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Copyright:: Copyright 2008-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -35,7 +35,7 @@ class Chef
 
         if file_path.kind_of?(String)
           file_path = File.expand_path(file_path).split(File::SEPARATOR)
-          file_path.shift if file_path[0] == ''
+          file_path.shift if file_path[0] == ""
           # Check if path starts with a separator or drive letter (Windows)
           unless file_path[0].match("^#{File::SEPARATOR}|^[a-zA-Z]:")
             file_path[0] = "#{File::SEPARATOR}#{file_path[0]}"
