@@ -1,8 +1,8 @@
 #
-# Author:: Mark Mzyk <mmzyk@opscode.com>
-# Author:: Seth Chisamore <schisamo@opscode.com>
-# Author:: Bryan McLellan <btm@opscode.com>
-# Copyright:: Copyright (c) 2011-2012 Opscode, Inc.
+# Author:: Mark Mzyk <mmzyk@chef.io>
+# Author:: Seth Chisamore <schisamo@chef.io>
+# Author:: Bryan McLellan <btm@chef.io>
+# Copyright:: Copyright 2011-2016, Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -24,14 +24,12 @@ class Chef
 
       def file_class
         @host_os_file ||= if Chef::Platform.windows?
-          require 'chef/win32/file'
-          Chef::ReservedNames::Win32::File
-        else
-          ::File
-        end
+                            require "chef/win32/file"
+                            Chef::ReservedNames::Win32::File
+                          else
+                            ::File
+                          end
       end
     end
   end
 end
-
-
