@@ -1,6 +1,6 @@
 #--
-# Author:: Daniel DeLeo (<dan@opscode.com>)
-# Copyright:: Copyright (c) 2010 Opscode, Inc.
+# Author:: Daniel DeLeo (<dan@chef.io>)
+# Copyright:: Copyright 2010-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,7 +15,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-require 'mixlib/shellout'
+require "mixlib/shellout"
 
 class Chef
   module Mixin
@@ -28,26 +28,15 @@ class Chef
 
       # we use 'en_US.UTF-8' by default because we parse localized strings in English as an API and
       # generally must support UTF-8 unicode.
-      def shell_out(*command_args)
-        args = command_args.dup
-        if args.last.is_a?(Hash)
-          options = args.pop.dup
-          env_key = options.has_key?(:env) ? :env : :environment
-          options[env_key] ||= {}
-          options[env_key] = options[env_key].dup
-          options[env_key]['LC_ALL'] ||= Chef::Config[:internal_locale] unless options[env_key].has_key?('LC_ALL')
-          options[env_key]['LANGUAGE'] ||= Chef::Config[:internal_locale] unless options[env_key].has_key?('LANGUAGE')
-          options[env_key]['LANG'] ||= Chef::Config[:internal_locale] unless options[env_key].has_key?('LANG')
-          args << options
-        else
-          args << { :environment => {
-            'LC_ALL' => Chef::Config[:internal_locale],
-            'LANGUAGE' => Chef::Config[:internal_locale],
-            'LANG' => Chef::Config[:internal_locale],
-          } }
-        end
-
-        shell_out_command(*args)
+      def shell_out(*args, **options)
+        options = options.dup
+        env_key = options.has_key?(:env) ? :env : :environment
+        options[env_key] = {
+          "LC_ALL" => Chef::Config[:internal_locale],
+          "LANGUAGE" => Chef::Config[:internal_locale],
+          "LANG" => Chef::Config[:internal_locale],
+        }.update(options[env_key] || {})
+        shell_out_command(*args, **options)
       end
 
       # call shell_out (using en_US.UTF-8) and raise errors
@@ -89,6 +78,36 @@ class Chef
         return my_command_args
       end
 
+      # Helper for sublcasses to convert an array of string args into a string.  It
+      # will compact nil or empty strings in the array and will join the array elements
+      # with spaces, without introducing any double spaces for nil/empty elements.
+      #
+      # @param args [String] variable number of string arguments
+      # @return [String] nicely concatenated string or empty string
+      def a_to_s(*args)
+        clean_array(*args).join(" ")
+      end
+
+      # Helper for sublcasses to reject nil and empty strings out of an array.  It allows
+      # using the array form of shell_out (which avoids the need to surround arguments with
+      # quote marks to deal with shells).
+      #
+      # Usage:
+      #   shell_out!(*clean_array("useradd", universal_options, useradd_options, new_resource.username))
+      #
+      # universal_options and useradd_options can be nil, empty array, empty string, strings or arrays
+      # and the result makes sense.
+      #
+      # keeping this separate from shell_out!() makes it a bit easier to write expectations against the
+      # shell_out args and be able to omit nils and such in the tests (and to test that the nils are
+      # being rejected correctly).
+      #
+      # @param args [String] variable number of string arguments
+      # @return [Array] array of strings with nil and null string rejection
+      def clean_array(*args)
+        args.flatten.reject { |i| i.nil? || i == "" }.map(&:to_s)
+      end
+
       private
 
       def shell_out_command(*command_args)
@@ -99,7 +118,7 @@ class Chef
       end
 
       def deprecate_option(old_option, new_option)
-        Chef::Log.logger.warn "DEPRECATION: Chef::Mixin::ShellOut option :#{old_option} is deprecated. Use :#{new_option}"
+        Chef.log_deprecation "DEPRECATION: Chef::Mixin::ShellOut option :#{old_option} is deprecated. Use :#{new_option}"
       end
 
       def io_for_live_stream
@@ -114,4 +133,4 @@ class Chef
 end
 
 # Break circular dep
-require 'chef/config'
+require "chef/config"
