@@ -1,6 +1,6 @@
 #--
-# Author:: Lamont Granquist <lamont@getchef.io>
-# Copyright:: Copyright (c) 2010 Opscode, Inc.
+# Author:: Lamont Granquist <lamont@chef.io>
+# Copyright:: Copyright 2010-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -21,14 +21,14 @@ class Chef
       def which(cmd, opts = {})
         extra_path =
           if opts[:extra_path].nil?
-            [ '/bin', '/usr/bin', '/sbin', '/usr/sbin' ]
+            [ "/bin", "/usr/bin", "/sbin", "/usr/sbin" ]
           else
             [ opts[:extra_path] ].flatten
           end
-        paths = ENV['PATH'].split(File::PATH_SEPARATOR) + extra_path
+        paths = ENV["PATH"].split(File::PATH_SEPARATOR) + extra_path
         paths.each do |path|
           filename = File.join(path, cmd)
-          return filename if File.executable?(filename)
+          return filename if File.executable?(Chef.path_to(filename))
         end
         false
       end
