@@ -1,7 +1,7 @@
 #--
-# Author:: Daniel DeLeo (<dan@opscode.com>)
-# Copyright:: Copyright (c) 2009 Opscode, Inc.
-# Copyright:: Copyright (c) 2005 Sam Ruby
+# Author:: Daniel DeLeo (<dan@chef.io>)
+# Copyright:: Copyright 2009-2016, Chef Software Inc.
+# Copyright:: Copyright 2005-2016, Sam Ruby
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -26,7 +26,7 @@
 #
 # Thanks, Sam!
 #
-# Copyright (c) 2005, Sam Ruby
+# Copyright 2005-2016, Sam Ruby
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -46,10 +46,10 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-require 'chef/log'
+require "chef/log"
 
 begin
-  require 'fast_xs'
+  require "fast_xs"
 rescue LoadError
   Chef::Log.info "The fast_xs gem is not installed, slower pure ruby XML escaping will be used."
 end
@@ -64,14 +64,14 @@ class Chef
         CP1252 = {
           128 => 8364, # euro sign
           130 => 8218, # single low-9 quotation mark
-          131 =>  402, # latin small letter f with hook
+          131 => 402, # latin small letter f with hook
           132 => 8222, # double low-9 quotation mark
           133 => 8230, # horizontal ellipsis
           134 => 8224, # dagger
           135 => 8225, # double dagger
-          136 =>  710, # modifier letter circumflex accent
+          136 => 710, # modifier letter circumflex accent
           137 => 8240, # per mille sign
-          138 =>  352, # latin capital letter s with caron
+          138 => 352, # latin capital letter s with caron
           139 => 8249, # single left-pointing angle quotation mark
           140 =>  338, # latin capital ligature oe
           142 =>  381, # latin capital letter z with caron
@@ -82,9 +82,9 @@ class Chef
           149 => 8226, # bullet
           150 => 8211, # en dash
           151 => 8212, # em dash
-          152 =>  732, # small tilde
+          152 => 732, # small tilde
           153 => 8482, # trade mark sign
-          154 =>  353, # latin small letter s with caron
+          154 => 353, # latin small letter s with caron
           155 => 8250, # single right-pointing angle quotation mark
           156 =>  339, # latin small ligature oe
           158 =>  382, # latin small letter z with caron
@@ -93,9 +93,9 @@ class Chef
 
         # http://www.w3.org/TR/REC-xml/#dt-chardata
         PREDEFINED = {
-          38 => '&amp;', # ampersand
-          60 => '&lt;',  # left angle bracket
-          62 => '&gt;'  # right angle bracket
+          38 => "&amp;", # ampersand
+          60 => "&lt;",  # left angle bracket
+          62 => "&gt;" # right angle bracket
         }
 
         # http://www.w3.org/TR/REC-xml/#charsets
@@ -104,9 +104,9 @@ class Chef
 
         def xml_escape(unescaped_str)
           begin
-            unescaped_str.unpack("U*").map {|char| xml_escape_char!(char)}.join
+            unescaped_str.unpack("U*").map { |char| xml_escape_char!(char) }.join
           rescue
-            unescaped_str.unpack("C*").map {|char| xml_escape_char!(char)}.join
+            unescaped_str.unpack("C*").map { |char| xml_escape_char!(char) }.join
           end
         end
 
@@ -114,8 +114,8 @@ class Chef
 
         def xml_escape_char!(char)
           char = CP1252[char] || char
-          char = 42 unless VALID.detect {|range| range.include? char}
-          char = PREDEFINED[char] || (char<128 ? char.chr : "&##{char};")
+          char = 42 unless VALID.detect { |range| range.include? char }
+          char = PREDEFINED[char] || (char < 128 ? char.chr : "&##{char};")
         end
       end
 
