@@ -1,6 +1,6 @@
 #
 # Author:: Bryan McLellan (btm@loftninjas.org)
-# Copyright:: Copyright (c) 2009 Bryan McLellan
+# Copyright:: Copyright 2009-2016, Bryan McLellan
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,9 +16,9 @@
 # limitations under the License.
 #
 
-require 'chef/log'
-require 'chef/mixin/command'
-require 'chef/provider'
+require "chef/log"
+require "chef/mixin/command"
+require "chef/provider"
 
 class Chef
   class Provider
@@ -67,7 +67,7 @@ class Chef
               if cron_found
                 @current_resource.time($2.to_sym)
                 @current_resource.command($3)
-                cron_found=false
+                cron_found = false
               end
             when CRON_PATTERN
               if cron_found
@@ -77,11 +77,11 @@ class Chef
                 @current_resource.month($4)
                 @current_resource.weekday($5)
                 @current_resource.command($6)
-                cron_found=false
+                cron_found = false
               end
               next
             else
-              cron_found=false # We've got a Chef comment with no following crontab line
+              cron_found = false # We've got a Chef comment with no following crontab line
               next
             end
           end
@@ -187,8 +187,7 @@ class Chef
             end
             crontab << line
           end
-          description = cron_found ? "remove #{@new_resource.name} from crontab" :
-            "save unmodified crontab"
+          description = cron_found ? "remove #{@new_resource.name} from crontab" : "save unmodified crontab"
           converge_by(description) do
             write_crontab crontab
             Chef::Log.info("#{@new_resource} deleted crontab entry")
@@ -199,7 +198,7 @@ class Chef
       private
 
       def set_environment_var(attr_name, attr_value)
-        if %w(MAILTO PATH SHELL HOME).include?(attr_name)
+        if %w{MAILTO PATH SHELL HOME}.include?(attr_name)
           @current_resource.send(attr_name.downcase.to_sym, attr_value)
         else
           @current_resource.environment(@current_resource.environment.merge(attr_name => attr_value))
@@ -237,7 +236,7 @@ class Chef
         newcron = ""
         newcron << "# Chef Name: #{new_resource.name}\n"
         [ :mailto, :path, :shell, :home ].each do |v|
-          newcron << "#{v.to_s.upcase}=#{@new_resource.send(v)}\n" if @new_resource.send(v)
+          newcron << "#{v.to_s.upcase}=\"#{@new_resource.send(v)}\"\n" if @new_resource.send(v)
         end
         @new_resource.environment.each do |name, value|
           newcron << "#{name}=#{value}\n"
