@@ -1,6 +1,6 @@
 #
 # Author:: Doug MacEachern (<dougm@vmware.com>)
-# Copyright:: Copyright (c) 2010 VMware, Inc.
+# Copyright:: Copyright 2010-2016, VMware, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,7 +16,7 @@
 # limitations under the License.
 #
 
-require 'chef/mixin/windows_env_helper'
+require "chef/mixin/windows_env_helper"
 
 class Chef
   class Provider
@@ -36,7 +36,7 @@ class Chef
           obj.variablevalue = @new_resource.value
           obj.put_
           value = @new_resource.value
-          value = expand_path(value) if @new_resource.key_name.upcase == 'PATH'
+          value = expand_path(value) if @new_resource.key_name.casecmp("PATH").zero?
           ENV[@new_resource.key_name] = value
           broadcast_env_change
         end
