@@ -1,6 +1,6 @@
 #
 # Author:: Daniel DeLeo (<dan@kallistec.com>)
-# Copyright:: Copyright (c) 2008 Opscode, Inc.
+# Copyright:: Copyright 2008-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,17 +16,20 @@
 # limitations under the License.
 #
 
-require 'chef/exceptions'
-require 'chef/log'
-require 'chef/provider'
-require 'fileutils'
+require "chef/exceptions"
+require "chef/log"
+require "chef/provider"
+require "fileutils"
 
 class Chef
   class Provider
     class Git < Chef::Provider
 
+      extend Forwardable
       provides :git
 
+      def_delegator :@new_resource, :destination, :cwd
+
       def whyrun_supported?
         true
       end
@@ -42,20 +45,20 @@ class Chef
       def define_resource_requirements
         # Parent directory of the target must exist.
         requirements.assert(:checkout, :sync) do |a|
-          dirname = ::File.dirname(@new_resource.destination)
+          dirname = ::File.dirname(cwd)
           a.assertion { ::File.directory?(dirname) }
           a.whyrun("Directory #{dirname} does not exist, this run will fail unless it has been previously created. Assuming it would have been created.")
           a.failure_message(Chef::Exceptions::MissingParentDirectory,
-            "Cannot clone #{@new_resource} to #{@new_resource.destination}, the enclosing directory #{dirname} does not exist")
+            "Cannot clone #{@new_resource} to #{cwd}, the enclosing directory #{dirname} does not exist")
         end
 
         requirements.assert(:all_actions) do |a|
           a.assertion { !(@new_resource.revision =~ /^origin\//) }
           a.failure_message Chef::Exceptions::InvalidRemoteGitReference,
              "Deploying remote branches is not supported. " +
-             "Specify the remote branch as a local branch for " +
-             "the git repository you're deploying from " +
-             "(ie: '#{@new_resource.revision.gsub('origin/', '')}' rather than '#{@new_resource.revision}')."
+            "Specify the remote branch as a local branch for " +
+            "the git repository you're deploying from " +
+            "(ie: '#{@new_resource.revision.gsub('origin/', '')}' rather than '#{@new_resource.revision}')."
         end
 
         requirements.assert(:all_actions) do |a|
@@ -79,14 +82,14 @@ class Chef
           enable_submodules
           add_remotes
         else
-          Chef::Log.debug "#{@new_resource} checkout destination #{@new_resource.destination} already exists or is a non-empty directory"
+          Chef::Log.debug "#{@new_resource} checkout destination #{cwd} already exists or is a non-empty directory"
         end
       end
 
       def action_export
         action_checkout
-        converge_by("complete the export by removing #{@new_resource.destination}.git after checkout") do
-          FileUtils.rm_rf(::File.join(@new_resource.destination,".git"))
+        converge_by("complete the export by removing #{cwd}.git after checkout") do
+          FileUtils.rm_rf(::File.join(cwd, ".git"))
         end
       end
 
@@ -105,28 +108,28 @@ class Chef
       end
 
       def git_minor_version
-        @git_minor_version ||= Gem::Version.new(shell_out!('git --version', run_options).stdout.split.last)
+        @git_minor_version ||= Gem::Version.new( git("--version").stdout.split.last )
       end
 
       def existing_git_clone?
-        ::File.exist?(::File.join(@new_resource.destination, ".git"))
+        ::File.exist?(::File.join(cwd, ".git"))
       end
 
       def target_dir_non_existent_or_empty?
-        !::File.exist?(@new_resource.destination) || Dir.entries(@new_resource.destination).sort == ['.','..']
+        !::File.exist?(cwd) || Dir.entries(cwd).sort == [".", ".."]
       end
 
       def find_current_revision
         Chef::Log.debug("#{@new_resource} finding current git revision")
         if ::File.exist?(::File.join(cwd, ".git"))
           # 128 is returned when we're not in a git repo. this is fine
-          result = shell_out!('git rev-parse HEAD', :cwd => cwd, :returns => [0,128]).stdout.strip
+          result = git("rev-parse", "HEAD", cwd: cwd, returns: [0, 128]).stdout.strip
         end
         sha_hash?(result) ? result : nil
       end
 
       def add_remotes
-        if (@new_resource.additional_remotes.length > 0)
+        if @new_resource.additional_remotes.length > 0
           @new_resource.additional_remotes.each_pair do |remote_name, remote_url|
             converge_by("add remote #{remote_name} from #{remote_url}") do
               Chef::Log.info "#{@new_resource} adding git remote #{remote_name} = #{remote_url}"
@@ -137,18 +140,18 @@ class Chef
       end
 
       def clone
-        converge_by("clone from #{@new_resource.repository} into #{@new_resource.destination}") do
+        converge_by("clone from #{@new_resource.repository} into #{cwd}") do
           remote = @new_resource.remote
 
-          args = []
-          args << "-o #{remote}" unless remote == 'origin'
-          args << "--depth #{@new_resource.depth}" if @new_resource.depth
-          args << "--no-single-branch" if @new_resource.depth and git_minor_version >= Gem::Version.new('1.7.10')
+          clone_cmd = ["clone"]
+          clone_cmd << "-o #{remote}" unless remote == "origin"
+          clone_cmd << "--depth #{@new_resource.depth}" if @new_resource.depth
+          clone_cmd << "--no-single-branch" if @new_resource.depth && git_minor_version >= Gem::Version.new("1.7.10")
+          clone_cmd << "\"#{@new_resource.repository}\""
+          clone_cmd << "\"#{cwd}\""
 
-          Chef::Log.info "#{@new_resource} cloning repo #{@new_resource.repository} to #{@new_resource.destination}"
-
-          clone_cmd = "git clone #{args.join(' ')} \"#{@new_resource.repository}\" \"#{@new_resource.destination}\""
-          shell_out!(clone_cmd, run_options)
+          Chef::Log.info "#{@new_resource} cloning repo #{@new_resource.repository} to #{cwd}"
+          git clone_cmd
         end
       end
 
@@ -157,8 +160,8 @@ class Chef
 
         converge_by("checkout ref #{sha_ref} branch #{@new_resource.revision}") do
           # checkout into a local branch rather than a detached HEAD
-          shell_out!("git branch -f #{@new_resource.checkout_branch} #{sha_ref}", run_options(:cwd => @new_resource.destination))
-          shell_out!("git checkout #{@new_resource.checkout_branch}", run_options(:cwd => @new_resource.destination))
+          git("branch", "-f", @new_resource.checkout_branch, sha_ref, cwd: cwd)
+          git("checkout", @new_resource.checkout_branch, cwd: cwd)
           Chef::Log.info "#{@new_resource} checked out branch: #{@new_resource.revision} onto: #{@new_resource.checkout_branch} reference: #{sha_ref}"
         end
       end
@@ -167,12 +170,10 @@ class Chef
         if @new_resource.enable_submodules
           converge_by("enable git submodules for #{@new_resource}") do
             Chef::Log.info "#{@new_resource} synchronizing git submodules"
-            command = "git submodule sync"
-            shell_out!(command, run_options(:cwd => @new_resource.destination))
+            git("submodule", "sync", cwd: cwd)
             Chef::Log.info "#{@new_resource} enabling git submodules"
             # the --recursive flag means we require git 1.6.5+ now, see CHEF-1827
-            command = "git submodule update --init --recursive"
-            shell_out!(command, run_options(:cwd => @new_resource.destination))
+            git("submodule", "update", "--init", "--recursive", cwd: cwd)
           end
         end
       end
@@ -181,18 +182,18 @@ class Chef
         setup_remote_tracking_branches(@new_resource.remote, @new_resource.repository)
         converge_by("fetch updates for #{@new_resource.remote}") do
           # since we're in a local branch already, just reset to specified revision rather than merge
-          fetch_command = "git fetch #{@new_resource.remote} && git fetch #{@new_resource.remote} --tags && git reset --hard #{target_revision}"
           Chef::Log.debug "Fetching updates from #{new_resource.remote} and resetting to revision #{target_revision}"
-          shell_out!(fetch_command, run_options(:cwd => @new_resource.destination))
+          git("fetch", @new_resource.remote, cwd: cwd)
+          git("fetch", @new_resource.remote, "--tags", cwd: cwd)
+          git("reset", "--hard", target_revision, cwd: cwd)
         end
       end
 
       def setup_remote_tracking_branches(remote_name, remote_url)
         converge_by("set up remote tracking branches for #{remote_url} at #{remote_name}") do
-          Chef::Log.debug "#{@new_resource} configuring remote tracking branches for repository #{remote_url} "+
-            "at remote #{remote_name}"
-          check_remote_command = "git config --get remote.#{remote_name}.url"
-          remote_status = shell_out!(check_remote_command, run_options(:cwd => @new_resource.destination, :returns => [0,1,2]))
+          Chef::Log.debug "#{@new_resource} configuring remote tracking branches for repository #{remote_url} " + "at remote #{remote_name}"
+          check_remote_command = ["config", "--get", "remote.#{remote_name}.url"]
+          remote_status = git(check_remote_command, cwd: cwd, returns: [0, 1, 2])
           case remote_status.exitstatus
           when 0, 2
             # * Status 0 means that we already have a remote with this name, so we should update the url
@@ -200,13 +201,11 @@ class Chef
             # * Status 2 means that we have multiple urls assigned to the same remote (not a good idea)
             #   which we can fix by replacing them all with our target url (hence the --replace-all option)
 
-            if multiple_remotes?(remote_status) || !remote_matches?(remote_url,remote_status)
-              update_remote_url_command = "git config --replace-all remote.#{remote_name}.url #{remote_url}"
-              shell_out!(update_remote_url_command, run_options(:cwd => @new_resource.destination))
+            if multiple_remotes?(remote_status) || !remote_matches?(remote_url, remote_status)
+              git("config", "--replace-all", "remote.#{remote_name}.url", remote_url, cwd: cwd)
             end
           when 1
-            add_remote_command = "git remote add #{remote_name} #{remote_url}"
-            shell_out!(add_remote_command, run_options(:cwd => @new_resource.destination))
+            git("remote", "add", remote_name, remote_url, cwd: cwd)
           end
         end
       end
@@ -250,18 +249,18 @@ class Chef
         # Using such a degenerate annotated tag would be very
         # confusing. We avoid the issue by disallowing the use of
         # annotated tags named 'HEAD'.
-        if rev_search_pattern != 'HEAD'
-          found = find_revision(refs, @new_resource.revision, '^{}')
+        if rev_search_pattern != "HEAD"
+          found = find_revision(refs, @new_resource.revision, "^{}")
         else
-          found = refs_search(refs, 'HEAD')
+          found = refs_search(refs, "HEAD")
         end
         found = find_revision(refs, @new_resource.revision) if found.empty?
         found.size == 1 ? found.first[0] : nil
       end
 
-      def find_revision(refs, revision, suffix="")
-        found = refs_search(refs, rev_match_pattern('refs/tags/', revision) + suffix)
-        found = refs_search(refs, rev_match_pattern('refs/heads/', revision) + suffix) if found.empty?
+      def find_revision(refs, revision, suffix = "")
+        found = refs_search(refs, rev_match_pattern("refs/tags/", revision) + suffix)
+        found = refs_search(refs, rev_match_pattern("refs/heads/", revision) + suffix) if found.empty?
         found = refs_search(refs, revision + suffix) if found.empty?
         found
       end
@@ -275,16 +274,15 @@ class Chef
       end
 
       def rev_search_pattern
-        if ['', 'HEAD'].include? @new_resource.revision
-          'HEAD'
+        if ["", "HEAD"].include? @new_resource.revision
+          "HEAD"
         else
-          @new_resource.revision + '*'
+          @new_resource.revision + "*"
         end
       end
 
       def git_ls_remote(rev_pattern)
-        command = git(%Q(ls-remote "#{@new_resource.repository}" "#{rev_pattern}"))
-        shell_out!(command, run_options).stdout
+        git("ls-remote", "\"#{@new_resource.repository}\"", "\"#{rev_pattern}\"").stdout
       end
 
       def refs_search(refs, pattern)
@@ -293,36 +291,38 @@ class Chef
 
       private
 
-      def run_options(run_opts={})
+      def run_options(run_opts = {})
         env = {}
         if @new_resource.user
           run_opts[:user] = @new_resource.user
           # Certain versions of `git` misbehave if git configuration is
           # inaccessible in $HOME. We need to ensure $HOME matches the
           # user who is executing `git` not the user running Chef.
-          env['HOME'] = begin
-            require 'etc'
-            Etc.getpwnam(@new_resource.user).dir
+          env["HOME"] = begin
+            require "etc"
+            case @new_resource.user
+            when Integer
+              Etc.getpwuid(@new_resource.user).dir
+            else
+              Etc.getpwnam(@new_resource.user.to_s).dir
+            end
           rescue ArgumentError # user not found
             raise Chef::Exceptions::User, "Could not determine HOME for specified user '#{@new_resource.user}' for resource '#{@new_resource.name}'"
           end
         end
         run_opts[:group] = @new_resource.group if @new_resource.group
-        env['GIT_SSH'] = @new_resource.ssh_wrapper if @new_resource.ssh_wrapper
+        env["GIT_SSH"] = @new_resource.ssh_wrapper if @new_resource.ssh_wrapper
         run_opts[:log_tag] = @new_resource.to_s
         run_opts[:timeout] = @new_resource.timeout if @new_resource.timeout
         env.merge!(@new_resource.environment) if @new_resource.environment
         run_opts[:environment] = env unless env.empty?
         run_opts
-
       end
 
-      def cwd
-        @new_resource.destination
-      end
-
-      def git(*args)
-        ["git", *args].compact.join(" ")
+      def git(*args, **run_opts)
+        git_command = ["git", args].compact.join(" ")
+        Chef::Log.debug "running #{git_command}"
+        shell_out!(git_command, run_options(run_opts))
       end
 
       def sha_hash?(string)
