@@ -1,6 +1,6 @@
 #
-# Author:: AJ Christensen (<aj@opscode.com>)
-# Copyright:: Copyright (c) 2008 OpsCode, Inc.
+# Author:: AJ Christensen (<aj@chef.io>)
+# Copyright:: Copyright 2008-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,10 +16,10 @@
 # limitations under the License.
 #
 
-require 'chef/provider'
-require 'chef/mixin/shell_out'
-require 'chef/mixin/command'
-require 'etc'
+require "chef/provider"
+require "chef/mixin/shell_out"
+require "chef/mixin/command"
+require "etc"
 
 class Chef
   class Provider
@@ -86,14 +86,15 @@ class Chef
       # <false>:: If a change is not required
       def compare_group
         @change_desc = [ ]
-        if @new_resource.gid.to_s  != @current_resource.gid.to_s
+        if @new_resource.gid.to_s != @current_resource.gid.to_s
           @change_desc << "change gid #{@current_resource.gid} to #{@new_resource.gid}"
         end
 
-        if(@new_resource.append)
+        if @new_resource.append
           missing_members = []
           @new_resource.members.each do |member|
             next if has_current_group_member?(member)
+            validate_member!(member)
             missing_members << member
           end
           if missing_members.length > 0
@@ -122,10 +123,16 @@ class Chef
         @current_resource.members.include?(member)
       end
 
+      def validate_member!(member)
+        # Sub-classes can do any validation if needed
+        # and raise an error if validation fails
+        true
+      end
+
       def action_create
         case @group_exists
         when false
-          converge_by("create #{@new_resource.group_name}") do
+          converge_by("create group #{@new_resource.group_name}") do
             create_group
             Chef::Log.info("#{@new_resource} created")
           end
