@@ -1,6 +1,6 @@
 #
 # Author:: Doug MacEachern (<dougm@vmware.com>)
-# Copyright:: Copyright (c) 2010 VMware, Inc.
+# Copyright:: Copyright 2010-2016, VMware, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,13 +16,14 @@
 # limitations under the License.
 #
 
-require 'chef/provider/group/groupadd'
-require 'chef/mixin/shell_out'
+require "chef/provider/group/groupadd"
+require "chef/mixin/shell_out"
 
 class Chef
   class Provider
     class Group
       class Aix < Chef::Provider::Group::Groupadd
+        provides :group, platform: "aix"
 
         def required_binaries
           [ "/usr/bin/mkgroup",
@@ -68,10 +69,10 @@ class Chef
 
         def set_options
           opts = ""
-          { :gid => "id" }.sort { |a,b| a[0] <=> b[0] }.each do |field, option|
+          { :gid => "id" }.sort { |a, b| a[0] <=> b[0] }.each do |field, option|
             if @current_resource.send(field) != @new_resource.send(field)
               if @new_resource.send(field)
-                Chef::Log.debug("#{@new_resource} setting #{field.to_s} to #{@new_resource.send(field)}")
+                Chef::Log.debug("#{@new_resource} setting #{field} to #{@new_resource.send(field)}")
                 opts << " '#{option}=#{@new_resource.send(field)}'"
               end
             end
