@@ -1,6 +1,6 @@
 #
 # Author:: Dreamcat4 (<dreamcat4@gmail.com>)
-# Copyright:: Copyright (c) 2009 OpsCode, Inc.
+# Copyright:: Copyright 2009-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -35,8 +35,8 @@ class Chef
         def safe_dscl(*args)
           result = dscl(*args)
           return "" if ( args.first =~ /^delete/ ) && ( result[1].exitstatus != 0 )
-          raise(Chef::Exceptions::Group,"dscl error: #{result.inspect}") unless result[1].exitstatus == 0
-          raise(Chef::Exceptions::Group,"dscl error: #{result.inspect}") if result[2] =~ /No such key: /
+          raise(Chef::Exceptions::Group, "dscl error: #{result.inspect}") unless result[1].exitstatus == 0
+          raise(Chef::Exceptions::Group, "dscl error: #{result.inspect}") if result[2] =~ /No such key: /
           return result[2]
         end
 
@@ -53,14 +53,14 @@ class Chef
 
           if group_info
             group_info.each_line do |line|
-              key, val = line.split(': ')
+              key, val = line.split(": ")
               val.strip! if val
               case key.downcase
-              when 'primarygroupid'
+              when "primarygroupid"
                 @new_resource.gid(val) unless @new_resource.gid
                 @current_resource.gid(val)
-              when 'groupmembership'
-                @current_resource.members(val.split(' '))
+              when "groupmembership"
+                @current_resource.members(val.split(" "))
               end
             end
           end
@@ -69,10 +69,10 @@ class Chef
         end
 
         # get a free GID greater than 200
-        def get_free_gid(search_limit=1000)
+        def get_free_gid(search_limit = 1000)
           gid = nil; next_gid_guess = 200
           groups_gids = safe_dscl("list /Groups gid")
-          while(next_gid_guess < search_limit + 200)
+          while next_gid_guess < search_limit + 200
             if groups_gids =~ Regexp.new("#{Regexp.escape(next_gid_guess.to_s)}\n")
               next_gid_guess += 1
             else
@@ -90,8 +90,8 @@ class Chef
         end
 
         def set_gid
-          @new_resource.gid(get_free_gid) if [nil,""].include? @new_resource.gid
-          raise(Chef::Exceptions::Group,"gid is already in use") if gid_used?(@new_resource.gid)
+          @new_resource.gid(get_free_gid) if [nil, ""].include? @new_resource.gid
+          raise(Chef::Exceptions::Group, "gid is already in use") if gid_used?(@new_resource.gid)
           safe_dscl("create /Groups/#{@new_resource.group_name} PrimaryGroupID #{@new_resource.gid}")
         end
 
