@@ -1,6 +1,6 @@
 #
-# Author:: AJ Christensen (<aj@opscode.com>)
-# Copyright:: Copyright (c) 2008 OpsCode, Inc.
+# Author:: AJ Christensen (<aj@chef.io>)
+# Copyright:: Copyright 2008-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,12 +16,14 @@
 # limitations under the License.
 #
 
-require 'chef/provider/group/groupadd'
+require "chef/provider/group/groupadd"
 
 class Chef
   class Provider
     class Group
       class Suse < Chef::Provider::Group::Groupadd
+        provides :group, platform: "opensuse", platform_version: "< 12.3"
+        provides :group, platform: "suse", platform_version: "< 12.0"
 
         def load_current_resource
           super
@@ -37,12 +39,14 @@ class Chef
         end
 
         def set_members(members)
-          unless @current_resource.members.empty?
-            shell_out!("groupmod -R #{@current_resource.members.join(',')} #{@new_resource.group_name}")
+          to_delete = @current_resource.members - members
+          to_delete.each do |member|
+            remove_member(member)
           end
 
-          unless members.empty?
-            shell_out!("groupmod -A #{members.join(',')} #{@new_resource.group_name}")
+          to_add = members - @current_resource.members
+          to_add.each do |member|
+            add_member(member)
           end
         end
 
