@@ -1,6 +1,6 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Copyright:: Copyright (c) 2008 Opscode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Copyright:: Copyright 2008-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,8 +16,8 @@
 # limitations under the License.
 #
 
-require 'tempfile'
-require 'chef/http/simple'
+require "tempfile"
+require "chef/http/simple"
 
 class Chef
   class Provider
@@ -109,13 +109,13 @@ class Chef
 
       private
 
-        def check_message(message)
-          if message.kind_of?(Proc)
-            message.call
-          else
-            message
-          end
+      def check_message(message)
+        if message.kind_of?(Proc)
+          message.call
+        else
+          message
         end
+      end
 
     end
   end
