@@ -1,6 +1,6 @@
 #
 # Author:: Kaustubh Deorukhkar (kaustubh@clogeny.com)
-# Copyright:: Copyright (c) 2013 Opscode, Inc
+# Copyright:: Copyright 2013-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,12 +16,13 @@
 # limitations under the License.
 #
 
-require 'chef/provider/ifconfig'
+require "chef/provider/ifconfig"
 
 class Chef
   class Provider
     class Ifconfig
       class Aix < Chef::Provider::Ifconfig
+        provides :ifconfig, platform: %w{aix}
 
         def load_current_resource
           @current_resource = Chef::Resource::Ifconfig.new(@new_resource.name)
@@ -66,6 +67,7 @@ class Chef
         end
 
         private
+
         def add_command
           # ifconfig changes are temporary, chdev persist across reboots.
           raise Chef::Exceptions::Ifconfig, "interface metric attribute cannot be set for :add action" if @new_resource.metric
@@ -87,7 +89,7 @@ class Chef
         def hex_to_dec_netmask(netmask)
           # example '0xffff0000' -> '255.255.0.0'
           dec = netmask[2..3].to_i(16).to_s(10)
-          [4,6,8].each { |n| dec = dec + "." + netmask[n..n+1].to_i(16).to_s(10) }
+          [4, 6, 8].each { |n| dec = dec + "." + netmask[n..n + 1].to_i(16).to_s(10) }
           dec
         end
 
