@@ -1,6 +1,6 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Copyright:: Copyright (c) 2008 Opscode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Copyright:: Copyright 2008-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,13 +16,13 @@
 # limitations under the License.
 #
 
-require 'chef/config'
-require 'chef/log'
-require 'chef/mixin/file_class'
-require 'chef/resource/link'
-require 'chef/provider'
-require 'chef/scan_access_control'
-require 'chef/util/path_helper'
+require "chef/config"
+require "chef/log"
+require "chef/mixin/file_class"
+require "chef/resource/link"
+require "chef/provider"
+require "chef/scan_access_control"
+require "chef/util/path_helper"
 
 class Chef
   class Provider
@@ -58,8 +58,8 @@ class Chef
           @current_resource.link_type(:hard)
           if ::File.exists?(@current_resource.target_file)
             if ::File.exists?(@new_resource.to) &&
-               file_class.stat(@current_resource.target_file).ino ==
-               file_class.stat(@new_resource.to).ino
+                file_class.stat(@current_resource.target_file).ino ==
+                    file_class.stat(@new_resource.to).ino
               @current_resource.to(canonicalize(@new_resource.to))
             else
               @current_resource.to("")
@@ -74,19 +74,19 @@ class Chef
         requirements.assert(:delete) do |a|
           a.assertion do
             if @current_resource.to
-              @current_resource.link_type == @new_resource.link_type and
-              (@current_resource.link_type == :symbolic  or @current_resource.to != '')
+              @current_resource.link_type == @new_resource.link_type &&
+                (@current_resource.link_type == :symbolic || @current_resource.to != "")
             else
               true
             end
           end
-          a.failure_message Chef::Exceptions::Link, "Cannot delete #{@new_resource} at #{@new_resource.target_file}! Not a #{@new_resource.link_type.to_s} link."
+          a.failure_message Chef::Exceptions::Link, "Cannot delete #{@new_resource} at #{@new_resource.target_file}! Not a #{@new_resource.link_type} link."
           a.whyrun("Would assume the link at #{@new_resource.target_file} was previously created")
         end
       end
 
       def canonicalize(path)
-        Chef::Platform.windows? ? path.gsub('/', '\\') : path
+        Chef::Platform.windows? ? path.tr("/", '\\') : path
       end
 
       def action_create
@@ -96,7 +96,7 @@ class Chef
         #   target_file - the name of the link
 
         if @current_resource.to != canonicalize(@new_resource.to) ||
-           @current_resource.link_type != @new_resource.link_type
+            @current_resource.link_type != @new_resource.link_type
           # Handle the case where the symlink already exists and is pointing at a valid to_file
           if @current_resource.to
             # On Windows, to fix a symlink already pointing at a directory we must first
@@ -106,7 +106,7 @@ class Chef
             # directory we want to throw an exception and calling ::File.unlink on the directory symlink
             # will throw the correct ones.
             if Chef::Platform.windows? && ::File.directory?(@new_resource.to) &&
-               ::File.directory?(@current_resource.target_file)
+                ::File.directory?(@current_resource.target_file)
               converge_by("unlink existing windows symlink to dir at #{@new_resource.target_file}") do
                 ::Dir.unlink(@new_resource.target_file)
               end
@@ -118,7 +118,7 @@ class Chef
           end
           if @new_resource.link_type == :symbolic
             converge_by("create symlink at #{@new_resource.target_file} to #{@new_resource.to}") do
-              file_class.symlink(canonicalize(@new_resource.to),@new_resource.target_file)
+              file_class.symlink(canonicalize(@new_resource.to), @new_resource.target_file)
               Chef::Log.debug("#{@new_resource} created #{@new_resource.link_type} link from #{@new_resource.target_file} -> #{@new_resource.to}")
               Chef::Log.info("#{@new_resource} created")
             end
@@ -141,9 +141,16 @@ class Chef
 
       def action_delete
         if @current_resource.to # Exists
-          converge_by("delete link at #{@new_resource.target_file}") do
-            ::File.delete(@new_resource.target_file)
-            Chef::Log.info("#{@new_resource} deleted")
+          if Chef::Platform.windows? && ::File.directory?(@current_resource.target_file)
+            converge_by("delete link to dir at #{@new_resource.target_file}") do
+              ::Dir.delete(@new_resource.target_file)
+              Chef::Log.info("#{@new_resource} deleted")
+            end
+          else
+            converge_by("delete link to file at #{@new_resource.target_file}") do
+              ::File.delete(@new_resource.target_file)
+              Chef::Log.info("#{@new_resource} deleted")
+            end
           end
         end
       end
