@@ -1,6 +1,6 @@
 #
 # Author:: Joe Williams (<joe@joetify.com>)
-# Copyright:: Copyright (c) 2009 Joe Williams
+# Copyright:: Copyright 2009-2016, Joe Williams
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,8 +16,8 @@
 # limitations under the License.
 #
 
-require 'chef/log'
-require 'chef/provider'
+require "chef/log"
+require "chef/provider"
 
 class Chef
   class Provider
@@ -39,7 +39,7 @@ class Chef
         Chef::Log.debug("#{@new_resource} checking for software raid device #{@current_resource.raid_device}")
 
         device_not_found = 4
-        mdadm = shell_out!("mdadm --detail --test #{@new_resource.raid_device}", :returns => [0,device_not_found])
+        mdadm = shell_out!("mdadm --detail --test #{@new_resource.raid_device}", :returns => [0, device_not_found])
         exists = (mdadm.status == 0)
         @current_resource.exists(exists)
       end
@@ -51,6 +51,7 @@ class Chef
             command << " --chunk=#{@new_resource.chunk}" unless @new_resource.level == 1
             command << " --metadata=#{@new_resource.metadata}"
             command << " --bitmap=#{@new_resource.bitmap}" if @new_resource.bitmap
+            command << " --layout=#{@new_resource.layout}" if @new_resource.layout
             command << " --raid-devices #{@new_resource.devices.length} #{@new_resource.devices.join(" ")}"
             Chef::Log.debug("#{@new_resource} mdadm command: #{command}")
             shell_out!(command)
