@@ -1,6 +1,6 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Copyright:: Copyright (c) 2008 Opscode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Copyright:: Copyright 2008-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,14 +16,13 @@
 # limitations under the License.
 #
 
-require 'chef/provider'
-require 'chef/mixin/command'
-require 'etc'
+require "chef/provider"
+require "chef/mixin/command"
+require "etc"
 
 class Chef
   class Provider
     class User < Chef::Provider
-
       include Chef::Mixin::Command
 
       attr_accessor :user_exists, :locked
@@ -72,9 +71,9 @@ class Chef
           end
           @current_resource.comment(user_info.gecos)
 
-          if @new_resource.password && @current_resource.password == 'x'
+          if @new_resource.password && @current_resource.password == "x"
             begin
-              require 'shadow'
+              require "shadow"
             rescue LoadError
               @shadow_lib_ok = false
             else
@@ -90,7 +89,7 @@ class Chef
       end
 
       def define_resource_requirements
-        requirements.assert(:all_actions) do |a|
+        requirements.assert(:create, :modify, :manage, :lock, :unlock) do |a|
           a.assertion { @group_name_resolved }
           a.failure_message Chef::Exceptions::User, "Couldn't lookup integer GID for group name #{@new_resource.gid}"
           a.whyrun "group name #{@new_resource.gid} does not exist.  This will cause group assignment to fail.  Assuming this group will have been created previously."
@@ -99,7 +98,7 @@ class Chef
           a.assertion { @shadow_lib_ok }
           a.failure_message Chef::Exceptions::MissingLibrary, "You must have ruby-shadow installed for password support!"
           a.whyrun "ruby-shadow is not installed. Attempts to set user password will cause failure.  Assuming that this gem will have been previously installed." +
-                   "Note that user update converge may report false-positive on the basis of mismatched password. "
+            "Note that user update converge may report false-positive on the basis of mismatched password. "
         end
         requirements.assert(:modify, :lock, :unlock) do |a|
           a.assertion { @user_exists }
@@ -126,7 +125,6 @@ class Chef
       end
 
       def action_create
-
         if !@user_exists
           converge_by("create user #{@new_resource.username}") do
             create_user
@@ -149,10 +147,6 @@ class Chef
         end
       end
 
-      def remove_user
-        raise NotImplementedError
-      end
-
       def action_manage
         if @user_exists && compare_user
           converge_by("manage user #{@new_resource.username}") do
@@ -162,10 +156,6 @@ class Chef
         end
       end
 
-      def manage_user
-        raise NotImplementedError
-      end
-
       def action_modify
         if compare_user
           converge_by("modify user #{@new_resource.username}") do
@@ -181,19 +171,11 @@ class Chef
             lock_user
             Chef::Log.info("#{@new_resource} locked")
           end
-         else
+        else
           Chef::Log.debug("#{@new_resource} already locked - nothing to do")
         end
       end
 
-      def check_lock
-        raise NotImplementedError
-      end
-
-      def lock_user
-        raise NotImplementedError
-      end
-
       def action_unlock
         if check_lock() == true
           converge_by("unlock user #{@new_resource.username}") do
@@ -205,10 +187,29 @@ class Chef
         end
       end
 
+      def create_user
+        raise NotImplementedError
+      end
+
+      def remove_user
+        raise NotImplementedError
+      end
+
+      def manage_user
+        raise NotImplementedError
+      end
+
+      def lock_user
+        raise NotImplementedError
+      end
+
       def unlock_user
         raise NotImplementedError
       end
 
+      def check_lock
+        raise NotImplementedError
+      end
     end
   end
 end
