@@ -1,6 +1,6 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Copyright:: Copyright (c) 2008 Opscode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Copyright:: Copyright 2008-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,13 +16,14 @@
 # limitations under the License.
 #
 
-require 'pathname'
-require 'chef/provider/user'
+require "pathname"
+require "chef/provider/user"
 
 class Chef
   class Provider
     class User
       class Useradd < Chef::Provider::User
+        # MAJOR XXX: this should become the base class of all Useradd providers instead of the linux implementation
 
         UNIVERSAL_OPTIONS = [[:comment, "-c"], [:gid, "-g"], [:password, "-p"], [:shell, "-s"], [:uid, "-u"]]
 
@@ -54,7 +55,7 @@ class Chef
         def check_lock
           # we can get an exit code of 1 even when it's successful on
           # rhel/centos (redhat bug 578534). See additional error checks below.
-          passwd_s = shell_out!("passwd", "-S", new_resource.username, :returns => [0,1])
+          passwd_s = shell_out!("passwd", "-S", new_resource.username, :returns => [0, 1])
           if whyrun_mode? && passwd_s.stdout.empty? && passwd_s.stderr.match(/does not exist/)
             # if we're in whyrun mode and the user is not yet created we assume it would be
             return false
@@ -62,7 +63,7 @@ class Chef
 
           raise Chef::Exceptions::User, "Cannot determine if #{@new_resource} is locked!" if passwd_s.stdout.empty?
 
-          status_line = passwd_s.stdout.split(' ')
+          status_line = passwd_s.stdout.split(" ")
           case status_line[1]
           when /^P/
             @locked = false
@@ -74,11 +75,11 @@ class Chef
 
           unless passwd_s.exitstatus == 0
             raise_lock_error = false
-            if ['redhat', 'centos'].include?(node[:platform])
-              passwd_version_check = shell_out!('rpm -q passwd')
+            if %w{redhat centos}.include?(node[:platform])
+              passwd_version_check = shell_out!("rpm -q passwd")
               passwd_version = passwd_version_check.stdout.chomp
 
-              unless passwd_version == 'passwd-0.73-1'
+              unless passwd_version == "passwd-0.73-1"
                 raise_lock_error = true
               end
             else
@@ -115,15 +116,15 @@ class Chef
                 update_options(field, option, opts)
               end
               if updating_home?
+                opts << "-d" << new_resource.home
                 if managing_home_dir?
                   Chef::Log.debug("#{new_resource} managing the users home directory")
-                  opts << "-d" << new_resource.home << "-m"
+                  opts << "-m"
                 else
                   Chef::Log.debug("#{new_resource} setting home to #{new_resource.home}")
-                  opts << "-d" << new_resource.home
                 end
               end
-              opts << "-o" if new_resource.non_unique || new_resource.supports[:non_unique]
+              opts << "-o" if new_resource.non_unique
               opts
             end
         end
@@ -140,6 +141,7 @@ class Chef
         def useradd_options
           opts = []
           opts << "-r" if new_resource.system
+          opts << "-M" unless managing_home_dir?
           opts
         end
 
@@ -149,7 +151,7 @@ class Chef
           # ::File.expand_path("///tmp") == ::File.expand_path("/tmp") => false
           # ::File.expand_path("\\tmp") => "C:/tmp"
           return true if @current_resource.home.nil? && new_resource.home
-          new_resource.home and Pathname.new(@current_resource.home).cleanpath != Pathname.new(new_resource.home).cleanpath
+          new_resource.home && Pathname.new(@current_resource.home).cleanpath != Pathname.new(new_resource.home).cleanpath
         end
 
         def managing_home_dir?
