@@ -1,6 +1,6 @@
 #
 # Author:: Daniel DeLeo (<dan@kallistec.com>)
-# Copyright:: Copyright (c) 2008 Opscode, Inc.
+# Copyright:: Copyright 2008-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,20 +16,17 @@
 # limitations under the License.
 #
 
-
-require 'chef/resource'
+require "chef/resource"
 
 class Chef
   class Resource
     class Breakpoint < Chef::Resource
+      default_action :break
 
-      def initialize(action="break", *args)
-        @name = caller.first
-        super(@name, *args)
-        @action = "break"
-        @allowed_actions << :break
-        @resource_name = :breakpoint
+      def initialize(action = "break", *args)
+        super(caller.first, *args)
       end
+
     end
   end
 end
