@@ -1,6 +1,6 @@
 #
 # Author:: Joe Williams (<joe@joetify.com>)
-# Copyright:: Copyright (c) 2009 Joe Williams
+# Copyright:: Copyright 2009-2016, Joe Williams
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,42 +16,16 @@
 # limitations under the License.
 #
 
-require 'chef/resource/package'
+require "chef/resource/package"
 
 class Chef
   class Resource
     class EasyInstallPackage < Chef::Resource::Package
+      resource_name :easy_install_package
 
-      provides :easy_install_package
-
-      def initialize(name, run_context=nil)
-        super
-        @resource_name = :easy_install_package
-      end
-
-      def easy_install_binary(arg=nil)
-        set_or_return(
-          :easy_install_binary,
-          arg,
-          :kind_of => [ String ]
-        )
-      end
-
-      def python_binary(arg=nil)
-        set_or_return(
-          :python_install_binary,
-          arg,
-          :kind_of => [ String ]
-        )
-      end
-
-      def module_name(arg=nil)
-        set_or_return(
-          :module_name,
-          arg,
-          :kind_of => [ String ]
-        )
-      end
+      property :easy_install_binary, String, desired_state: false
+      property :python_binary, String, desired_state: false
+      property :module_name, String, desired_state: false
 
     end
   end
