@@ -1,7 +1,7 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Author:: Tyler Cloke (<tyler@opscode.com>)
-# Copyright:: Copyright (c) 2008 OpsCode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Author:: Tyler Cloke (<tyler@chef.io>)
+# Copyright:: Copyright 2008-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -25,22 +25,20 @@ class Chef
 
       state_attrs :members
 
-      provides :group
+      allowed_actions :create, :remove, :modify, :manage
+      default_action :create
 
-      def initialize(name, run_context=nil)
+      def initialize(name, run_context = nil)
         super
-        @resource_name = :group
         @group_name = name
         @gid = nil
         @members = []
         @excluded_members = []
-        @action = :create
         @append = false
         @non_unique = false
-        @allowed_actions.push(:create, :remove, :modify, :manage)
       end
 
-      def group_name(arg=nil)
+      def group_name(arg = nil)
         set_or_return(
           :group_name,
           arg,
@@ -48,7 +46,7 @@ class Chef
         )
       end
 
-      def gid(arg=nil)
+      def gid(arg = nil)
         set_or_return(
           :gid,
           arg,
@@ -56,8 +54,8 @@ class Chef
         )
       end
 
-      def members(arg=nil)
-        converted_members = arg.is_a?(String) ? [].push(arg) : arg
+      def members(arg = nil)
+        converted_members = arg.is_a?(String) ? arg.split(",") : arg
         set_or_return(
           :members,
           converted_members,
@@ -67,8 +65,8 @@ class Chef
 
       alias_method :users, :members
 
-      def excluded_members(arg=nil)
-        converted_members = arg.is_a?(String) ? [].push(arg) : arg
+      def excluded_members(arg = nil)
+        converted_members = arg.is_a?(String) ? arg.split(",") : arg
         set_or_return(
           :excluded_members,
           converted_members,
@@ -76,8 +74,7 @@ class Chef
         )
       end
 
-
-      def append(arg=nil)
+      def append(arg = nil)
         set_or_return(
           :append,
           arg,
@@ -85,7 +82,7 @@ class Chef
         )
       end
 
-      def system(arg=nil)
+      def system(arg = nil)
         set_or_return(
           :system,
           arg,
@@ -93,7 +90,7 @@ class Chef
         )
       end
 
-      def non_unique(arg=nil)
+      def non_unique(arg = nil)
         set_or_return(
           :non_unique,
           arg,
