@@ -1,6 +1,6 @@
 #
 # Author:: Jason Williams (<williamsjj@digitar.com>)
-# Copyright:: Copyright (c) 2011 Opscode, Inc.
+# Copyright:: Copyright 2011-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,29 +16,19 @@
 # limitations under the License.
 #
 
-require 'chef/resource/package'
-require 'chef/provider/package/ips'
+require "chef/resource/package"
+require "chef/provider/package/ips"
 
 class Chef
   class Resource
     class IpsPackage < ::Chef::Resource::Package
-
+      resource_name :ips_package
+      provides :package, os: "solaris2"
       provides :ips_package, os: "solaris2"
 
-      def initialize(name, run_context = nil)
-        super(name, run_context)
-        @resource_name = :ips_package
-        @allowed_actions.push(:install, :remove, :upgrade)
-        @accept_license = false
-      end
+      allowed_actions :install, :remove, :upgrade
 
-      def accept_license(arg=nil)
-        set_or_return(
-          :purge,
-          arg,
-          :kind_of => [ TrueClass, FalseClass ]
-        )
-      end
+      property :accept_license, [ true, false ], default: false, desired_state: false
     end
   end
 end
