@@ -1,7 +1,7 @@
 #
 # Author:: Michael Leinartas (<mleinartas@gmail.com>)
-# Author:: Tyler Cloke (<tyler@opscode.com>)
-# Copyright:: Copyright (c) 2010 Michael Leinartas
+# Author:: Tyler Cloke (<tyler@chef.io>)
+# Copyright:: Copyright 2010-2016, Michael Leinartas
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -25,16 +25,15 @@ class Chef
 
       state_attrs :plugin
 
-      def initialize(name, run_context=nil)
+      default_action :reload
+
+      def initialize(name, run_context = nil)
         super
-        @resource_name = :ohai
         @name = name
-        @allowed_actions.push(:reload)
-        @action = :reload
         @plugin = nil
       end
 
-      def plugin(arg=nil)
+      def plugin(arg = nil)
         set_or_return(
           :plugin,
           arg,
@@ -42,7 +41,7 @@ class Chef
         )
       end
 
-      def name(arg=nil)
+      def name(arg = nil)
         set_or_return(
           :name,
           arg,
