@@ -1,6 +1,6 @@
 #
-# Author:: Chris Doherty <cdoherty@getchef.com>)
-# Copyright:: Copyright (c) 2014 Chef, Inc.
+# Author:: Chris Doherty <cdoherty@chef.io>)
+# Copyright:: Copyright 2014-2016, Chef, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,7 +16,7 @@
 # limitations under the License.
 #
 
-require 'chef/resource'
+require "chef/resource"
 
 # In using this resource via notifications, it's important to *only* use
 # immediate notifications. Delayed notifications produce unintuitive and
@@ -24,11 +24,11 @@ require 'chef/resource'
 class Chef
   class Resource
     class Reboot < Chef::Resource
-      def initialize(name, run_context=nil)
+      allowed_actions :request_reboot, :reboot_now, :cancel
+
+      def initialize(name, run_context = nil)
         super
-        @resource_name = :reboot
         @provider = Chef::Provider::Reboot
-        @allowed_actions.push(:request_reboot, :reboot_now, :cancel)
 
         @reason = "Reboot by Chef"
         @delay_mins = 0
@@ -36,11 +36,11 @@ class Chef
         # no default action.
       end
 
-      def reason(arg=nil)
+      def reason(arg = nil)
         set_or_return(:reason, arg, :kind_of => String)
       end
 
-      def delay_mins(arg=nil)
+      def delay_mins(arg = nil)
         set_or_return(:delay_mins, arg, :kind_of => Fixnum)
       end
     end
