@@ -1,7 +1,7 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Author:: Tyler Cloke (<tyler@opscode.com>)
-# Copyright:: Copyright (c) 2008 Opscode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Author:: Tyler Cloke (<tyler@chef.io>)
+# Copyright:: Copyright 2008-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,19 +17,17 @@
 # limitations under the License.
 #
 
-require 'chef/resource/execute'
-require 'chef/provider/script'
+require "chef/resource/execute"
+require "chef/provider/script"
 
 class Chef
   class Resource
     class Script < Chef::Resource::Execute
-
       # Chef-13: go back to using :name as the identity attr
       identity_attr :command
 
-      def initialize(name, run_context=nil)
+      def initialize(name, run_context = nil)
         super
-        @resource_name = :script
         # Chef-13: the command variable should be initialized to nil
         @command = name
         @code = nil
@@ -38,16 +36,16 @@ class Chef
         @default_guard_interpreter = :default
       end
 
-      def command(arg=nil)
+      def command(arg = nil)
         unless arg.nil?
           # Chef-13: change this to raise if the user is trying to set a value here
           Chef::Log.warn "Specifying command attribute on a script resource is a coding error, use the 'code' attribute, or the execute resource"
-          Chef::Log.warn "This attribute is deprecated and must be fixed or this code will fail on Chef-13"
+          Chef::Log.warn "This attribute is deprecated and must be fixed or this code will fail on Chef 13"
         end
         super
       end
 
-      def code(arg=nil)
+      def code(arg = nil)
         set_or_return(
           :code,
           arg,
@@ -55,7 +53,7 @@ class Chef
         )
       end
 
-      def interpreter(arg=nil)
+      def interpreter(arg = nil)
         set_or_return(
           :interpreter,
           arg,
@@ -63,7 +61,7 @@ class Chef
         )
       end
 
-      def flags(arg=nil)
+      def flags(arg = nil)
         set_or_return(
           :flags,
           arg,
