@@ -1,6 +1,6 @@
 #
-# Author:: Prajakta Purohit (<prajakta@opscode.com>)
-# Copyright:: Copyright (c) 2011 Opscode, Inc.
+# Author:: Prajakta Purohit (<prajakta@chef.io>)
+# Copyright:: Copyright 2011-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -25,15 +25,13 @@ describe Chef::Resource::RegistryKey, :windows_only do
     ::Win32::Registry::HKEY_CURRENT_USER.create "Software\\Root"
     ::Win32::Registry::HKEY_CURRENT_USER.create "Software\\Root\\Branch"
     ::Win32::Registry::HKEY_CURRENT_USER.open('Software\\Root', Win32::Registry::KEY_ALL_ACCESS) do |reg|
-      reg['RootType1', Win32::Registry::REG_SZ] = 'fibrous'
-      reg.write('Roots', Win32::Registry::REG_MULTI_SZ, ["strong roots", "healthy tree"])
+      reg["RootType1", Win32::Registry::REG_SZ] = "fibrous"
+      reg.write("Roots", Win32::Registry::REG_MULTI_SZ, ["strong roots", "healthy tree"])
     end
 
     events = Chef::EventDispatch::Dispatcher.new
     node = Chef::Node.new
-    ohai = Ohai::System.new
-    ohai.all_plugins
-    node.consume_external_attrs(ohai.data,{})
+    node.consume_external_attrs(OHAI_SYSTEM.data, {})
     run_context = Chef::RunContext.new(node, {}, events)
     @resource = Chef::Resource.new("foo", run_context)
   end
@@ -44,7 +42,7 @@ describe Chef::Resource::RegistryKey, :windows_only do
     end
     it "returns true if registry has specified value" do
       values = @resource.registry_get_values("HKCU\\Software\\Root")
-      expect(values.include?({:name=>"RootType1",:type=>:string,:data=>"fibrous"})).to eq(true)
+      expect(values.include?({ :name => "RootType1", :type => :string, :data => "fibrous" })).to eq(true)
     end
     it "returns true if specified registry_has_subkey" do
       expect(@resource.registry_has_subkeys?("HKCU\\Software\\Root")).to eq(true)
@@ -54,10 +52,10 @@ describe Chef::Resource::RegistryKey, :windows_only do
       expect(subkeys.include?("Branch")).to eq(true)
     end
     it "returns true if registry_value_exists" do
-      expect(@resource.registry_value_exists?("HKCU\\Software\\Root", {:name=>"RootType1", :type=>:string, :data=>"fibrous"})).to eq(true)
+      expect(@resource.registry_value_exists?("HKCU\\Software\\Root", { :name => "RootType1", :type => :string, :data => "fibrous" })).to eq(true)
     end
     it "returns true if data_value_exists" do
-      expect(@resource.registry_data_exists?("HKCU\\Software\\Root", {:name=>"RootType1", :type=>:string, :data=>"fibrous"})).to eq(true)
+      expect(@resource.registry_data_exists?("HKCU\\Software\\Root", { :name => "RootType1", :type => :string, :data => "fibrous" })).to eq(true)
     end
   end
 end
