@@ -1,6 +1,6 @@
 #
 # Author:: Prabhu Das (<prabhu.das@clogeny.com>)
-# Copyright:: Copyright (c) 2013 Opscode, Inc.
+# Copyright:: Copyright 2013-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,11 +16,11 @@
 # limitations under the License.
 #
 
-require 'functional/resource/base'
-require 'chef/mixin/shell_out'
+require "functional/resource/base"
+require "chef/mixin/shell_out"
 
 # Run the test only for AIX platform.
-describe Chef::Resource::BffPackage, :requires_root, :external => ohai[:platform] != 'aix' do
+describe Chef::Resource::BffPackage, :requires_root, :external => ohai[:platform] != "aix" do
   include Chef::Mixin::ShellOut
 
   let(:new_resource) do
@@ -39,11 +39,10 @@ describe Chef::Resource::BffPackage, :requires_root, :external => ohai[:platform
     !::File.exists?("/usr/PkgA/bin/acommand")
   end
 
-
   before(:all) do
     @pkg_name = "PkgA.rte"
-    @pkg_path = "/tmp/PkgA.1.0.0.0.bff"
-    FileUtils.cp 'spec/functional/assets/PkgA.1.0.0.0.bff' , @pkg_path
+    @pkg_path = "#{Dir.tmpdir}/PkgA.1.0.0.0.bff"
+    FileUtils.cp "spec/functional/assets/PkgA.1.0.0.0.bff" , @pkg_path
   end
 
   after(:all) do
@@ -70,15 +69,15 @@ describe Chef::Resource::BffPackage, :requires_root, :external => ohai[:platform
 
     after(:each) do
       shell_out("installp -u #{@pkg_name}")
-      FileUtils.rm "/tmp/installp.log"
+      FileUtils.rm "#{Dir.tmpdir}/installp.log"
     end
   end
 
   context "package upgrade action" do
     before(:each) do
       shell_out("installp -aYF -d #{@pkg_path} #{@pkg_name}")
-      @pkg_path = "/tmp/PkgA.2.0.0.0.bff"
-      FileUtils.cp 'spec/functional/assets/PkgA.2.0.0.0.bff' , @pkg_path
+      @pkg_path = "#{Dir.tmpdir}/PkgA.2.0.0.0.bff"
+      FileUtils.cp "spec/functional/assets/PkgA.2.0.0.0.bff" , @pkg_path
     end
 
     it "should upgrade package" do
@@ -115,8 +114,7 @@ describe Chef::Resource::BffPackage, :requires_root, :external => ohai[:platform
     end
 
     after(:each) do
-      FileUtils.rm "/tmp/installp.log"
+      FileUtils.rm "#{Dir.tmpdir}/installp.log"
     end
   end
 end
-
