@@ -1,6 +1,6 @@
 #
-# Author:: Tim Hinderliter (<tim@opscode.com>)
-# Copyright:: Copyright (c) 2012 Opscode, Inc.
+# Author:: Tim Hinderliter (<tim@chef.io>)
+# Copyright:: Copyright 2012-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,16 +16,16 @@
 # limitations under the License.
 #
 
-require 'spec_helper'
+require "spec_helper"
 
 describe Chef::Resource::CookbookFile do
   include_context Chef::Resource::File
 
-  let(:file_base) { 'cookbook_file_spec' }
-  let(:source) { 'java.response' }
-  let(:cookbook_name) { 'java' }
+  let(:file_base) { "cookbook_file_spec" }
+  let(:source) { "java.response" }
+  let(:cookbook_name) { "java" }
   let(:expected_content) do
-    content = File.open(File.join(CHEF_SPEC_DATA, 'cookbooks', 'java', 'files', 'default', 'java.response'), "rb") do |f|
+    content = File.open(File.join(CHEF_SPEC_DATA, "cookbooks", "java", "files", "default", "java.response"), "rb") do |f|
       f.read
     end
     content.force_encoding(Encoding::BINARY) if content.respond_to?(:force_encoding)
@@ -39,7 +39,7 @@ describe Chef::Resource::CookbookFile do
   def create_resource
     # set up cookbook collection for this run to use, based on our
     # spec data.
-    cookbook_repo = File.expand_path(File.join(CHEF_SPEC_DATA, 'cookbooks'))
+    cookbook_repo = File.expand_path(File.join(CHEF_SPEC_DATA, "cookbooks"))
     Chef::Cookbook::FileVendor.fetch_from_disk(cookbook_repo)
     loader = Chef::CookbookLoader.new(cookbook_repo)
     loader.load_cookbooks
@@ -66,11 +66,11 @@ describe Chef::Resource::CookbookFile do
   # implementation
   # stages files in temp.
   context "targets a file outside of the system temp directory" do
-    let(:windows_non_temp_dir) { File.join(ENV['systemdrive'], make_tmpname(file_base, "non-temp")) }
+    let(:windows_non_temp_dir) { File.join(ENV["systemdrive"], make_tmpname(file_base, "non-temp")) }
     let(:path) { File.join(windows_non_temp_dir, make_tmpname(file_base)) }
 
     before do
-      FileUtils::mkdir_p(windows_non_temp_dir) if Chef::Platform.windows?
+      FileUtils.mkdir_p(windows_non_temp_dir) if Chef::Platform.windows?
     end
 
     after do
