@@ -1,6 +1,6 @@
 #
 # Author:: Kaustubh Deorukhkar (<kaustubh@clogeny.com>)
-# Copyright:: Copyright (c) 2013 Opscode, Inc.
+# Copyright:: Copyright 2013-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,17 +16,19 @@
 # limitations under the License.
 #
 
-require 'functional/resource/base'
-require 'chef/mixin/shell_out'
+require "functional/resource/base"
+require "chef/mixin/shell_out"
 
 # run this test only for following platforms.
-include_flag = !(['ubuntu', 'centos', 'aix'].include?(ohai[:platform]))
+include_flag = !(%w{ubuntu centos aix}.include?(ohai[:platform]))
+
+describe Chef::Resource::Ifconfig, :requires_root, :skip_travis, :external => include_flag do
+  # This test does not work in travis because there is no eth0
 
-describe Chef::Resource::Ifconfig, :requires_root, :external => include_flag do
   include Chef::Mixin::ShellOut
 
   let(:new_resource) do
-    new_resource = Chef::Resource::Ifconfig.new('10.10.0.1', run_context)
+    new_resource = Chef::Resource::Ifconfig.new("10.10.0.1", run_context)
     new_resource
   end
 
@@ -43,9 +45,9 @@ describe Chef::Resource::Ifconfig, :requires_root, :external => include_flag do
     # use loopback interface for tests
     case ohai[:platform]
     when "aix"
-      'lo0'
+      "lo0"
     else
-      'lo'
+      "lo"
     end
   end
 
@@ -53,9 +55,9 @@ describe Chef::Resource::Ifconfig, :requires_root, :external => include_flag do
   def en0_interface_for_test
     case ohai[:platform]
     when "aix"
-      'en0'
+      "en0"
     else
-      'eth0'
+      "eth0"
     end
   end
 
@@ -105,14 +107,14 @@ describe Chef::Resource::Ifconfig, :requires_root, :external => include_flag do
   # Actual tests
 
   describe "#load_current_resource" do
-    it 'should load given interface' do
+    it "should load given interface" do
       new_resource.device lo_interface_for_test
       expect(current_resource.device).to eql(lo_interface_for_test)
       expect(current_resource.inet_addr).to match(/^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$/)
     end
   end
 
-  exclude_test = ohai[:platform] != 'ubuntu'
+  exclude_test = ohai[:platform] != "ubuntu"
   describe "#action_add", :external => exclude_test do
     after do
       new_resource.run_action(:delete)
