@@ -1,6 +1,6 @@
 #
 # Author:: Kaustubh Deorukhkar (<kaustubh@clogeny.com>)
-# Copyright:: Copyright (c) 2013 Opscode, Inc.
+# Copyright:: Copyright 2013-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,14 +16,17 @@
 # limitations under the License.
 #
 
-require 'functional/resource/base'
-require 'chef/mixin/shell_out'
-require 'tmpdir'
+require "spec_helper"
+require "functional/resource/base"
+require "chef/mixin/shell_out"
+require "tmpdir"
 
 # run this test only for following platforms.
-include_flag = !(['ubuntu', 'centos', 'aix', 'solaris2'].include?(ohai[:platform]))
+include_flag = !(%w{ubuntu centos aix solaris2}.include?(ohai[:platform]))
 
-describe Chef::Resource::Mount, :requires_root, :external => include_flag do
+describe Chef::Resource::Mount, :requires_root, :skip_travis, :external => include_flag do
+  # Disabled in travis because it refuses to let us mount a ramdisk. /dev/ramX does not
+  # exist even after loading the kernel module
 
   include Chef::Mixin::ShellOut
 
@@ -34,13 +37,11 @@ describe Chef::Resource::Mount, :requires_root, :external => include_flag do
     # This can cleaner if we have chef resource/provider for ramdisk.
     case ohai[:platform]
     when "aix"
-      ramdisk = shell_out!("mkramdisk 16M").stdout
-
-      # identify device, for /dev/rramdisk0 it is /dev/ramdisk0
-      device = ramdisk.tr("\n","").gsub(/\/rramdisk/, '/ramdisk')
-
-      fstype = "jfs2"
-      shell_out!("mkfs  -V #{fstype} #{device}")
+      # On AIX, we can't create a ramdisk inside a WPAR, so we use
+      # a "namefs" mount against / to test
+      # https://www-304.ibm.com/support/knowledgecenter/ssw_aix_71/com.ibm.aix.performance/namefs_file_sys.htm
+      device = "/"
+      fstype = "namefs"
     when "ubuntu", "centos"
       device = "/dev/ram1"
       shell_out("ls -1 /dev/ram*").stdout.each_line do |d|
@@ -60,15 +61,6 @@ describe Chef::Resource::Mount, :requires_root, :external => include_flag do
     [device, fstype]
   end
 
-  def cleanup_device(device)
-    case ohai[:platform]
-    when "aix"
-      ramdisk = device.gsub(/\/ramdisk/, '/rramdisk')
-      shell_out("rmramdisk #{ramdisk}")
-    else
-    end
-  end
-
   def cleanup_mount(mount_point)
     shell_out("umount #{mount_point}")
   end
@@ -87,9 +79,9 @@ describe Chef::Resource::Mount, :requires_root, :external => include_flag do
 
   def unix_mount_config_file
     case ohai[:platform]
-    when 'aix'
+    when "aix"
       mount_config = "/etc/filesystems"
-    when 'solaris2'
+    when "solaris2"
       mount_config = "/etc/vfstab"
     else
       mount_config = "/etc/fstab"
@@ -98,7 +90,7 @@ describe Chef::Resource::Mount, :requires_root, :external => include_flag do
 
   def mount_should_be_enabled(mount_point, device)
     case ohai[:platform]
-    when 'aix'
+    when "aix"
       expect(shell_out("cat #{unix_mount_config_file} | grep \"#{mount_point}:\" ").exitstatus).to eq(0)
     else
       expect(shell_out("cat #{unix_mount_config_file} | grep \"#{mount_point}\" | grep \"#{device}\" ").exitstatus).to eq(0)
@@ -114,7 +106,7 @@ describe Chef::Resource::Mount, :requires_root, :external => include_flag do
     new_resource.device      @device
     new_resource.name        @mount_point
     new_resource.fstype      @fstype
-    new_resource.options     "log=NULL" if ohai[:platform] == 'aix'
+    new_resource.options     "log=NULL" if ohai[:platform] == "aix"
     new_resource
   end
 
@@ -146,7 +138,6 @@ describe Chef::Resource::Mount, :requires_root, :external => include_flag do
 
   after(:all) do
     Dir.rmdir(@mount_point)
-    cleanup_device(@device)
   end
 
   after(:each) do
@@ -172,10 +163,10 @@ describe Chef::Resource::Mount, :requires_root, :external => include_flag do
       mount_should_exist(new_resource.mount_point, new_resource.device)
 
       new_resource.supports[:remount] = true
-      new_resource.options "rw,log=NULL" if ohai[:platform] == 'aix'
+      new_resource.options "rw" if ohai[:platform] == "aix"
       new_resource.run_action(:remount)
 
-      mount_should_exist(new_resource.mount_point, new_resource.device, nil, (ohai[:platform] == 'aix') ? new_resource.options : nil)
+      mount_should_exist(new_resource.mount_point, new_resource.device, nil, (ohai[:platform] == "aix") ? new_resource.options : nil)
     end
   end
 
