@@ -1,6 +1,6 @@
 #
-# Author:: Seth Chisamore (<schisamo@opscode.com>)
-# Copyright:: Copyright (c) 2011 Opscode, Inc.
+# Author:: Seth Chisamore (<schisamo@chef.io>)
+# Copyright:: Copyright 2011-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,9 +16,9 @@
 # limitations under the License.
 #
 
-require 'spec_helper'
-require 'tiny_server'
-require 'support/shared/functional/http'
+require "spec_helper"
+require "tiny_server"
+require "support/shared/functional/http"
 
 describe Chef::Resource::RemoteFile do
   include ChefHTTPShared
@@ -55,19 +55,19 @@ describe Chef::Resource::RemoteFile do
   let(:default_mode) { (0666 & ~File.umask).to_s(8) }
 
   context "when fetching files over HTTP" do
-    before(:all) do
+    before(:each) do
       start_tiny_server
     end
 
-    after(:all) do
+    after(:each) do
       stop_tiny_server
     end
 
     describe "when redownload isn't necessary" do
-      let(:source) { 'http://localhost:9000/seattle_capo.png' }
+      let(:source) { "http://localhost:9000/seattle_capo.png" }
 
       before do
-        @api.get("/seattle_capo.png", 304, "", { 'Etag' => 'abcdef' } )
+        @api.get("/seattle_capo.png", 304, "", { "Etag" => "abcdef" } )
       end
 
       it "does not fetch the file" do
@@ -76,7 +76,7 @@ describe Chef::Resource::RemoteFile do
     end
 
     context "when using normal encoding" do
-      let(:source) { 'http://localhost:9000/nyan_cat.png' }
+      let(:source) { "http://localhost:9000/nyan_cat.png" }
       let(:expected_content) { binread(nyan_uncompressed_filename) }
 
       it_behaves_like "a file resource"
@@ -85,7 +85,7 @@ describe Chef::Resource::RemoteFile do
     end
 
     context "when using gzip encoding" do
-      let(:source) { 'http://localhost:9000/nyan_cat.png.gz' }
+      let(:source) { "http://localhost:9000/nyan_cat.png.gz" }
       let(:expected_content) { binread(nyan_compressed_filename) }
 
       it_behaves_like "a file resource"
@@ -97,7 +97,7 @@ describe Chef::Resource::RemoteFile do
 
   context "when fetching files over HTTPS" do
 
-    before(:all) do
+    before(:each) do
       cert_text = File.read(File.expand_path("ssl/chef-rspec.cert", CHEF_SPEC_DATA))
       cert = OpenSSL::X509::Certificate.new(cert_text)
       key_text = File.read(File.expand_path("ssl/chef-rspec.key", CHEF_SPEC_DATA))
@@ -111,11 +111,11 @@ describe Chef::Resource::RemoteFile do
       start_tiny_server(server_opts)
     end
 
-    after(:all) do
+    after(:each) do
       stop_tiny_server
     end
 
-    let(:source) { 'https://localhost:9000/nyan_cat.png' }
+    let(:source) { "https://localhost:9000/nyan_cat.png" }
 
     let(:expected_content) { binread(nyan_uncompressed_filename) }
 
@@ -124,17 +124,17 @@ describe Chef::Resource::RemoteFile do
   end
 
   context "when dealing with content length checking" do
-    before(:all) do
+    before(:each) do
       start_tiny_server
     end
 
-    after(:all) do
+    after(:each) do
       stop_tiny_server
     end
 
     context "when downloading compressed data" do
       let(:expected_content) { binread(nyan_uncompressed_filename) }
-      let(:source) { 'http://localhost:9000/nyan_cat_content_length_compressed.png' }
+      let(:source) { "http://localhost:9000/nyan_cat_content_length_compressed.png" }
 
       before do
         expect(File).not_to exist(path)
@@ -156,7 +156,7 @@ describe Chef::Resource::RemoteFile do
 
     context "when downloding uncompressed data" do
       let(:expected_content) { binread(nyan_uncompressed_filename) }
-      let(:source) { 'http://localhost:9000/nyan_cat_content_length.png' }
+      let(:source) { "http://localhost:9000/nyan_cat_content_length.png" }
 
       before do
         expect(File).not_to exist(path)
@@ -177,7 +177,7 @@ describe Chef::Resource::RemoteFile do
     end
 
     context "when downloading truncated compressed data" do
-      let(:source) { 'http://localhost:9000/nyan_cat_truncated_compressed.png' }
+      let(:source) { "http://localhost:9000/nyan_cat_truncated_compressed.png" }
 
       before do
         expect(File).not_to exist(path)
@@ -190,7 +190,7 @@ describe Chef::Resource::RemoteFile do
     end
 
     context "when downloding truncated uncompressed data" do
-      let(:source) { 'http://localhost:9000/nyan_cat_truncated.png' }
+      let(:source) { "http://localhost:9000/nyan_cat_truncated.png" }
 
       before do
         expect(File).not_to exist(path)
@@ -204,7 +204,7 @@ describe Chef::Resource::RemoteFile do
 
     context "when downloding data with transfer-encoding set" do
       let(:expected_content) { binread(nyan_uncompressed_filename) }
-      let(:source) { 'http://localhost:9000/nyan_cat_transfer_encoding.png' }
+      let(:source) { "http://localhost:9000/nyan_cat_transfer_encoding.png" }
 
       before do
         expect(File).not_to exist(path)
@@ -225,14 +225,23 @@ describe Chef::Resource::RemoteFile do
     end
 
     describe "when the download of the source raises an exception" do
-      let(:source) { 'http://localhost:0000/seattle_capo.png' }
+      let(:source) { "http://localhost:0000/seattle_capo.png" }
 
       before do
         expect(File).not_to exist(path)
       end
 
       it "should not create the file" do
-        expect{ resource.run_action(:create) }.to raise_error
+        # This can legitimately raise either Errno::EADDRNOTAVAIL or Errno::ECONNREFUSED
+        # in different Ruby versions.
+        old_value = RSpec::Expectations.configuration.on_potential_false_positives
+        RSpec::Expectations.configuration.on_potential_false_positives = :nothing
+        begin
+          expect { resource.run_action(:create) }.to raise_error
+        ensure
+          RSpec::Expectations.configuration.on_potential_false_positives = old_value
+        end
+
         expect(File).not_to exist(path)
       end
     end
