@@ -1,6 +1,6 @@
 #
 # Author:: Prabhu Das (<prabhu.das@clogeny.com>)
-# Copyright:: Copyright (c) 2013 Opscode, Inc.
+# Copyright:: Copyright 2013-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,12 +16,12 @@
 # limitations under the License.
 #
 
-require 'spec_helper'
-require 'functional/resource/base'
-require 'chef/mixin/shell_out'
+require "spec_helper"
+require "functional/resource/base"
+require "chef/mixin/shell_out"
 
 # run this test only for following platforms.
-exclude_test = !['aix', 'centos', 'redhat', 'suse'].include?(ohai[:platform])
+exclude_test = !%w{aix centos redhat suse}.include?(ohai[:platform])
 describe Chef::Resource::RpmPackage, :requires_root, :external => exclude_test do
   include Chef::Mixin::ShellOut
 
@@ -60,13 +60,13 @@ describe Chef::Resource::RpmPackage, :requires_root, :external => exclude_test d
     when "aix"
       @pkg_name = "dummy"
       @pkg_version = "1-0"
-      @pkg_path = "/tmp/dummy-1-0.aix6.1.noarch.rpm"
-      FileUtils.cp(File.join(CHEF_SPEC_ASSETS, 'dummy-1-0.aix6.1.noarch.rpm') , @pkg_path)
+      @pkg_path = "#{Dir.tmpdir}/dummy-1-0.aix6.1.noarch.rpm"
+      FileUtils.cp(File.join(CHEF_SPEC_ASSETS, "dummy-1-0.aix6.1.noarch.rpm") , @pkg_path)
     when "centos", "redhat", "suse"
       @pkg_name = "mytest"
       @pkg_version = "1.0-1"
-      @pkg_path = "/tmp/mytest-1.0-1.noarch.rpm"
-      FileUtils.cp(File.join(CHEF_SPEC_ASSETS, 'mytest-1.0-1.noarch.rpm') , @pkg_path)
+      @pkg_path = "#{Dir.tmpdir}/mytest-1.0-1.noarch.rpm"
+      FileUtils.cp(File.join(CHEF_SPEC_ASSETS, "mytest-1.0-1.noarch.rpm") , @pkg_path)
     end
   end
 
@@ -99,14 +99,14 @@ describe Chef::Resource::RpmPackage, :requires_root, :external => exclude_test d
   context "package upgrade action" do
     before(:each) do
       shell_out("rpm -i #{@pkg_path}")
-      if ohai[:platform] == 'aix'
+      if ohai[:platform] == "aix"
         @pkg_version = "2-0"
-        @pkg_path = "/tmp/dummy-2-0.aix6.1.noarch.rpm"
-        FileUtils.cp(File.join(CHEF_SPEC_ASSETS, 'dummy-2-0.aix6.1.noarch.rpm') , @pkg_path)
+        @pkg_path = "#{Dir.tmpdir}/dummy-2-0.aix6.1.noarch.rpm"
+        FileUtils.cp(File.join(CHEF_SPEC_ASSETS, "dummy-2-0.aix6.1.noarch.rpm") , @pkg_path)
       else
         @pkg_version = "2.0-1"
-        @pkg_path = "/tmp/mytest-2.0-1.noarch.rpm"
-        FileUtils.cp(File.join(CHEF_SPEC_ASSETS, 'mytest-2.0-1.noarch.rpm') , @pkg_path)
+        @pkg_path = "#{Dir.tmpdir}/mytest-2.0-1.noarch.rpm"
+        FileUtils.cp(File.join(CHEF_SPEC_ASSETS, "mytest-2.0-1.noarch.rpm") , @pkg_path)
       end
     end
 
