@@ -1,6 +1,6 @@
 #
-# Author:: Daniel DeLeo (<dan@opscode.com>)
-# Copyright:: Copyright (c) 2013 Opscode, Inc.
+# Author:: Daniel DeLeo (<dan@chef.io>)
+# Copyright:: Copyright 2013-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,14 +15,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-require 'support/shared/integration/integration_helper'
-require 'chef/mixin/shell_out'
+require "support/shared/integration/integration_helper"
+require "chef/mixin/shell_out"
 
 describe "chef-client" do
   include IntegrationSupport
   include Chef::Mixin::ShellOut
 
-  let(:chef_zero_opts) { {:host => "::1"} }
+  let(:chef_zero_opts) { { :host => "::1" } }
 
   let(:validation_pem) do
     <<-END_VALIDATION_PEM
@@ -73,10 +73,9 @@ END_CLIENT_RB
     basic_config_file
   end
 
-
   let(:chef_dir) { File.join(File.dirname(__FILE__), "..", "..", "..", "bin") }
 
-  let(:chef_client_cmd) { %Q[ruby '#{chef_dir}/chef-client' --minimal-ohai -c "#{path_to('config/client.rb')}" -lwarn] }
+  let(:chef_client_cmd) { %Q{ruby '#{chef_dir}/chef-client' --minimal-ohai -c "#{path_to('config/client.rb')}" -lwarn} }
 
   after do
     FileUtils.rm_rf(cache_path)
@@ -84,13 +83,13 @@ END_CLIENT_RB
 
   # Some Solaris test platforms are too old for IPv6. These tests should not
   # otherwise be platform dependent, so exclude solaris
-  when_the_chef_server "is running on IPv6", :not_supported_on_solaris do
+  when_the_chef_server "is running on IPv6", :not_supported_on_solaris, :not_supported_on_gce do
 
     when_the_repository "has a cookbook with a no-op recipe" do
       before do
-        cookbook 'noop', '1.0.0', { }, "recipes" => {"default.rb" => "#raise 'foo'"}
-        file 'config/client.rb', client_rb_content
-        file 'config/validator.pem', validation_pem
+        cookbook "noop", "1.0.0", {}, "recipes" => { "default.rb" => "#raise 'foo'" }
+        file "config/client.rb", client_rb_content
+        file "config/validator.pem", validation_pem
       end
 
       it "should complete with success" do
@@ -103,7 +102,7 @@ END_CLIENT_RB
     when_the_repository "has a cookbook that hits server APIs" do
 
       before do
-        recipe=<<-END_RECIPE
+        recipe = <<-END_RECIPE
           actual_item = data_bag_item("expect_bag", "expect_item")
           if actual_item.key?("expect_key") and actual_item["expect_key"] == "expect_value"
             Chef::Log.info "lookin good"
@@ -115,14 +114,14 @@ END_CLIENT_RB
 
         END_RECIPE
 
-        data_bag('expect_bag', { 'expect_item' => {"expect_key" => "expect_value"} })
+        data_bag("expect_bag", { "expect_item" => { "expect_key" => "expect_value" } })
 
-        cookbook 'api-smoke-test', '1.0.0', { }, "recipes" => {"default.rb" => recipe}
+        cookbook "api-smoke-test", "1.0.0", {}, "recipes" => { "default.rb" => recipe }
       end
 
       before do
-        file 'config/client.rb', client_rb_content
-        file 'config/validator.pem', validation_pem
+        file "config/client.rb", client_rb_content
+        file "config/validator.pem", validation_pem
       end
 
       it "should complete with success" do
