@@ -1,6 +1,6 @@
 #
-# Author:: John Keiser (<jkeiser@opscode.com>)
-# Copyright:: Copyright (c) 2013 Opscode, Inc.
+# Author:: John Keiser (<jkeiser@chef.io>)
+# Copyright:: Copyright 2013-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,15 +15,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-require 'support/shared/integration/integration_helper'
-require 'chef/knife/list'
-require 'chef/knife/show'
+require "support/shared/integration/integration_helper"
+require "chef/knife/list"
+require "chef/knife/show"
 
-describe 'General chef_repo file system checks', :workstation do
+describe "General chef_repo file system checks", :workstation do
   include IntegrationSupport
   include KnifeSupport
 
-  context 'directories and files that should/should not be ignored' do
+  context "directories and files that should/should not be ignored" do
     when_the_repository "has empty roles, environments and data bag item directories" do
       before do
         directory "roles"
@@ -32,7 +32,7 @@ describe 'General chef_repo file system checks', :workstation do
       end
 
       it "knife list --local -Rfp / returns them" do
-        knife('list --local -Rfp /').should_succeed <<EOM
+        knife("list --local -Rfp /").should_succeed <<EOM
 /data_bags/
 /data_bags/bag1/
 /environments/
@@ -45,25 +45,25 @@ EOM
       before { directory "data_bags" }
 
       it "knife list --local / returns it" do
-        knife('list --local /').should_succeed "/data_bags\n"
+        knife("list --local /").should_succeed "/data_bags\n"
       end
     end
 
     when_the_repository "has an empty cookbook directory" do
-      before { directory 'cookbooks/cookbook1' }
+      before { directory "cookbooks/cookbook1" }
 
       it "knife list --local -Rfp / does not return it" do
-        knife('list --local -Rfp /').should_succeed(<<EOM, :stderr => "WARN: Cookbook 'cookbook1' is empty or entirely chefignored at #{Chef::Config.chef_repo_path}/cookbooks/cookbook1\n")
+        knife("list --local -Rfp /").should_succeed(<<EOM, :stderr => "WARN: Cookbook 'cookbook1' is empty or entirely chefignored at #{Chef::Config.chef_repo_path}/cookbooks/cookbook1\n")
 /cookbooks/
 EOM
       end
     end
 
     when_the_repository "has only empty cookbook subdirectories" do
-      before { directory 'cookbooks/cookbook1/recipes' }
+      before { directory "cookbooks/cookbook1/recipes" }
 
       it "knife list --local -Rfp / does not return it" do
-        knife('list --local -Rfp /').should_succeed(<<EOM, :stderr => "WARN: Cookbook 'cookbook1' is empty or entirely chefignored at #{Chef::Config.chef_repo_path}/cookbooks/cookbook1\n")
+        knife("list --local -Rfp /").should_succeed(<<EOM, :stderr => "WARN: Cookbook 'cookbook1' is empty or entirely chefignored at #{Chef::Config.chef_repo_path}/cookbooks/cookbook1\n")
 /cookbooks/
 EOM
       end
@@ -71,12 +71,12 @@ EOM
 
     when_the_repository "has empty and non-empty cookbook subdirectories" do
       before do
-        directory 'cookbooks/cookbook1/recipes'
-        file 'cookbooks/cookbook1/templates/default/x.txt', ''
+        directory "cookbooks/cookbook1/recipes"
+        file "cookbooks/cookbook1/templates/default/x.txt", ""
       end
 
       it "knife list --local -Rfp / does not return the empty ones" do
-        knife('list --local -Rfp /').should_succeed <<EOM
+        knife("list --local -Rfp /").should_succeed <<EOM
 /cookbooks/
 /cookbooks/cookbook1/
 /cookbooks/cookbook1/templates/
@@ -87,10 +87,10 @@ EOM
     end
 
     when_the_repository "has only empty cookbook sub-sub-directories" do
-      before { directory 'cookbooks/cookbook1/templates/default' }
+      before { directory "cookbooks/cookbook1/templates/default" }
 
       it "knife list --local -Rfp / does not return it" do
-        knife('list --local -Rfp /').should_succeed(<<EOM, :stderr => "WARN: Cookbook 'cookbook1' is empty or entirely chefignored at #{Chef::Config.chef_repo_path}/cookbooks/cookbook1\n")
+        knife("list --local -Rfp /").should_succeed(<<EOM, :stderr => "WARN: Cookbook 'cookbook1' is empty or entirely chefignored at #{Chef::Config.chef_repo_path}/cookbooks/cookbook1\n")
 /cookbooks/
 EOM
       end
@@ -98,13 +98,13 @@ EOM
 
     when_the_repository "has empty cookbook sub-sub-directories alongside non-empty ones" do
       before do
-        file 'cookbooks/cookbook1/templates/default/x.txt', ''
-        directory 'cookbooks/cookbook1/templates/rhel'
-        directory 'cookbooks/cookbook1/files/default'
+        file "cookbooks/cookbook1/templates/default/x.txt", ""
+        directory "cookbooks/cookbook1/templates/rhel"
+        directory "cookbooks/cookbook1/files/default"
       end
 
       it "knife list --local -Rfp / does not return the empty ones" do
-        knife('list --local -Rfp /').should_succeed <<EOM
+        knife("list --local -Rfp /").should_succeed <<EOM
 /cookbooks/
 /cookbooks/cookbook1/
 /cookbooks/cookbook1/templates/
@@ -122,7 +122,7 @@ EOM
       end
 
       it "knife list --local -Rfp / should NOT return it" do
-        knife('list --local -Rfp /').should_succeed ""
+        knife("list --local -Rfp /").should_succeed ""
       end
     end
 
@@ -146,7 +146,7 @@ EOM
       end
 
       it "knife list --local -Rfp / should NOT return them" do
-        knife('list --local -Rfp /').should_succeed <<EOM
+        knife("list --local -Rfp /").should_succeed <<EOM
 /data_bags/
 /data_bags/bag1/
 /data_bags/bag1/item1.json
@@ -160,62 +160,62 @@ EOM
 
     when_the_repository "has extraneous subdirectories and files under a cookbook" do
       before do
-        directory 'cookbooks/cookbook1' do
-          file 'a.rb', ''
-          file 'blarghle/blah.rb', ''
-          directory 'attributes' do
-            file 'a.rb', ''
-            file 'b.json', {}
-            file 'c/d.rb', ''
-            file 'c/e.json', {}
+        directory "cookbooks/cookbook1" do
+          file "a.rb", ""
+          file "blarghle/blah.rb", ""
+          directory "attributes" do
+            file "a.rb", ""
+            file "b.json", {}
+            file "c/d.rb", ""
+            file "c/e.json", {}
           end
-          directory 'definitions' do
-            file 'a.rb', ''
-            file 'b.json', {}
-            file 'c/d.rb', ''
-            file 'c/e.json', {}
+          directory "definitions" do
+            file "a.rb", ""
+            file "b.json", {}
+            file "c/d.rb", ""
+            file "c/e.json", {}
           end
-          directory 'recipes' do
-            file 'a.rb', ''
-            file 'b.json', {}
-            file 'c/d.rb', ''
-            file 'c/e.json', {}
+          directory "recipes" do
+            file "a.rb", ""
+            file "b.json", {}
+            file "c/d.rb", ""
+            file "c/e.json", {}
           end
-          directory 'libraries' do
-            file 'a.rb', ''
-            file 'b.json', {}
-            file 'c/d.rb', ''
-            file 'c/e.json', {}
+          directory "libraries" do
+            file "a.rb", ""
+            file "b.json", {}
+            file "c/d.rb", ""
+            file "c/e.json", {}
           end
-          directory 'templates' do
-            file 'a.rb', ''
-            file 'b.json', {}
-            file 'c/d.rb', ''
-            file 'c/e.json', {}
+          directory "templates" do
+            file "a.rb", ""
+            file "b.json", {}
+            file "c/d.rb", ""
+            file "c/e.json", {}
           end
-          directory 'files' do
-            file 'a.rb', ''
-            file 'b.json', {}
-            file 'c/d.rb', ''
-            file 'c/e.json', {}
+          directory "files" do
+            file "a.rb", ""
+            file "b.json", {}
+            file "c/d.rb", ""
+            file "c/e.json", {}
           end
-          directory 'resources' do
-            file 'a.rb', ''
-            file 'b.json', {}
-            file 'c/d.rb', ''
-            file 'c/e.json', {}
+          directory "resources" do
+            file "a.rb", ""
+            file "b.json", {}
+            file "c/d.rb", ""
+            file "c/e.json", {}
           end
-          directory 'providers' do
-            file 'a.rb', ''
-            file 'b.json', {}
-            file 'c/d.rb', ''
-            file 'c/e.json', {}
+          directory "providers" do
+            file "a.rb", ""
+            file "b.json", {}
+            file "c/d.rb", ""
+            file "c/e.json", {}
           end
         end
       end
 
       it "knife list --local -Rfp / should NOT return them" do
-        knife('list --local -Rfp /').should_succeed <<EOM
+        knife("list --local -Rfp /").should_succeed <<EOM
 /cookbooks/
 /cookbooks/cookbook1/
 /cookbooks/cookbook1/a.rb
@@ -231,6 +231,10 @@ EOM
 /cookbooks/cookbook1/files/c/e.json
 /cookbooks/cookbook1/libraries/
 /cookbooks/cookbook1/libraries/a.rb
+/cookbooks/cookbook1/libraries/b.json
+/cookbooks/cookbook1/libraries/c/
+/cookbooks/cookbook1/libraries/c/d.rb
+/cookbooks/cookbook1/libraries/c/e.json
 /cookbooks/cookbook1/providers/
 /cookbooks/cookbook1/providers/a.rb
 /cookbooks/cookbook1/providers/c/
@@ -252,41 +256,41 @@ EOM
     end
 
     when_the_repository "has a file in cookbooks/" do
-      before { file 'cookbooks/file', '' }
-      it 'does not show up in list -Rfp' do
-        knife('list --local -Rfp /').should_succeed <<EOM
+      before { file "cookbooks/file", "" }
+      it "does not show up in list -Rfp" do
+        knife("list --local -Rfp /").should_succeed <<EOM
 /cookbooks/
 EOM
       end
     end
 
     when_the_repository "has a file in data_bags/" do
-      before { file 'data_bags/file', '' }
-      it 'does not show up in list -Rfp' do
-        knife('list --local -Rfp /').should_succeed <<EOM
+      before { file "data_bags/file", "" }
+      it "does not show up in list -Rfp" do
+        knife("list --local -Rfp /").should_succeed <<EOM
 /data_bags/
 EOM
       end
     end
   end
 
-  when_the_repository 'has a cookbook starting with .' do
+  when_the_repository "has a cookbook starting with ." do
     before do
-      file 'cookbooks/.svn/metadata.rb', ''
-      file 'cookbooks/a.b/metadata.rb', ''
+      file "cookbooks/.svn/metadata.rb", ""
+      file "cookbooks/a.b/metadata.rb", ""
     end
-    it 'knife list does not show it' do
-      knife('list --local -fp /cookbooks').should_succeed "/cookbooks/a.b/\n"
+    it "knife list does not show it" do
+      knife("list --local -fp /cookbooks").should_succeed "/cookbooks/a.b/\n"
     end
   end
 
-  when_the_repository 'has a data bag starting with .' do
+  when_the_repository "has a data bag starting with ." do
     before do
-      file 'data_bags/.svn/x.json', {}
-      file 'data_bags/a.b/x.json', {}
+      file "data_bags/.svn/x.json", {}
+      file "data_bags/a.b/x.json", {}
     end
-    it 'knife list does not show it' do
-      knife('list --local -fp /data_bags').should_succeed "/data_bags/a.b/\n"
+    it "knife list does not show it" do
+      knife("list --local -fp /data_bags").should_succeed "/data_bags/a.b/\n"
     end
   end
 end
