@@ -1,6 +1,6 @@
 #
-# Author:: Seth Chisamore (<schisamo@opscode.com>)
-# Copyright:: Copyright (c) 2011 Opscode, Inc.
+# Author:: Seth Chisamore (<schisamo@chef.io>)
+# Copyright:: Copyright 2011-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,22 +16,22 @@
 # limitations under the License.
 #
 
-require 'spec_helper'
+require "spec_helper"
 
 if windows?
-  require 'chef/win32/security'
-  require 'tmpdir'
-  require 'fileutils'
+  require "chef/win32/security"
+  require "tmpdir"
+  require "fileutils"
 end
 
-describe 'Chef::ReservedNames::Win32::Security', :windows_only do
+describe "Chef::ReservedNames::Win32::Security", :windows_only do
 
   def monkeyfoo
-    File.join(CHEF_SPEC_DATA, "monkeyfoo").gsub("/", "\\")
+    File.join(CHEF_SPEC_DATA, "monkeyfoo").tr("/", "\\")
   end
 
   before :all do
-    @test_tempdir = File.join(Dir::tmpdir, "cheftests", "chef_win32_security")
+    @test_tempdir = File.join(Dir.tmpdir, "cheftests", "chef_win32_security")
     FileUtils.mkdir_p(@test_tempdir)
     @monkeyfoo = File.join(@test_tempdir, "monkeyfoo.txt")
   end
@@ -49,21 +49,21 @@ describe 'Chef::ReservedNames::Win32::Security', :windows_only do
   end
 
   it "should not leak when retrieving and reading the ACE from a file", :volatile do
-    expect {
+    expect do
       sids = Chef::ReservedNames::Win32::Security::SecurableObject.new(@monkeyfoo).security_descriptor.dacl.select { |ace| ace.sid }
       GC.start
-    }.not_to leak_memory(:warmup => 50, :iterations => 100)
+    end.not_to leak_memory(:warmup => 50, :iterations => 100)
   end
 
   it "should not leak when creating a new ACL and setting it on a file", :volatile do
     securable_object = Security::SecurableObject.new(@monkeyfoo)
-    expect {
+    expect do
       securable_object.dacl = Chef::ReservedNames::Win32::Security::ACL.create([
         Chef::ReservedNames::Win32::Security::ACE.access_allowed(Chef::ReservedNames::Win32::Security::SID.Everyone, Chef::ReservedNames::Win32::API::Security::GENERIC_READ),
-        Chef::ReservedNames::Win32::Security::ACE.access_denied(Chef::ReservedNames::Win32::Security::SID.from_account("Users"), Chef::ReservedNames::Win32::API::Security::GENERIC_ALL)
+        Chef::ReservedNames::Win32::Security::ACE.access_denied(Chef::ReservedNames::Win32::Security::SID.from_account("Users"), Chef::ReservedNames::Win32::API::Security::GENERIC_ALL),
       ])
       GC.start
-    }.not_to leak_memory(:warmup => 50, :iterations => 100)
+    end.not_to leak_memory(:warmup => 50, :iterations => 100)
   end
 
 end
