@@ -1,6 +1,6 @@
 #
 # Author:: John Hampton (<john@cleanoffer.com>)
-# Copyright:: Copyright (c) 2009 CleanOffer, Inc.
+# Copyright:: Copyright 2009-2016, CleanOffer, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -19,19 +19,15 @@
 class Chef
   class Resource
     class OneTwoThreeFour < Chef::Resource
-      attr_reader :i_can_count
 
-      def initialize(name, run_context)
-        @resource_name = :one_two_three_four
-        super
-      end
+      attr_reader :i_can_count
 
       def i_can_count(tf)
         @i_can_count = tf
       end
 
-      def something(arg=nil)
-        if arg == true or arg == false
+      def something(arg = nil)
+        if arg == true || arg == false
           @something = arg
         end
         @something
