@@ -1,5 +1,5 @@
 
-require 'functional/resource/base'
+require "functional/resource/base"
 
 ALL_EXPANDED_PERMISSIONS = ["generic read",
                             "generic write",
@@ -21,7 +21,6 @@ ALL_EXPANDED_PERMISSIONS = ["generic read",
                             "read attributes",
                             "write attributes"]
 
-
 shared_examples_for "a securable resource with reporting" do
 
   include_context "diff disabled"
@@ -76,9 +75,9 @@ shared_examples_for "a securable resource with reporting" do
         # TODO/bug: duplicated from the "securable resource" tests
 
         if ohai[:platform] == "aix"
-          let(:expected_user_name) { 'guest' }
+          let(:expected_user_name) { "guest" }
         else
-          let(:expected_user_name) { 'nobody' }
+          let(:expected_user_name) { "nobody" }
         end
 
         before do
@@ -96,9 +95,9 @@ shared_examples_for "a securable resource with reporting" do
 
         # TODO: duplicated from "securable resource"
         if ohai[:platform] == "aix"
-          let(:expected_user_name) { 'guest' }
+          let(:expected_user_name) { "guest" }
         else
-          let(:expected_user_name) { 'nobody' }
+          let(:expected_user_name) { "nobody" }
         end
         let(:expected_uid) { Etc.getpwnam(expected_user_name).uid }
         let(:desired_gid) { 1337 }
@@ -273,37 +272,35 @@ shared_examples_for "a securable resource with reporting" do
       # Windows reporting data should look like this (+/- ish):
       # { "owner" => "bob", "checksum" => "ffff", "access control" => { "bob" => { "permissions" => ["perm1", "perm2", ...], "flags" => [] }}}
 
-
       before do
         resource.action(:create)
       end
 
       it "has empty values for file metadata in 'current_resource'" do
-        pending "windows reporting not yet fully supported"
+        skip "windows reporting not yet fully supported"
         expect(current_resource.owner).to be_nil
         expect(current_resource.expanded_rights).to be_nil
       end
 
       context "and no security metadata is specified in new_resource" do
         before do
-          pending "windows reporting not yet fully supported"
+          skip "windows reporting not yet fully supported"
         end
 
         it "sets the metadata values on the new_resource as strings after creating" do
           resource.run_action(:create)
           # TODO: most stable way to specify?
           expect(resource.owner).to eq(etc.getpwuid(process.uid).name)
-          expect(resource.state[:expanded_rights]).to eq({ "CURRENTUSER" => { "permissions" => ALL_EXPANDED_PERMISSIONS, "flags" => [] }})
+          expect(resource.state[:expanded_rights]).to eq({ "CURRENTUSER" => { "permissions" => ALL_EXPANDED_PERMISSIONS, "flags" => [] } })
           expect(resource.state[:expanded_deny_rights]).to eq({})
           expect(resource.state[:inherits]).to be_truthy
         end
       end
 
-
-      context "and owner is specified with a string (username) in new_resource"  do
+      context "and owner is specified with a string (username) in new_resource" do
 
         # TODO/bug: duplicated from the "securable resource" tests
-        let(:expected_user_name) { 'Guest' }
+        let(:expected_user_name) { "Guest" }
 
         before do
           resource.owner(expected_user_name)
@@ -322,7 +319,7 @@ shared_examples_for "a securable resource with reporting" do
         let(:expected_user_name) { 'domain\user' }
 
         before do
-          pending "windows reporting not yet fully supported"
+          skip "windows reporting not yet fully supported"
           resource.owner(expected_user_name)
           resource.run_action(:create)
         end
@@ -336,7 +333,7 @@ shared_examples_for "a securable resource with reporting" do
 
     context "when the target file exists" do
       before do
-        pending "windows reporting not yet fully supported"
+        skip "windows reporting not yet fully supported"
         FileUtils.touch(resource.path)
         resource.action(:create)
       end
@@ -392,7 +389,6 @@ shared_examples_for "a securable resource with reporting" do
         end
       end
 
-
     end
   end
 end
