@@ -1,7 +1,7 @@
 #
-# Author:: Seth Falcon (<seth@opscode.com>)
-# Author:: Daniel DeLeo (<dan@opscode.com>)
-# Copyright:: Copyright (c) 2010, 2012 Opscode, Inc.
+# Author:: Seth Falcon (<seth@chef.io>)
+# Author:: Daniel DeLeo (<dan@chef.io>)
+# Copyright:: Copyright 2010-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,28 +17,28 @@
 # limitations under the License.
 #
 
-
 shared_examples_for "a platform introspector" do
   before(:each) do
     @platform_hash = {}
     %w{openbsd freebsd}.each do |x|
       @platform_hash[x] = {
         "default" => x,
-        "1.2.3" => "#{x}-1.2.3"
+        "1.2.3" => "#{x}-1.2.3",
       }
     end
-    @platform_hash["debian"] = {["5", "6"] => "debian-5/6", "default" => "debian"}
+    @platform_hash["debian"] = { %w{5 6} => "debian-5/6", "default" => "debian" }
     @platform_hash["default"] = "default"
     # The following @platform_hash keys are used for testing version constraints
-    @platform_hash['exact_match'] = { '1.2.3' => 'exact', '>= 1.0' => 'not exact'}
-    @platform_hash['multiple_matches'] = { '~> 2.3.4' => 'matched ~> 2.3.4', '>= 2.3' => 'matched >=2.3' }
-    @platform_hash['successful_matches'] = { '< 3.0' => 'matched < 3.0', '>= 3.0' => 'matched >= 3.0' }
+    @platform_hash["exact_match"] = { "1.2.3" => "exact", ">= 1.0" => "not exact" }
+    @platform_hash["multiple_matches"] = { "~> 2.3.4" => "matched ~> 2.3.4", ">= 2.3" => "matched >=2.3" }
+    @platform_hash["invalid_cookbook_version"] = { ">= 21" => "Matches a single number" }
+    @platform_hash["successful_matches"] = { "< 3.0" => "matched < 3.0", ">= 3.0" => "matched >= 3.0" }
 
     @platform_family_hash = {
       "debian" => "debian value",
       [:rhel, :fedora] => "redhatty value",
       "suse" => "suse value",
-      :default => "default value"
+      :default => "default value",
     }
   end
 
@@ -83,22 +83,28 @@ shared_examples_for "a platform introspector" do
     expect(platform_introspector.value_for_platform(@platform_hash)).to eq("openbsd")
   end
 
-  it 'returns the exact match' do
-    node.automatic_attrs[:platform] = 'exact_match'
-    node.automatic_attrs[:platform_version] = '1.2.3'
-    expect(platform_introspector.value_for_platform(@platform_hash)).to eq('exact')
+  it "returns the exact match" do
+    node.automatic_attrs[:platform] = "exact_match"
+    node.automatic_attrs[:platform_version] = "1.2.3"
+    expect(platform_introspector.value_for_platform(@platform_hash)).to eq("exact")
   end
 
-  it 'raises RuntimeError' do
-    node.automatic_attrs[:platform] = 'multiple_matches'
-    node.automatic_attrs[:platform_version] = '2.3.4'
-    expect {platform_introspector.value_for_platform(@platform_hash)}.to raise_error(RuntimeError)
+  it "raises RuntimeError" do
+    node.automatic_attrs[:platform] = "multiple_matches"
+    node.automatic_attrs[:platform_version] = "2.3.4"
+    expect { platform_introspector.value_for_platform(@platform_hash) }.to raise_error(RuntimeError)
   end
 
-  it 'should return the value for that match' do
-    node.automatic_attrs[:platform] = 'successful_matches'
-    node.automatic_attrs[:platform_version] = '2.9'
-    expect(platform_introspector.value_for_platform(@platform_hash)).to eq('matched < 3.0')
+  it "should not require .0 to match >= 21.0" do
+    node.automatic_attrs[:platform] = "invalid_cookbook_version"
+    node.automatic_attrs[:platform_version] = "21"
+    expect(platform_introspector.value_for_platform(@platform_hash)).to eq("Matches a single number")
+  end
+
+  it "should return the value for that match" do
+    node.automatic_attrs[:platform] = "successful_matches"
+    node.automatic_attrs[:platform_version] = "2.9"
+    expect(platform_introspector.value_for_platform(@platform_hash)).to eq("matched < 3.0")
   end
 
   describe "when platform versions is an array" do
@@ -118,17 +124,17 @@ shared_examples_for "a platform introspector" do
   describe "when checking platform?" do
 
     it "returns true if the node is a provided platform and platforms are provided as symbols" do
-      node.automatic_attrs[:platform] = 'ubuntu'
+      node.automatic_attrs[:platform] = "ubuntu"
       expect(platform_introspector.platform?([:redhat, :ubuntu])).to eq(true)
     end
 
     it "returns true if the node is a provided platform and platforms are provided as strings" do
-      node.automatic_attrs[:platform] = 'ubuntu'
-      expect(platform_introspector.platform?(["redhat", "ubuntu"])).to eq(true)
+      node.automatic_attrs[:platform] = "ubuntu"
+      expect(platform_introspector.platform?(%w{redhat ubuntu})).to eq(true)
     end
 
     it "returns false if the node is not of the provided platforms" do
-      node.automatic_attrs[:platform] = 'ubuntu'
+      node.automatic_attrs[:platform] = "ubuntu"
       expect(platform_introspector.platform?(:splatlinux)).to eq(false)
     end
   end
@@ -136,17 +142,17 @@ shared_examples_for "a platform introspector" do
   describe "when checking platform_family?" do
 
     it "returns true if the node is in a provided platform family and families are provided as symbols" do
-      node.automatic_attrs[:platform_family] = 'debian'
+      node.automatic_attrs[:platform_family] = "debian"
       expect(platform_introspector.platform_family?([:rhel, :debian])).to eq(true)
     end
 
     it "returns true if the node is a provided platform and platforms are provided as strings" do
-      node.automatic_attrs[:platform_family] = 'rhel'
-      expect(platform_introspector.platform_family?(["rhel", "debian"])).to eq(true)
+      node.automatic_attrs[:platform_family] = "rhel"
+      expect(platform_introspector.platform_family?(%w{rhel debian})).to eq(true)
     end
 
     it "returns false if the node is not of the provided platforms" do
-      node.automatic_attrs[:platform_family] = 'suse'
+      node.automatic_attrs[:platform_family] = "suse"
       expect(platform_introspector.platform_family?(:splatlinux)).to eq(false)
     end
 
@@ -164,21 +170,20 @@ shared_examples_for "a platform introspector" do
         "centos" => { "default" => [ :restart, :reload, :status ] },
         "redhat" => { "default" => [ :restart, :reload, :status ] },
         "fedora" => { "default" => [ :restart, :reload, :status ] },
-        "default" => { "default" => [:restart, :reload ] }}
+        "default" => { "default" => [:restart, :reload ] } }
     end
 
     it "returns the correct default for a given platform" do
       node.automatic_attrs[:platform] = "debian"
-      node.automatic_attrs[:platform_version] = '9000'
+      node.automatic_attrs[:platform_version] = "9000"
       expect(platform_introspector.value_for_platform(@platform_hash)).to eq([ :restart, :reload, :status ])
     end
 
     it "returns the correct platform+version specific value " do
       node.automatic_attrs[:platform] = "debian"
-      node.automatic_attrs[:platform_version] = '4.0'
+      node.automatic_attrs[:platform_version] = "4.0"
       expect(platform_introspector.value_for_platform(@platform_hash)).to eq([:restart, :reload])
     end
   end
 
 end
-
