@@ -1,6 +1,6 @@
 #
-# Author:: John Keiser (<jkeiser@opscode.com>)
-# Copyright:: Copyright (c) 2012 Opscode, Inc.
+# Author:: John Keiser (<jkeiser@chef.io>)
+# Copyright:: Copyright 2012-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,31 +16,31 @@
 # limitations under the License.
 #
 
-require 'spec_helper'
-require 'chef/chef_fs/file_system/operation_failed_error'
+require "spec_helper"
+require "chef/chef_fs/file_system/operation_failed_error"
 
 describe Chef::ChefFS::FileSystem::OperationFailedError do
-  context 'message' do
+  context "message" do
     let(:error_message) { 'HTTP error writing: 400 "Bad Request"' }
 
-    context 'has a cause attribute and HTTP result code is 400' do
-      it 'include error cause' do
+    context "has a cause attribute and HTTP result code is 400" do
+      it "include error cause" do
         allow_message_expectations_on_nil
         response_body = '{"error":["Invalid key test in request body"]}'
         allow(@response).to receive(:code).and_return("400")
         allow(@response).to receive(:body).and_return(response_body)
         exception = Net::HTTPServerException.new("(exception) unauthorized", @response)
-        expect {
+        expect do
           raise Chef::ChefFS::FileSystem::OperationFailedError.new(:write, self, exception), error_message
-        }.to raise_error(Chef::ChefFS::FileSystem::OperationFailedError, "#{error_message} cause: #{response_body}")
+        end.to raise_error(Chef::ChefFS::FileSystem::OperationFailedError, "#{error_message} cause: #{response_body}")
       end
     end
 
-    context 'does not have a cause attribute' do
-      it 'does not include error cause' do
-        expect {
+    context "does not have a cause attribute" do
+      it "does not include error cause" do
+        expect do
           raise Chef::ChefFS::FileSystem::OperationFailedError.new(:write, self), error_message
-        }.to raise_error(Chef::ChefFS::FileSystem::OperationFailedError, error_message)
+        end.to raise_error(Chef::ChefFS::FileSystem::OperationFailedError, error_message)
       end
     end
   end
