@@ -1,7 +1,7 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Author:: Seth Falcon (<seth@opscode.com>)
-# Copyright:: Copyright 2008-2010 Opscode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Author:: Seth Falcon (<seth@chef.io>)
+# Copyright:: Copyright 2008-2016, Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,8 +17,8 @@
 # limitations under the License.
 #
 
-require 'spec_helper'
-require 'chef/cookbook/metadata'
+require "spec_helper"
+require "chef/cookbook/metadata"
 
 describe Chef::Cookbook::Metadata do
 
@@ -30,7 +30,8 @@ describe Chef::Cookbook::Metadata do
                   :maintainer_email, :license, :platforms, :dependencies,
                   :recommendations, :suggestions, :conflicting, :providing,
                   :replacing, :attributes, :groupings, :recipes, :version,
-                  :source_url, :issues_url ]
+                  :source_url, :issues_url, :privacy, :ohai_versions, :chef_versions,
+                  :gems ]
     end
 
     it "does not depend on object identity for equality" do
@@ -142,11 +143,15 @@ describe Chef::Cookbook::Metadata do
     end
 
     it "has an empty source_url string" do
-      expect(metadata.source_url).to eq('')
+      expect(metadata.source_url).to eq("")
     end
 
     it "has an empty issues_url string" do
-      expect(metadata.issues_url).to eq('')
+      expect(metadata.issues_url).to eq("")
+    end
+
+    it "is not private" do
+      expect(metadata.privacy).to eq(false)
     end
   end
 
@@ -185,7 +190,7 @@ describe Chef::Cookbook::Metadata do
   describe "adding a supported platform" do
     it "should support adding a supported platform with a single expression" do
       metadata.supports("ubuntu", ">= 8.04")
-      expect(metadata.platforms["ubuntu"]).to eq('>= 8.04')
+      expect(metadata.platforms["ubuntu"]).to eq(">= 8.04")
     end
   end
 
@@ -198,9 +203,10 @@ describe Chef::Cookbook::Metadata do
       :long_description => "Much Longer\nSeriously",
       :version => "0.6.0",
       :source_url => "http://example.com",
-      :issues_url => "http://example.com/issues"
+      :issues_url => "http://example.com/issues",
+      :privacy => true,
     }
-    params.sort { |a,b| a.to_s <=> b.to_s }.each do |field, field_value|
+    params.sort { |a, b| a.to_s <=> b.to_s }.each do |field, field_value|
       describe field do
         it "should be set-able via #{field}" do
           expect(metadata.send(field, field_value)).to eql(field_value)
@@ -234,7 +240,7 @@ describe Chef::Cookbook::Metadata do
       :provides    => [ :providing, "foo::bar", "<= 0.2" ],
       :replaces    => [ :replacing, "foo::bar", "= 0.2.1" ],
     }
-    dep_types.sort { |a,b| a.to_s <=> b.to_s }.each do |dep, dep_args|
+    dep_types.sort { |a, b| a.to_s <=> b.to_s }.each do |dep, dep_args|
       check_with = dep_args.shift
       describe dep do
         it "should be set-able via #{dep}" do
@@ -255,7 +261,7 @@ describe Chef::Cookbook::Metadata do
       :provides    => [ :providing, "foo::bar", "<=0.2", "<= 0.2" ],
       :replaces    => [ :replacing, "foo::bar", "=0.2.1", "= 0.2.1" ],
     }
-    dep_types.sort { |a,b| a.to_s <=> b.to_s }.each do |dep, dep_args|
+    dep_types.sort { |a, b| a.to_s <=> b.to_s }.each do |dep, dep_args|
       check_with = dep_args.shift
       normalized_version = dep_args.pop
       describe dep do
@@ -269,7 +275,6 @@ describe Chef::Cookbook::Metadata do
       end
     end
 
-
     describe "in the obsoleted format" do
       dep_types = {
         :depends     => [ "foo::bar", "> 0.2", "< 1.0" ],
@@ -282,12 +287,11 @@ describe Chef::Cookbook::Metadata do
 
       dep_types.each do |dep, dep_args|
         it "for #{dep} raises an informative error instead of vomiting on your shoes" do
-          expect {metadata.send(dep, *dep_args)}.to raise_error(Chef::Exceptions::ObsoleteDependencySyntax)
+          expect { metadata.send(dep, *dep_args) }.to raise_error(Chef::Exceptions::ObsoleteDependencySyntax)
         end
       end
     end
 
-
     describe "with obsolete operators" do
       dep_types = {
         :depends     => [ "foo::bar", ">> 0.2"],
@@ -300,36 +304,178 @@ describe Chef::Cookbook::Metadata do
 
       dep_types.each do |dep, dep_args|
         it "for #{dep} raises an informative error instead of vomiting on your shoes" do
-          expect {metadata.send(dep, *dep_args)}.to raise_error(Chef::Exceptions::InvalidVersionConstraint)
+          expect { metadata.send(dep, *dep_args) }.to raise_error(Chef::Exceptions::InvalidVersionConstraint)
         end
       end
     end
+
+    it "strips out self-dependencies", chef: "< 13" do
+      metadata.name("foo")
+      expect(Chef::Log).to receive(:warn).with(
+        "Ignoring self-dependency in cookbook foo, please remove it (in the future this will be fatal)."
+      )
+      metadata.depends("foo")
+      expect(metadata.dependencies).to eql({})
+    end
+
+    it "errors on self-dependencies", chef: ">= 13" do
+      metadata.name("foo")
+      expect { metadata.depends("foo") }.to raise_error
+      # FIXME: add the error type
+    end
+  end
+
+  describe "chef_version" do
+    def expect_chef_version_works(*args)
+      ret = []
+      args.each do |arg|
+        metadata.send(:chef_version, *arg)
+        ret << Gem::Dependency.new("chef", *arg)
+      end
+      expect(metadata.send(:chef_versions)).to eql(ret)
+    end
+
+    it "should work with a single simple constraint" do
+      expect_chef_version_works(["~> 12"])
+    end
+
+    it "should work with a single complex constraint" do
+      expect_chef_version_works([">= 12.0.1", "< 12.5.1"])
+    end
+
+    it "should work with multiple simple constraints" do
+      expect_chef_version_works(["~> 12.5.1"], ["~> 11.18.10"])
+    end
+
+    it "should work with multiple complex constraints" do
+      expect_chef_version_works([">= 11.14.2", "< 11.18.10"], [">= 12.2.1", "< 12.5.1"])
+    end
+
+    it "should fail validation on a simple pessimistic constraint" do
+      expect_chef_version_works(["~> 999.0"])
+      expect { metadata.validate_chef_version! }.to raise_error(Chef::Exceptions::CookbookChefVersionMismatch)
+    end
+
+    it "should fail validation when that valid chef versions are too big" do
+      expect_chef_version_works([">= 999.0", "< 999.9"])
+      expect { metadata.validate_chef_version! }.to raise_error(Chef::Exceptions::CookbookChefVersionMismatch)
+    end
+
+    it "should fail validation when that valid chef versions are too small" do
+      expect_chef_version_works([">= 0.0.1", "< 0.0.9"])
+      expect { metadata.validate_chef_version! }.to raise_error(Chef::Exceptions::CookbookChefVersionMismatch)
+    end
+
+    it "should fail validation when all ranges fail" do
+      expect_chef_version_works([">= 999.0", "< 999.9"], [">= 0.0.1", "< 0.0.9"])
+      expect { metadata.validate_chef_version! }.to raise_error(Chef::Exceptions::CookbookChefVersionMismatch)
+    end
+
+    it "should pass validation when one constraint passes" do
+      expect_chef_version_works([">= 999.0", "< 999.9"], ["= #{Chef::VERSION}"])
+      expect { metadata.validate_chef_version! }.not_to raise_error
+    end
+  end
+
+  describe "ohai_version" do
+    def expect_ohai_version_works(*args)
+      ret = []
+      args.each do |arg|
+        metadata.send(:ohai_version, *arg)
+        ret << Gem::Dependency.new("ohai", *arg)
+      end
+      expect(metadata.send(:ohai_versions)).to eql(ret)
+    end
+
+    it "should work with a single simple constraint" do
+      expect_ohai_version_works(["~> 12"])
+    end
+
+    it "should work with a single complex constraint" do
+      expect_ohai_version_works([">= 12.0.1", "< 12.5.1"])
+    end
+
+    it "should work with multiple simple constraints" do
+      expect_ohai_version_works(["~> 12.5.1"], ["~> 11.18.10"])
+    end
+
+    it "should work with multiple complex constraints" do
+      expect_ohai_version_works([">= 11.14.2", "< 11.18.10"], [">= 12.2.1", "< 12.5.1"])
+    end
+
+    it "should fail validation on a simple pessimistic constraint" do
+      expect_ohai_version_works(["~> 999.0"])
+      expect { metadata.validate_ohai_version! }.to raise_error(Chef::Exceptions::CookbookOhaiVersionMismatch)
+    end
+
+    it "should fail validation when that valid chef versions are too big" do
+      expect_ohai_version_works([">= 999.0", "< 999.9"])
+      expect { metadata.validate_ohai_version! }.to raise_error(Chef::Exceptions::CookbookOhaiVersionMismatch)
+    end
+
+    it "should fail validation when that valid chef versions are too small" do
+      expect_ohai_version_works([">= 0.0.1", "< 0.0.9"])
+      expect { metadata.validate_ohai_version! }.to raise_error(Chef::Exceptions::CookbookOhaiVersionMismatch)
+    end
+
+    it "should fail validation when all ranges fail" do
+      expect_ohai_version_works([">= 999.0", "< 999.9"], [">= 0.0.1", "< 0.0.9"])
+      expect { metadata.validate_ohai_version! }.to raise_error(Chef::Exceptions::CookbookOhaiVersionMismatch)
+    end
+
+    it "should pass validation when one constraint passes" do
+      expect_ohai_version_works([">= 999.0", "< 999.9"], ["= #{Ohai::VERSION}"])
+      expect { metadata.validate_ohai_version! }.not_to raise_error
+    end
+  end
+
+  describe "gem" do
+    def expect_gem_works(*args)
+      ret = []
+      args.each do |arg|
+        metadata.send(:gem, *arg)
+        ret << arg
+      end
+      expect(metadata.send(:gems)).to eql(ret)
+    end
+
+    it "works on a simple case" do
+      expect_gem_works(["foo", "~> 1.2"])
+    end
+
+    it "works if there's two gems" do
+      expect_gem_works(["foo", "~> 1.2"], ["bar", "~> 2.0"])
+    end
+
+    it "works if there's a more complicated constraint" do
+      expect_gem_works(["foo", "~> 1.2"], ["bar", ">= 2.4", "< 4.0"])
+    end
   end
 
   describe "attribute groupings" do
     it "should allow you set a grouping" do
       group = {
         "title" => "MySQL Tuning",
-        "description" => "Setting from the my.cnf file that allow you to tune your mysql server"
+        "description" => "Setting from the my.cnf file that allow you to tune your mysql server",
       }
       expect(metadata.grouping("/db/mysql/databases/tuning", group)).to eq(group)
     end
     it "should not accept anything but a string for display_name" do
-      expect {
+      expect do
         metadata.grouping("db/mysql/databases", :title => "foo")
-      }.not_to raise_error
-      expect {
+      end.not_to raise_error
+      expect do
         metadata.grouping("db/mysql/databases", :title => Hash.new)
-      }.to raise_error(ArgumentError)
+      end.to raise_error(ArgumentError)
     end
 
     it "should not accept anything but a string for the description" do
-      expect {
+      expect do
         metadata.grouping("db/mysql/databases", :description => "foo")
-      }.not_to raise_error
-      expect {
+      end.not_to raise_error
+      expect do
         metadata.grouping("db/mysql/databases", :description => Hash.new)
-      }.to raise_error(ArgumentError)
+      end.to raise_error(ArgumentError)
     end
   end
 
@@ -338,64 +484,77 @@ describe Chef::Cookbook::Metadata do
       attrs = {
         "display_name" => "MySQL Databases",
         "description" => "Description of MySQL",
-        "choice" => ['dedicated', 'shared'],
+        "choice" => %w{dedicated shared},
         "calculated" => false,
-        "type" => 'string',
-        "required" => 'recommended',
+        "type" => "string",
+        "required" => "recommended",
         "recipes" => [ "mysql::server", "mysql::master" ],
         "default" => [ ],
         "source_url" => "http://example.com",
-        "issues_url" => "http://example.com/issues"
+        "issues_url" => "http://example.com/issues",
+        "privacy" => true,
       }
       expect(metadata.attribute("/db/mysql/databases", attrs)).to eq(attrs)
     end
 
     it "should not accept anything but a string for display_name" do
-      expect {
+      expect do
         metadata.attribute("db/mysql/databases", :display_name => "foo")
-      }.not_to raise_error
-      expect {
+      end.not_to raise_error
+      expect do
         metadata.attribute("db/mysql/databases", :display_name => Hash.new)
-      }.to raise_error(ArgumentError)
+      end.to raise_error(ArgumentError)
     end
 
     it "should not accept anything but a string for the description" do
-      expect {
+      expect do
         metadata.attribute("db/mysql/databases", :description => "foo")
-      }.not_to raise_error
-      expect {
+      end.not_to raise_error
+      expect do
         metadata.attribute("db/mysql/databases", :description => Hash.new)
-      }.to raise_error(ArgumentError)
+      end.to raise_error(ArgumentError)
     end
 
     it "should not accept anything but a string for the source_url" do
-      expect {
+      expect do
         metadata.attribute("db/mysql/databases", :source_url => "foo")
-      }.not_to raise_error
-      expect {
+      end.not_to raise_error
+      expect do
         metadata.attribute("db/mysql/databases", :source_url => Hash.new)
-      }.to raise_error(ArgumentError)
+      end.to raise_error(ArgumentError)
     end
 
     it "should not accept anything but a string for the issues_url" do
-      expect {
+      expect do
         metadata.attribute("db/mysql/databases", :issues_url => "foo")
-      }.not_to raise_error
-      expect {
+      end.not_to raise_error
+      expect do
         metadata.attribute("db/mysql/databases", :issues_url => Hash.new)
-      }.to raise_error(ArgumentError)
+      end.to raise_error(ArgumentError)
+    end
+
+    it "should not accept anything but true or false for the privacy flag" do
+      expect do
+        metadata.attribute("db/mysql/databases", :privacy => true)
+      end.not_to raise_error
+      expect do
+        metadata.attribute("db/mysql/databases", :privacy => false)
+      end.not_to raise_error
+      expect do
+        metadata.attribute("db/mysql/databases", :privacy => "true")
+      end.to raise_error(ArgumentError)
     end
 
     it "should not accept anything but an array of strings for choice" do
-      expect {
-        metadata.attribute("db/mysql/databases", :choice => ['dedicated', 'shared'])
-      }.not_to raise_error
-      expect {
-        metadata.attribute("db/mysql/databases", :choice => [10, 'shared'])
-      }.to raise_error(ArgumentError)
-      expect {
+      expect do
+        metadata.attribute("db/mysql/databases", :choice => %w{dedicated shared})
+      end.not_to raise_error
+      expect do
+        metadata.attribute("db/mysql/databases", :choice => [10, "shared"])
+      end.to raise_error(ArgumentError)
+      expect do
         metadata.attribute("db/mysql/databases", :choice => Hash.new)
-      }.to raise_error(ArgumentError)
+      end.to raise_error(ArgumentError)
     end
 
     it "should set choice to empty array by default" do
@@ -403,88 +562,88 @@ describe Chef::Cookbook::Metadata do
       expect(metadata.attributes["db/mysql/databases"][:choice]).to eq([])
     end
 
-     it "should let calculated be true or false" do
-       expect {
-         metadata.attribute("db/mysql/databases", :calculated => true)
-       }.not_to raise_error
-       expect {
-         metadata.attribute("db/mysql/databases", :calculated => false)
-       }.not_to raise_error
-       expect {
-         metadata.attribute("db/mysql/databases", :calculated => Hash.new)
-       }.to raise_error(ArgumentError)
-     end
+    it "should let calculated be true or false" do
+      expect do
+        metadata.attribute("db/mysql/databases", :calculated => true)
+      end.not_to raise_error
+      expect do
+        metadata.attribute("db/mysql/databases", :calculated => false)
+      end.not_to raise_error
+      expect do
+        metadata.attribute("db/mysql/databases", :calculated => Hash.new)
+      end.to raise_error(ArgumentError)
+    end
 
-     it "should set calculated to false by default" do
-       metadata.attribute("db/mysql/databases", {})
-       expect(metadata.attributes["db/mysql/databases"][:calculated]).to eq(false)
-     end
+    it "should set calculated to false by default" do
+      metadata.attribute("db/mysql/databases", {})
+      expect(metadata.attributes["db/mysql/databases"][:calculated]).to eq(false)
+    end
 
     it "accepts String for the attribute type" do
-      expect {
+      expect do
         metadata.attribute("db/mysql/databases", :type => "string")
-      }.not_to raise_error
+      end.not_to raise_error
     end
 
     it "accepts Array for the attribute type" do
-      expect {
+      expect do
         metadata.attribute("db/mysql/databases", :type => "array")
-      }.not_to raise_error
-      expect {
+      end.not_to raise_error
+      expect do
         metadata.attribute("db/mysql/databases", :type => Array.new)
-      }.to raise_error(ArgumentError)
+      end.to raise_error(ArgumentError)
     end
 
     it "accepts symbol for the attribute type" do
-      expect {
+      expect do
         metadata.attribute("db/mysql/databases", :type => "symbol")
-      }.not_to raise_error
+      end.not_to raise_error
     end
 
-     it "should let type be hash (backwards compatibility only)" do
-      expect {
+    it "should let type be hash (backwards compatibility only)" do
+      expect do
         metadata.attribute("db/mysql/databases", :type => "hash")
-      }.not_to raise_error
+      end.not_to raise_error
     end
 
     it "should let required be required, recommended or optional" do
-      expect {
-        metadata.attribute("db/mysql/databases", :required => 'required')
-      }.not_to raise_error
-      expect {
-        metadata.attribute("db/mysql/databases", :required => 'recommended')
-      }.not_to raise_error
-      expect {
-        metadata.attribute("db/mysql/databases", :required => 'optional')
-      }.not_to raise_error
+      expect do
+        metadata.attribute("db/mysql/databases", :required => "required")
+      end.not_to raise_error
+      expect do
+        metadata.attribute("db/mysql/databases", :required => "recommended")
+      end.not_to raise_error
+      expect do
+        metadata.attribute("db/mysql/databases", :required => "optional")
+      end.not_to raise_error
     end
 
     it "should convert required true to required" do
-      expect {
+      expect do
         metadata.attribute("db/mysql/databases", :required => true)
-      }.not_to raise_error
+      end.not_to raise_error
       #attrib = metadata.attributes["db/mysql/databases"][:required].should == "required"
     end
 
     it "should convert required false to optional" do
-      expect {
+      expect do
         metadata.attribute("db/mysql/databases", :required => false)
-      }.not_to raise_error
+      end.not_to raise_error
       #attrib = metadata.attributes["db/mysql/databases"][:required].should == "optional"
     end
 
     it "should set required to 'optional' by default" do
       metadata.attribute("db/mysql/databases", {})
-      expect(metadata.attributes["db/mysql/databases"][:required]).to eq('optional')
+      expect(metadata.attributes["db/mysql/databases"][:required]).to eq("optional")
     end
 
     it "should make sure recipes is an array" do
-      expect {
+      expect do
         metadata.attribute("db/mysql/databases", :recipes => [])
-      }.not_to raise_error
-      expect {
+      end.not_to raise_error
+      expect do
         metadata.attribute("db/mysql/databases", :required => Hash.new)
-      }.to raise_error(ArgumentError)
+      end.to raise_error(ArgumentError)
     end
 
     it "should set recipes to an empty array by default" do
@@ -493,119 +652,119 @@ describe Chef::Cookbook::Metadata do
     end
 
     it "should allow the default value to be a string, array, hash, boolean or numeric" do
-      expect {
+      expect do
         metadata.attribute("db/mysql/databases", :default => [])
-      }.not_to raise_error
-      expect {
+      end.not_to raise_error
+      expect do
         metadata.attribute("db/mysql/databases", :default => {})
-      }.not_to raise_error
-      expect {
+      end.not_to raise_error
+      expect do
         metadata.attribute("db/mysql/databases", :default => "alice in chains")
-      }.not_to raise_error
-      expect {
+      end.not_to raise_error
+      expect do
         metadata.attribute("db/mysql/databases", :default => 1337)
-      }.not_to raise_error
-      expect {
+      end.not_to raise_error
+      expect do
         metadata.attribute("db/mysql/databases", :default => true)
-      }.not_to raise_error
-      expect {
+      end.not_to raise_error
+      expect do
         metadata.attribute("db/mysql/databases", :required => :not_gonna_do_it)
-      }.to raise_error(ArgumentError)
+      end.to raise_error(ArgumentError)
     end
 
     it "should limit the types allowed in the choice array" do
       options = {
         :type => "string",
-        :choice => [ "test1", "test2" ],
-        :default => "test1"
+        :choice => %w{test1 test2},
+        :default => "test1",
       }
-      expect {
+      expect do
         metadata.attribute("test_cookbook/test", options)
-      }.not_to raise_error
+      end.not_to raise_error
 
       options = {
         :type => "boolean",
         :choice => [ true, false ],
-        :default => true
+        :default => true,
       }
-      expect {
+      expect do
         metadata.attribute("test_cookbook/test", options)
-      }.not_to raise_error
+      end.not_to raise_error
 
       options = {
         :type => "numeric",
         :choice => [ 1337, 420 ],
-        :default => 1337
+        :default => 1337,
       }
-      expect {
+      expect do
         metadata.attribute("test_cookbook/test", options)
-      }.not_to raise_error
+      end.not_to raise_error
 
       options = {
         :type => "numeric",
         :choice => [ true, "false" ],
-        :default => false
+        :default => false,
       }
-      expect {
+      expect do
         metadata.attribute("test_cookbook/test", options)
-      }.to raise_error
+      end.to raise_error(Chef::Exceptions::ValidationFailed)
     end
 
     it "should error if default used with calculated" do
-      expect {
+      expect do
         attrs = {
           :calculated => true,
-          :default => [ "I thought you said calculated" ]
+          :default => [ "I thought you said calculated" ],
         }
         metadata.attribute("db/mysql/databases", attrs)
-      }.to raise_error(ArgumentError)
-      expect {
+      end.to raise_error(ArgumentError)
+      expect do
         attrs = {
           :calculated => true,
-          :default => "I thought you said calculated"
+          :default => "I thought you said calculated",
         }
         metadata.attribute("db/mysql/databases", attrs)
-      }.to raise_error(ArgumentError)
+      end.to raise_error(ArgumentError)
     end
 
     it "should allow a default that is a choice" do
-      expect {
+      expect do
         attrs = {
-          :choice => [ "a", "b", "c"],
-          :default => "b"
+          :choice => %w{a b c},
+          :default => "b",
         }
         metadata.attribute("db/mysql/databases", attrs)
-      }.not_to raise_error
-      expect {
+      end.not_to raise_error
+      expect do
         attrs = {
-          :choice => [ "a", "b", "c", "d", "e"],
-          :default => ["b", "d"]
+          :choice => %w{a b c d e},
+          :default => %w{b d},
         }
         metadata.attribute("db/mysql/databases", attrs)
-      }.not_to raise_error
-     end
+      end.not_to raise_error
+    end
 
     it "should error if default is not a choice" do
-      expect {
+      expect do
         attrs = {
-          :choice => [ "a", "b", "c"],
-          :default => "d"
+          :choice => %w{a b c},
+          :default => "d",
         }
         metadata.attribute("db/mysql/databases", attrs)
-      }.to raise_error(ArgumentError)
-      expect {
+      end.to raise_error(ArgumentError)
+      expect do
         attrs = {
-          :choice => [ "a", "b", "c", "d", "e"],
-          :default => ["b", "z"]
+          :choice => %w{a b c d e},
+          :default => %w{b z},
         }
         metadata.attribute("db/mysql/databases", attrs)
-      }.to raise_error(ArgumentError)
+      end.to raise_error(ArgumentError)
     end
   end
 
   describe "recipes" do
     let(:cookbook) do
-      c = Chef::CookbookVersion.new('test_cookbook')
+      c = Chef::CookbookVersion.new("test_cookbook")
       c.recipe_files = [ "default.rb", "enlighten.rb" ]
       c
     end
@@ -651,9 +810,16 @@ describe Chef::Cookbook::Metadata do
       metadata.attribute "bizspark/has_login",
         :display_name => "You have nothing"
       metadata.version "1.2.3"
+      metadata.gem "foo", "~> 1.2"
+      metadata.gem "bar", ">= 2.2", "< 4.0"
+      metadata.chef_version ">= 11.14.2", "< 11.18.10"
+      metadata.chef_version ">= 12.2.1", "< 12.5.1"
+      metadata.ohai_version ">= 7.1.0", "< 7.5.0"
+      metadata.ohai_version ">= 8.0.1", "< 8.6.0"
     end
 
     it "should produce the same output from to_json and Chef::JSONCompat" do
+      # XXX: fairly certain this is testing ruby method dispatch
       expect(metadata.to_json).to eq(Chef::JSONCompat.to_json(metadata))
     end
 
@@ -684,18 +850,28 @@ describe Chef::Cookbook::Metadata do
         version
         source_url
         issues_url
+        privacy
+        gems
       }.each do |t|
         it "should include '#{t}'" do
           expect(deserialized_metadata[t]).to eq(metadata.send(t.to_sym))
         end
       end
+
+      %w{
+        ohai_versions
+        chef_versions
+      }.each do |t|
+        it "should include '#{t}'" do
+          expect(deserialized_metadata[t]).to eq(metadata.gem_requirements_to_array(*metadata.send(t.to_sym)))
+        end
+      end
     end
 
     describe "deserialize" do
 
       let(:deserialized_metadata) { Chef::Cookbook::Metadata.from_json(Chef::JSONCompat.to_json(metadata)) }
 
-
       it "should deserialize to a Chef::Cookbook::Metadata object" do
         expect(deserialized_metadata).to be_a_kind_of(Chef::Cookbook::Metadata)
       end
@@ -719,6 +895,10 @@ describe Chef::Cookbook::Metadata do
         version
         source_url
         issues_url
+        privacy
+        chef_versions
+        ohai_versions
+        gems
       }.each do |t|
         it "should match '#{t}'" do
           expect(deserialized_metadata.send(t.to_sym)).to eq(metadata.send(t.to_sym))
@@ -736,31 +916,31 @@ describe Chef::Cookbook::Metadata do
        :suggestions,
        :conflicting,
        :replacing].each do |to_check|
-        it "should transform deprecated greater than syntax for :#{to_check.to_s}" do
+        it "should transform deprecated greater than syntax for :#{to_check}" do
           @hash[to_check.to_s]["foo::bar"] = ">> 0.2"
           deserial = Chef::Cookbook::Metadata.from_hash(@hash)
-          expect(deserial.send(to_check)["foo::bar"]).to eq('> 0.2')
+          expect(deserial.send(to_check)["foo::bar"]).to eq("> 0.2")
         end
 
-        it "should transform deprecated less than syntax for :#{to_check.to_s}" do
+        it "should transform deprecated less than syntax for :#{to_check}" do
           @hash[to_check.to_s]["foo::bar"] = "<< 0.2"
           deserial = Chef::Cookbook::Metadata.from_hash(@hash)
-          expect(deserial.send(to_check)["foo::bar"]).to eq('< 0.2')
+          expect(deserial.send(to_check)["foo::bar"]).to eq("< 0.2")
         end
 
-        it "should ignore multiple dependency constraints for :#{to_check.to_s}" do
+        it "should ignore multiple dependency constraints for :#{to_check}" do
           @hash[to_check.to_s]["foo::bar"] = [ ">= 1.0", "<= 5.2" ]
           deserial = Chef::Cookbook::Metadata.from_hash(@hash)
           expect(deserial.send(to_check)["foo::bar"]).to eq([])
         end
 
-        it "should accept an empty array of dependency constraints for :#{to_check.to_s}" do
+        it "should accept an empty array of dependency constraints for :#{to_check}" do
           @hash[to_check.to_s]["foo::bar"] = []
           deserial = Chef::Cookbook::Metadata.from_hash(@hash)
           expect(deserial.send(to_check)["foo::bar"]).to eq([])
         end
 
-        it "should accept single-element arrays of dependency constraints for :#{to_check.to_s}" do
+        it "should accept single-element arrays of dependency constraints for :#{to_check}" do
           @hash[to_check.to_s]["foo::bar"] = [ ">= 2.0" ]
           deserial = Chef::Cookbook::Metadata.from_hash(@hash)
           expect(deserial.send(to_check)["foo::bar"]).to eq(">= 2.0")
