@@ -1,6 +1,6 @@
-require 'spec_helper'
-require 'chef/cookbook/synchronizer'
-require 'chef/cookbook_version'
+require "spec_helper"
+require "chef/cookbook/synchronizer"
+require "chef/cookbook_version"
 
 describe Chef::CookbookCacheCleaner do
   describe "when cleaning up unused cookbook components" do
@@ -38,7 +38,6 @@ describe Chef::CookbookCacheCleaner do
       unused_template_files.each do |cbf|
         expect(file_cache).to receive(:delete).with(cbf)
       end
-      cookbook_hash = {"valid1"=> {}, "valid2" => {}}
       allow(cleaner).to receive(:cache).and_return(file_cache)
       cleaner.cleanup_file_cache
     end
@@ -51,7 +50,7 @@ describe Chef::CookbookCacheCleaner do
     end
 
     it "does not remove anything on chef-solo" do
-      Chef::Config[:solo] = true
+      Chef::Config[:solo_legacy_mode] = true
       allow(cleaner.cache).to receive(:find).and_return(%w{cookbooks/valid1/recipes/default.rb cookbooks/valid2/recipes/default.rb})
       expect(cleaner.cache).not_to receive(:delete)
       cleaner.cleanup_file_cache
@@ -94,7 +93,7 @@ describe Chef::CookbookSynchronizer do
 
   let(:cookbook_a_manifest) do
     segments = [ :resources, :providers, :recipes, :definitions, :libraries, :attributes, :files, :templates, :root_files ]
-    cookbook_a_manifest = segments.inject({}) {|h, segment| h[segment.to_s] = []; h}
+    cookbook_a_manifest = segments.inject({}) { |h, segment| h[segment.to_s] = []; h }
     cookbook_a_manifest["recipes"] = [ cookbook_a_default_recipe ]
     cookbook_a_manifest["attributes"] = [ cookbook_a_default_attrs ]
     cookbook_a_manifest["templates"] = [ cookbook_a_template ]
@@ -110,7 +109,7 @@ describe Chef::CookbookSynchronizer do
 
   let(:cookbook_manifest) do
     {
-      "cookbook_a" => cookbook_a
+      "cookbook_a" => cookbook_a,
     }
   end
 
@@ -124,7 +123,7 @@ describe Chef::CookbookSynchronizer do
   end
 
   it "lists the cookbook names" do
-    expect(synchronizer.cookbook_names).to eq(%w[cookbook_a])
+    expect(synchronizer.cookbook_names).to eq(%w{cookbook_a})
   end
 
   it "lists the cookbook manifests" do
@@ -158,15 +157,15 @@ describe Chef::CookbookSynchronizer do
     let(:file_cache) { double("Chef::FileCache with files from unused cookbooks") }
 
     let(:cookbook_manifest) do
-      {"valid1"=> {}, "valid2" => {}}
+      { "valid1" => {}, "valid2" => {} }
     end
 
     it "removes unneeded cookbooks" do
       valid_cached_cb_files = %w{cookbooks/valid1/recipes/default.rb cookbooks/valid2/recipes/default.rb}
       obsolete_cb_files = %w{cookbooks/old1/recipes/default.rb cookbooks/old2/recipes/default.rb}
       expect(file_cache).to receive(:find).with(File.join(%w{cookbooks ** {*,.*}})).and_return(valid_cached_cb_files + obsolete_cb_files)
-      expect(file_cache).to receive(:delete).with('cookbooks/old1/recipes/default.rb')
-      expect(file_cache).to receive(:delete).with('cookbooks/old2/recipes/default.rb')
+      expect(file_cache).to receive(:delete).with("cookbooks/old1/recipes/default.rb")
+      expect(file_cache).to receive(:delete).with("cookbooks/old2/recipes/default.rb")
       allow(synchronizer).to receive(:cache).and_return(file_cache)
       synchronizer.remove_old_cookbooks
     end
@@ -176,7 +175,7 @@ describe Chef::CookbookSynchronizer do
     let(:file_cache) { double("Chef::FileCache with files from unused cookbooks") }
 
     let(:cookbook_manifest) do
-      {"valid1"=> {}, "valid2" => {}}
+      { "valid1" => {}, "valid2" => {} }
     end
 
     it "removes only deleted files" do
@@ -187,7 +186,7 @@ describe Chef::CookbookSynchronizer do
       expect(synchronizer).to receive(:have_cookbook?).with("valid1").at_least(:once).and_return(true)
       # valid2 is a cookbook not in our run_list (we're simulating an override run_list where valid2 needs to be preserved)
       expect(synchronizer).to receive(:have_cookbook?).with("valid2").at_least(:once).and_return(false)
-      expect(file_cache).to receive(:delete).with('cookbooks/valid1/recipes/deleted.rb')
+      expect(file_cache).to receive(:delete).with("cookbooks/valid1/recipes/deleted.rb")
       expect(synchronizer).to receive(:cookbook_segment).with("valid1", "recipes").at_least(:once).and_return([ { "path" => "recipes/default.rb" }])
       allow(synchronizer).to receive(:cache).and_return(file_cache)
       synchronizer.remove_deleted_files
@@ -224,8 +223,8 @@ describe Chef::CookbookSynchronizer do
       and_return(false)
 
     # Fetch and copy default.rb recipe
-    expect(server_api).to receive(:get_rest).
-      with('http://chef.example.com/abc123', true).
+    expect(server_api).to receive(:streaming_request).
+      with("http://chef.example.com/abc123").
       and_return(cookbook_a_default_recipe_tempfile)
     expect(file_cache).to receive(:move_to).
       with("/tmp/cookbook_a_recipes_default_rb", "cookbooks/cookbook_a/recipes/default.rb")
@@ -234,8 +233,8 @@ describe Chef::CookbookSynchronizer do
       and_return("/file-cache/cookbooks/cookbook_a/recipes/default.rb")
 
     # Fetch and copy default.rb attribute file
-    expect(server_api).to receive(:get_rest).
-      with('http://chef.example.com/abc456', true).
+    expect(server_api).to receive(:streaming_request).
+      with("http://chef.example.com/abc456").
       and_return(cookbook_a_default_attribute_tempfile)
     expect(file_cache).to receive(:move_to).
       with("/tmp/cookbook_a_attributes_default_rb", "cookbooks/cookbook_a/attributes/default.rb")
@@ -252,8 +251,8 @@ describe Chef::CookbookSynchronizer do
       with("cookbooks/cookbook_a/templates/default/apache2.conf.erb").
       and_return(false)
 
-    expect(server_api).to receive(:get_rest).
-      with('http://chef.example.com/megaman.conf', true).
+    expect(server_api).to receive(:streaming_request).
+      with("http://chef.example.com/megaman.conf").
       and_return(cookbook_a_file_default_tempfile)
     expect(file_cache).to receive(:move_to).
       with("/tmp/cookbook_a_file_default_tempfile", "cookbooks/cookbook_a/files/default/megaman.conf")
@@ -261,8 +260,8 @@ describe Chef::CookbookSynchronizer do
       with("cookbooks/cookbook_a/files/default/megaman.conf", false).
       and_return("/file-cache/cookbooks/cookbook_a/default/megaman.conf")
 
-    expect(server_api).to receive(:get_rest).
-      with('http://chef.example.com/ffffff', true).
+    expect(server_api).to receive(:streaming_request).
+      with("http://chef.example.com/ffffff").
       and_return(cookbook_a_template_default_tempfile)
     expect(file_cache).to receive(:move_to).
       with("/tmp/cookbook_a_template_default_tempfile", "cookbooks/cookbook_a/templates/default/apache2.conf.erb")
@@ -281,8 +280,8 @@ describe Chef::CookbookSynchronizer do
       and_return(true)
 
     # Fetch and copy default.rb recipe
-    expect(server_api).to receive(:get_rest).
-      with('http://chef.example.com/abc123', true).
+    expect(server_api).to receive(:streaming_request).
+      with("http://chef.example.com/abc123").
       and_return(cookbook_a_default_recipe_tempfile)
     expect(file_cache).to receive(:move_to).
       with("/tmp/cookbook_a_recipes_default_rb", "cookbooks/cookbook_a/recipes/default.rb")
@@ -297,8 +296,8 @@ describe Chef::CookbookSynchronizer do
       and_return("fff000")
 
     # Fetch and copy default.rb attribute file
-    expect(server_api).to receive(:get_rest).
-      with('http://chef.example.com/abc456', true).
+    expect(server_api).to receive(:streaming_request).
+      with("http://chef.example.com/abc456").
       and_return(cookbook_a_default_attribute_tempfile)
     expect(file_cache).to receive(:move_to).
       with("/tmp/cookbook_a_attributes_default_rb", "cookbooks/cookbook_a/attributes/default.rb")
@@ -323,8 +322,8 @@ describe Chef::CookbookSynchronizer do
       and_return(true)
 
     # Fetch and copy megaman.conf
-    expect(server_api).to receive(:get_rest).
-      with('http://chef.example.com/megaman.conf', true).
+    expect(server_api).to receive(:streaming_request).
+      with("http://chef.example.com/megaman.conf").
       and_return(cookbook_a_file_default_tempfile)
     expect(file_cache).to receive(:move_to).
       with("/tmp/cookbook_a_file_default_tempfile", "cookbooks/cookbook_a/files/default/megaman.conf")
@@ -334,8 +333,8 @@ describe Chef::CookbookSynchronizer do
       and_return("/file-cache/cookbooks/cookbook_a/default/megaman.conf")
 
     # Fetch and copy apache2.conf template
-    expect(server_api).to receive(:get_rest).
-      with('http://chef.example.com/ffffff', true).
+    expect(server_api).to receive(:streaming_request).
+      with("http://chef.example.com/ffffff").
       and_return(cookbook_a_template_default_tempfile)
     expect(file_cache).to receive(:move_to).
       with("/tmp/cookbook_a_template_default_tempfile", "cookbooks/cookbook_a/templates/default/apache2.conf.erb")
@@ -415,8 +414,15 @@ describe Chef::CookbookSynchronizer do
       and_return("/file-cache/cookbooks/cookbook_a/templates/default/apache2.conf.erb")
   end
 
+  describe "#server_api" do
+    it "sets keepalive to true" do
+      expect(Chef::ServerAPI).to receive(:new).with(Chef::Config[:chef_server_url], keepalives: true)
+      synchronizer.server_api
+    end
+  end
+
   describe "when syncing cookbooks with the server" do
-    let(:server_api) { double("Chef::REST (mock)") }
+    let(:server_api) { double("Chef::ServerAPI (mock)") }
 
     let(:file_cache) { double("Chef::FileCache (mock)") }
 
@@ -442,8 +448,8 @@ describe Chef::CookbookSynchronizer do
 
         it "does not fetch templates or cookbook files" do
           # Implicitly tested in previous test; this test is just for behavior specification.
-          expect(server_api).not_to receive(:get_rest).
-            with('http://chef.example.com/ffffff', true)
+          expect(server_api).not_to receive(:streaming_request).
+            with("http://chef.example.com/ffffff")
 
           synchronizer.sync_cookbooks
         end
@@ -502,7 +508,7 @@ describe Chef::CookbookSynchronizer do
 
         it "does not update files" do
           expect(file_cache).not_to receive(:move_to)
-          expect(server_api).not_to receive(:get_rest)
+          expect(server_api).not_to receive(:streaming_request)
           synchronizer.sync_cookbooks
         end
       end
@@ -512,7 +518,7 @@ describe Chef::CookbookSynchronizer do
 
         it "does not update files" do
           expect(file_cache).not_to receive(:move_to)
-          expect(server_api).not_to receive(:get_rest)
+          expect(server_api).not_to receive(:streaming_request)
           synchronizer.sync_cookbooks
         end
       end
