@@ -1,6 +1,6 @@
 #
-# Author:: Seth Falcon (<seth@opscode.com>)
-# Copyright:: Copyright (c) 2010 Opscode, Inc.
+# Author:: Seth Falcon (<seth@chef.io>)
+# Copyright:: Copyright 2010-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,8 +16,8 @@
 # limitations under the License.
 #
 
-require 'spec_helper'
-require 'chef/dsl/platform_introspection'
+require "spec_helper"
+require "chef/dsl/platform_introspection"
 
 class LanguageTester
   attr_reader :node
@@ -39,16 +39,16 @@ end
 describe Chef::DSL::PlatformIntrospection::PlatformDependentValue do
   before do
     platform_hash = {
-      :openbsd => {:default => 'free, functional, secure'},
-      [:redhat, :centos, :fedora, :scientific] => {:default => '"stable"'},
-      :ubuntu => {'10.04' => 'using upstart more', :default => 'using init more'},
-      :default => 'bork da bork'
+      :openbsd => { :default => "free, functional, secure" },
+      [:redhat, :centos, :fedora, :scientific] => { :default => '"stable"' },
+      :ubuntu => { "10.04" => "using upstart more", :default => "using init more" },
+      :default => "bork da bork",
     }
     @platform_specific_value = Chef::DSL::PlatformIntrospection::PlatformDependentValue.new(platform_hash)
   end
 
   it "returns the default value when the platform doesn't match" do
-    expect(@platform_specific_value.value_for_node(:platform => :dos)).to eq('bork da bork')
+    expect(@platform_specific_value.value_for_node(:platform => :dos)).to eq("bork da bork")
   end
 
   it "returns a value for a platform set as a group" do
@@ -60,25 +60,25 @@ describe Chef::DSL::PlatformIntrospection::PlatformDependentValue do
   end
 
   it "returns a value for a specific platform version" do
-    node = {:platform => 'ubuntu', :platform_version => '10.04'}
-    expect(@platform_specific_value.value_for_node(node)).to eq('using upstart more')
+    node = { :platform => "ubuntu", :platform_version => "10.04" }
+    expect(@platform_specific_value.value_for_node(node)).to eq("using upstart more")
   end
 
   it "returns a platform-default value if the platform version doesn't match an explicit one" do
-    node = {:platform => 'ubuntu', :platform_version => '9.10' }
-    expect(@platform_specific_value.value_for_node(node)).to eq('using init more')
+    node = { :platform => "ubuntu", :platform_version => "9.10" }
+    expect(@platform_specific_value.value_for_node(node)).to eq("using init more")
   end
 
   it "returns nil if there is no default and no platforms match" do
     # this matches the behavior in the original implementation.
     # whether or not it's correct is another matter.
     platform_specific_value = Chef::DSL::PlatformIntrospection::PlatformDependentValue.new({})
-    expect(platform_specific_value.value_for_node(:platform => 'foo')).to be_nil
+    expect(platform_specific_value.value_for_node(:platform => "foo")).to be_nil
   end
 
   it "raises an argument error if the platform hash is not correctly structured" do
-    bad_hash = {:ubuntu => :foo} # should be :ubuntu => {:default => 'foo'}
-    expect {Chef::DSL::PlatformIntrospection::PlatformDependentValue.new(bad_hash)}.to raise_error(ArgumentError)
+    bad_hash = { :ubuntu => :foo } # should be :ubuntu => {:default => 'foo'}
+    expect { Chef::DSL::PlatformIntrospection::PlatformDependentValue.new(bad_hash) }.to raise_error(ArgumentError)
   end
 
 end
@@ -91,17 +91,16 @@ describe Chef::DSL::PlatformIntrospection::PlatformFamilyDependentValue do
       [:rhel, "fedora"] => "redhatty value",
       "suse" => @array_values,
       :gentoo => "gentoo value",
-      :default => "default value"
+      :default => "default value",
     }
 
     @platform_family_value = Chef::DSL::PlatformIntrospection::PlatformFamilyDependentValue.new(@platform_family_hash)
   end
 
   it "returns the default value when the platform family doesn't match" do
-    expect(@platform_family_value.value_for_node(:platform_family => :os2)).to eq('default value')
+    expect(@platform_family_value.value_for_node(:platform_family => :os2)).to eq("default value")
   end
 
-
   it "returns a value for the platform family when it was set as a string but fetched as a symbol" do
     expect(@platform_family_value.value_for_node(:platform_family => :debian)).to eq("debian value")
   end
@@ -124,7 +123,7 @@ describe Chef::DSL::PlatformIntrospection::PlatformFamilyDependentValue do
 
   it "returns nil if there is no default and no platforms match" do
     platform_specific_value = Chef::DSL::PlatformIntrospection::PlatformFamilyDependentValue.new({})
-    expect(platform_specific_value.value_for_node(:platform_family => 'foo')).to be_nil
+    expect(platform_specific_value.value_for_node(:platform_family => "foo")).to be_nil
   end
 
 end
