@@ -1,6 +1,6 @@
 #
 # Author:: Dreamcat4 (<dreamcat4@gmail.com>)
-# Copyright:: Copyright (c) 2009 OpsCode, Inc.
+# Copyright:: Copyright 2009-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,59 +16,60 @@
 # limitations under the License.
 #
 
-ShellCmdResult = Struct.new(:stdout, :stderr, :exitstatus)
-
-require 'spec_helper'
-require 'ostruct'
-require 'mixlib/shellout'
+require "spec_helper"
+require "ostruct"
+require "mixlib/shellout"
 
 describe Chef::Provider::User::Dscl do
   before do
-    allow(Chef::Platform).to receive(:windows?) { false }
+    allow(ChefConfig).to receive(:windows?) { false }
   end
-  let(:node) {
+  let(:shellcmdresult) do
+    Struct.new(:stdout, :stderr, :exitstatus)
+  end
+  let(:node) do
     node = Chef::Node.new
     allow(node).to receive(:[]).with(:platform_version).and_return(mac_version)
     allow(node).to receive(:[]).with(:platform).and_return("mac_os_x")
     node
-  }
+  end
 
-  let(:events) {
+  let(:events) do
     Chef::EventDispatch::Dispatcher.new
-  }
+  end
 
-  let(:run_context) {
+  let(:run_context) do
     Chef::RunContext.new(node, {}, events)
-  }
+  end
 
-  let(:new_resource) {
-    r = Chef::Resource::User.new("toor")
+  let(:new_resource) do
+    r = Chef::Resource::User::DsclUser.new("toor")
     r.password(password)
     r.salt(salt)
     r.iterations(iterations)
     r
-  }
+  end
 
-  let(:provider) {
+  let(:provider) do
     Chef::Provider::User::Dscl.new(new_resource, run_context)
-  }
+  end
 
-  let(:mac_version) {
+  let(:mac_version) do
     "10.9.1"
-  }
+  end
 
   let(:password) { nil }
   let(:salt) { nil }
   let(:iterations) { nil }
 
-  let(:salted_sha512_password) {
+  let(:salted_sha512_password) do
     "0f543f021c63255e64e121a3585601b8ecfedf6d2\
 705ddac69e682a33db5dbcdb9b56a2520bc8fff63a\
 2ba6b7984c0737ff0b7949455071581f7affcd536d\
 402b6cdb097"
-  }
+  end
 
-  let(:salted_sha512_pbkdf2_password) {
+  let(:salted_sha512_pbkdf2_password) do
     "c734b6e4787c3727bb35e29fdd92b97c\
 1de12df509577a045728255ec7c6c5f5\
 c18efa05ed02b682ffa7ebc05119900e\
@@ -77,24 +78,24 @@ b1d4880833aa7a190afc13e2bf0936b8\
 9464a8c234f3919082400b4f939bb77b\
 c5adbbac718b7eb99463a7b679571e0f\
 1c9fef2ef08d0b9e9c2bcf644eed2ffc"
-  }
+  end
 
-  let(:salted_sha512_pbkdf2_salt) {
+  let(:salted_sha512_pbkdf2_salt) do
     "2d942d8364a9ccf2b8e5cb7ed1ff58f78\
 e29dbfee7f9db58859144d061fd0058"
-  }
+  end
 
-  let(:salted_sha512_pbkdf2_iterations) {
+  let(:salted_sha512_pbkdf2_iterations) do
     25000
-  }
+  end
 
-  let(:vagrant_sha_512) {
+  let(:vagrant_sha_512) do
     "6f75d7190441facc34291ebbea1fc756b242d4f\
 e9bcff141bccb84f1979e27e539539aa31f9f7dcc92c0cea959\
 ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30"
-  }
+  end
 
-  let(:vagrant_sha_512_pbkdf2) {
+  let(:vagrant_sha_512_pbkdf2) do
     "12601a90db17cbf\
 8ba4808e6382fb0d3b9d8a6c1a190477bf680ab21afb\
 6065467136e55cc208a6f74156e3daf20fb13369ef4b\
@@ -102,44 +103,44 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30"
 47cca84341a7f93a27147343f89fb843fb46c0017d2\
 64afa4976baacf941b915bd1ec1ca24c30b3e759e02\
 403e02f59fe7ff5938a7636c"
-  }
+  end
 
-  let(:vagrant_sha_512_pbkdf2_salt) {
+  let(:vagrant_sha_512_pbkdf2_salt) do
     "ee954be472fdc60ddf89484781433993625f006af6ec810c08f49a7e413946a1"
-  }
+  end
 
-  let(:vagrant_sha_512_pbkdf2_iterations) {
+  let(:vagrant_sha_512_pbkdf2_iterations) do
     34482
-  }
+  end
 
   describe "when shelling out to dscl" do
     it "should run dscl with the supplied cmd /Path args" do
-      shell_return = ShellCmdResult.new('stdout', 'err', 0)
+      shell_return = shellcmdresult.new("stdout", "err", 0)
       expect(provider).to receive(:shell_out).with("dscl . -cmd /Path args").and_return(shell_return)
-      expect(provider.run_dscl("cmd /Path args")).to eq('stdout')
+      expect(provider.run_dscl("cmd /Path args")).to eq("stdout")
     end
 
     it "returns an empty string from delete commands" do
-      shell_return = ShellCmdResult.new('out', 'err', 23)
+      shell_return = shellcmdresult.new("out", "err", 23)
       expect(provider).to receive(:shell_out).with("dscl . -delete /Path args").and_return(shell_return)
       expect(provider.run_dscl("delete /Path args")).to eq("")
     end
 
     it "should raise an exception for any other command" do
-      shell_return = ShellCmdResult.new('out', 'err', 23)
-      expect(provider).to receive(:shell_out).with('dscl . -cmd /Path arguments').and_return(shell_return)
+      shell_return = shellcmdresult.new("out", "err", 23)
+      expect(provider).to receive(:shell_out).with("dscl . -cmd /Path arguments").and_return(shell_return)
       expect { provider.run_dscl("cmd /Path arguments") }.to raise_error(Chef::Exceptions::DsclCommandFailed)
     end
 
     it "raises an exception when dscl reports 'no such key'" do
-      shell_return = ShellCmdResult.new("No such key: ", 'err', 23)
-      expect(provider).to receive(:shell_out).with('dscl . -cmd /Path args').and_return(shell_return)
+      shell_return = shellcmdresult.new("No such key: ", "err", 23)
+      expect(provider).to receive(:shell_out).with("dscl . -cmd /Path args").and_return(shell_return)
       expect { provider.run_dscl("cmd /Path args") }.to raise_error(Chef::Exceptions::DsclCommandFailed)
     end
 
     it "raises an exception when dscl reports 'eDSRecordNotFound'" do
-      shell_return = ShellCmdResult.new("<dscl_cmd> DS Error: -14136 (eDSRecordNotFound)", 'err', -14136)
-      expect(provider).to receive(:shell_out).with('dscl . -cmd /Path args').and_return(shell_return)
+      shell_return = shellcmdresult.new("<dscl_cmd> DS Error: -14136 (eDSRecordNotFound)", "err", -14136)
+      expect(provider).to receive(:shell_out).with("dscl . -cmd /Path args").and_return(shell_return)
       expect { provider.run_dscl("cmd /Path args") }.to raise_error(Chef::Exceptions::DsclCommandFailed)
     end
   end
@@ -197,7 +198,7 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30"
     end
 
     it "finds a valid, unused uid when none is specified" do
-      expect(provider).to receive(:run_dscl).with("list /Users uid").and_return('')
+      expect(provider).to receive(:run_dscl).with("list /Users uid").and_return("")
       expect(provider).to receive(:run_dscl).with("create /Users/toor UniqueID 501")
       expect(provider).to receive(:get_free_uid).and_return(501)
       provider.dscl_set_uid
@@ -207,19 +208,19 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30"
     it "sets the uid specified in the resource" do
       new_resource.uid(1000)
       expect(provider).to receive(:run_dscl).with("create /Users/toor UniqueID 1000").and_return(true)
-      expect(provider).to receive(:run_dscl).with("list /Users uid").and_return('')
+      expect(provider).to receive(:run_dscl).with("list /Users uid").and_return("")
       provider.dscl_set_uid
     end
   end
 
   describe "when modifying the home directory" do
-    let(:current_resource) {
+    let(:current_resource) do
       new_resource.dup
-    }
+    end
 
     before do
       new_resource.supports({ :manage_home => true })
-      new_resource.home('/Users/toor')
+      new_resource.home("/Users/toor")
 
       provider.current_resource = current_resource
     end
@@ -230,40 +231,39 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30"
       provider.dscl_set_home
     end
 
-
     it "raises InvalidHomeDirectory when the resource's home directory doesn't look right" do
-      new_resource.home('epic-fail')
+      new_resource.home("epic-fail")
       expect { provider.dscl_set_home }.to raise_error(Chef::Exceptions::InvalidHomeDirectory)
     end
 
     it "moves the users home to the new location if it exists and the target location is different" do
       new_resource.supports(:manage_home => true)
 
-      current_home = CHEF_SPEC_DATA + '/old_home_dir'
-      current_home_files = [current_home + '/my-dot-emacs', current_home + '/my-dot-vim']
+      current_home = CHEF_SPEC_DATA + "/old_home_dir"
+      current_home_files = [current_home + "/my-dot-emacs", current_home + "/my-dot-vim"]
       current_resource.home(current_home)
       new_resource.gid(23)
-      allow(::File).to receive(:exists?).with('/old/home/toor').and_return(true)
-      allow(::File).to receive(:exists?).with('/Users/toor').and_return(true)
+      allow(::File).to receive(:exists?).with("/old/home/toor").and_return(true)
+      allow(::File).to receive(:exists?).with("/Users/toor").and_return(true)
 
-      expect(FileUtils).to receive(:mkdir_p).with('/Users/toor').and_return(true)
+      expect(FileUtils).to receive(:mkdir_p).with("/Users/toor").and_return(true)
       expect(FileUtils).to receive(:rmdir).with(current_home)
-      expect(::Dir).to receive(:glob).with("#{CHEF_SPEC_DATA}/old_home_dir/*",::File::FNM_DOTMATCH).and_return(current_home_files)
+      expect(::Dir).to receive(:glob).with("#{CHEF_SPEC_DATA}/old_home_dir/*", ::File::FNM_DOTMATCH).and_return(current_home_files)
       expect(FileUtils).to receive(:mv).with(current_home_files, "/Users/toor", :force => true)
-      expect(FileUtils).to receive(:chown_R).with('toor','23','/Users/toor')
+      expect(FileUtils).to receive(:chown_R).with("toor", "23", "/Users/toor")
 
       expect(provider).to receive(:run_dscl).with("create /Users/toor NFSHomeDirectory '/Users/toor'")
       provider.dscl_set_home
     end
 
     it "should raise an exception when the systems user template dir (skel) cannot be found" do
-      allow(::File).to receive(:exists?).and_return(false,false,false)
+      allow(::File).to receive(:exists?).and_return(false, false, false)
       expect { provider.dscl_set_home }.to raise_error(Chef::Exceptions::User)
     end
 
     it "should run ditto to copy any missing files from skel to the new home dir" do
       expect(::File).to receive(:exists?).with("/System/Library/User\ Template/English.lproj").and_return(true)
-      expect(FileUtils).to receive(:chown_R).with('toor', '', '/Users/toor')
+      expect(FileUtils).to receive(:chown_R).with("toor", "", "/Users/toor")
       expect(provider).to receive(:shell_out!).with("ditto '/System/Library/User Template/English.lproj' '/Users/toor'")
       provider.ditto_home
     end
@@ -294,7 +294,7 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30"
       let(:dscl_exists) { false }
 
       it "should raise an error" do
-        expect { run_requirements }.to raise_error
+        expect { run_requirements }.to raise_error(Chef::Exceptions::User)
       end
     end
 
@@ -302,24 +302,24 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30"
       let(:plutil_exists) { false }
 
       it "should raise an error" do
-        expect { run_requirements }.to raise_error
+        expect { run_requirements }.to raise_error(Chef::Exceptions::User)
       end
     end
 
     describe "when on Mac 10.6" do
-      let(:mac_version) {
+      let(:mac_version) do
         "10.6.5"
-      }
+      end
 
       it "should raise an error" do
-        expect { run_requirements }.to raise_error
+        expect { run_requirements }.to raise_error(Chef::Exceptions::User)
       end
     end
 
     describe "when on Mac 10.7" do
-      let(:mac_version) {
+      let(:mac_version) do
         "10.7.5"
-      }
+      end
 
       describe "when password is SALTED-SHA512" do
         let(:password) { salted_sha512_password }
@@ -333,22 +333,22 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30"
         let(:password) { salted_sha512_pbkdf2_password }
 
         it "should raise an error" do
-          expect { run_requirements }.to raise_error
+          expect { run_requirements }.to raise_error(Chef::Exceptions::User)
         end
       end
     end
 
     [ "10.9", "10.10"].each do |version|
       describe "when on Mac #{version}" do
-        let(:mac_version) {
+        let(:mac_version) do
           "#{version}.2"
-        }
+        end
 
         describe "when password is SALTED-SHA512" do
           let(:password) { salted_sha512_password }
 
           it "should raise an error" do
-            expect { run_requirements }.to raise_error
+            expect { run_requirements }.to raise_error(Chef::Exceptions::User)
           end
         end
 
@@ -357,7 +357,7 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30"
 
           describe "when salt and iteration is not set" do
             it "should raise an error" do
-              expect { run_requirements }.to raise_error
+              expect { run_requirements }.to raise_error(Chef::Exceptions::User)
             end
           end
 
@@ -382,9 +382,9 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30"
       expect(provider).to receive(:shell_out).with("dscacheutil '-flushcache'")
       expect(provider).to receive(:shell_out).with("plutil -convert xml1 -o - /var/db/dslocal/nodes/Default/users/toor.plist") do
         if user_plist_file.nil?
-          ShellCmdResult.new('Can not find the file', 'Sorry!!', 1)
+          shellcmdresult.new("Can not find the file", "Sorry!!", 1)
         else
-          ShellCmdResult.new(File.read(File.join(CHEF_SPEC_DATA, "mac_users/#{user_plist_file}.plist.xml")), "", 0)
+          shellcmdresult.new(File.read(File.join(CHEF_SPEC_DATA, "mac_users/#{user_plist_file}.plist.xml")), "", 0)
         end
       end
 
@@ -413,9 +413,9 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30"
       let(:password) { "something" } # Load password during load_current_resource
 
       describe "on 10.7" do
-        let(:mac_version) {
+        let(:mac_version) do
           "10.7.5"
-        }
+        end
 
         let(:user_plist_file) { "10.7" }
 
@@ -478,9 +478,9 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30"
       end
 
       describe "on 10.8" do
-        let(:mac_version) {
+        let(:mac_version) do
           "10.8.3"
-        }
+        end
 
         let(:user_plist_file) { "10.8" }
 
@@ -504,9 +504,9 @@ e68d1f9821b26689312366")
 
       describe "on 10.7 upgraded to 10.8" do
         # In this scenario user password is still in 10.7 format
-        let(:mac_version) {
+        let(:mac_version) do
           "10.8.3"
-        }
+        end
 
         let(:user_plist_file) { "10.7-8" }
 
@@ -542,9 +542,9 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30")
       end
 
       describe "on 10.9" do
-        let(:mac_version) {
+        let(:mac_version) do
           "10.9.1"
-        }
+        end
 
         let(:user_plist_file) { "10.9" }
 
@@ -646,9 +646,9 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30")
 
   describe "prepare_password_shadow_info" do
     describe "when on Mac 10.7" do
-      let(:mac_version) {
+      let(:mac_version) do
         "10.7.1"
-      }
+      end
 
       describe "when the password is plain text" do
         let(:password) { "vagrant" }
@@ -656,7 +656,7 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30")
         it "password_shadow_info should have salted-sha-512 format" do
           shadow_info = provider.prepare_password_shadow_info
           expect(shadow_info).to have_key("SALTED-SHA512")
-          info = shadow_info["SALTED-SHA512"].string.unpack('H*').first
+          info = shadow_info["SALTED-SHA512"].string.unpack("H*").first
           expect(provider.salted_sha512?(info)).to be_truthy
         end
       end
@@ -667,7 +667,7 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30")
         it "password_shadow_info should have salted-sha-512 format" do
           shadow_info = provider.prepare_password_shadow_info
           expect(shadow_info).to have_key("SALTED-SHA512")
-          info = shadow_info["SALTED-SHA512"].string.unpack('H*').first
+          info = shadow_info["SALTED-SHA512"].string.unpack("H*").first
           expect(provider.salted_sha512?(info)).to be_truthy
           expect(info).to eq(vagrant_sha_512)
         end
@@ -676,9 +676,9 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30")
 
     ["10.8", "10.9", "10.10"].each do |version|
       describe "when on Mac #{version}" do
-        let(:mac_version) {
+        let(:mac_version) do
           "#{version}.1"
-        }
+        end
 
         describe "when the password is plain text" do
           let(:password) { "vagrant" }
@@ -689,7 +689,7 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30")
             expect(shadow_info["SALTED-SHA512-PBKDF2"]).to have_key("entropy")
             expect(shadow_info["SALTED-SHA512-PBKDF2"]).to have_key("salt")
             expect(shadow_info["SALTED-SHA512-PBKDF2"]).to have_key("iterations")
-            info = shadow_info["SALTED-SHA512-PBKDF2"]["entropy"].string.unpack('H*').first
+            info = shadow_info["SALTED-SHA512-PBKDF2"]["entropy"].string.unpack("H*").first
             expect(provider.salted_sha512_pbkdf2?(info)).to be_truthy
           end
         end
@@ -705,7 +705,7 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30")
             expect(shadow_info["SALTED-SHA512-PBKDF2"]).to have_key("entropy")
             expect(shadow_info["SALTED-SHA512-PBKDF2"]).to have_key("salt")
             expect(shadow_info["SALTED-SHA512-PBKDF2"]).to have_key("iterations")
-            info = shadow_info["SALTED-SHA512-PBKDF2"]["entropy"].string.unpack('H*').first
+            info = shadow_info["SALTED-SHA512-PBKDF2"]["entropy"].string.unpack("H*").first
             expect(provider.salted_sha512_pbkdf2?(info)).to be_truthy
             expect(info).to eq(vagrant_sha_512_pbkdf2)
           end
@@ -720,7 +720,7 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30")
     end
 
     it "should sleep and flush the dscl cache before saving the password" do
-      expect(provider).to receive(:prepare_password_shadow_info).and_return({ })
+      expect(provider).to receive(:prepare_password_shadow_info).and_return({})
       mock_shellout = double("Mock::Shellout")
       allow(mock_shellout).to receive(:run_command)
       expect(Mixlib::ShellOut).to receive(:new).and_return(mock_shellout)
@@ -760,6 +760,13 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30")
         provider.dscl_create_comment
       end
 
+      it "sets the comment field to username" do
+        new_resource.comment nil
+        expect(provider).to receive(:run_dscl).with("create /Users/toor RealName '#mockssuck'").and_return(true)
+        provider.dscl_create_comment
+        expect(new_resource.comment).to eq("#mockssuck")
+      end
+
       it "should run run_dscl with create /Users/user PrimaryGroupID to set the users primary group" do
         expect(provider).to receive(:run_dscl).with("create /Users/toor PrimaryGroupID '1001'").and_return(true)
         provider.dscl_set_gid
@@ -784,11 +791,18 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30")
       end
 
       it "should raise an exception when the group does not exist" do
-        shell_return = ShellCmdResult.new("<dscl_cmd> DS Error: -14136 (eDSRecordNotFound)", 'err', -14136)
-        expect(provider).to receive(:shell_out).with('dscl . -read /Groups/newgroup PrimaryGroupID').and_return(shell_return)
+        shell_return = shellcmdresult.new("<dscl_cmd> DS Error: -14136 (eDSRecordNotFound)", "err", -14136)
+        expect(provider).to receive(:shell_out).with("dscl . -read /Groups/newgroup PrimaryGroupID").and_return(shell_return)
         expect { provider.dscl_set_gid }.to raise_error(Chef::Exceptions::GroupIDNotFound)
       end
     end
+
+    it "should set group ID to 20 if it's not specified" do
+      new_resource.gid nil
+      expect(provider).to receive(:run_dscl).with("create /Users/toor PrimaryGroupID '20'").ordered.and_return(true)
+      provider.dscl_set_gid
+      expect(new_resource.gid).to eq(20)
+    end
   end
 
   describe "when the user exists and chef is managing it" do
@@ -800,8 +814,8 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30")
       new_resource.username "mud"
       new_resource.uid 2342
       new_resource.gid 2342
-      new_resource.home '/Users/death'
-      new_resource.password 'goaway'
+      new_resource.home "/Users/death"
+      new_resource.password "goaway"
     end
 
     it "sets the user, comment field, uid, gid, moves the home directory, sets the shell, and sets the password" do
@@ -835,7 +849,7 @@ ea18e18b720e358e7fbe3cfbeaa561456f6ba008937a30")
     before do
       expect(provider).to receive(:shell_out).with("dscacheutil '-flushcache'")
       expect(provider).to receive(:shell_out).with("plutil -convert xml1 -o - /var/db/dslocal/nodes/Default/users/toor.plist") do
-        ShellCmdResult.new(File.read(File.join(CHEF_SPEC_DATA, "mac_users/10.9.plist.xml")), "", 0)
+        shellcmdresult.new(File.read(File.join(CHEF_SPEC_DATA, "mac_users/10.9.plist.xml")), "", 0)
       end
       provider.load_current_resource
     end
