@@ -1,6 +1,6 @@
 #
-# Author:: Bryan McLellan <btm@opscode.com>
-# Copyright:: Copyright (c) 2012 Opscode, Inc.
+# Author:: Bryan McLellan <btm@chef.io>
+# Copyright:: Copyright 2012-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,8 +16,8 @@
 # limitations under the License.
 #
 
-require 'spec_helper'
-require 'support/shared/unit/resource/static_provider_resolution'
+require "spec_helper"
+require "support/shared/unit/resource/static_provider_resolution"
 
 describe Chef::Resource::IpsPackage, "initialize" do
 
@@ -26,7 +26,7 @@ describe Chef::Resource::IpsPackage, "initialize" do
     provider: Chef::Provider::Package::Ips,
     name: :ips_package,
     action: :install,
-    os: "solaris2",
+    os: "solaris2"
   )
 
   before(:each) do
