@@ -1,6 +1,6 @@
 #
 # Author:: Thomas Bishop (<bishop.thomas@gmail.com>)
-# Copyright:: Copyright (c) 2010 Thomas Bishop
+# Copyright:: Copyright 2010-2016, Thomas Bishop
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,8 +16,8 @@
 # limitations under the License.
 #
 
-require 'spec_helper'
-require 'support/shared/unit/resource/static_provider_resolution'
+require "spec_helper"
+require "support/shared/unit/resource/static_provider_resolution"
 
 describe Chef::Resource::SmartosPackage, "initialize" do
 
@@ -27,7 +27,7 @@ describe Chef::Resource::SmartosPackage, "initialize" do
     name: :smartos_package,
     action: :install,
     os: "solaris2",
-    platform_family: "smartos",
+    platform_family: "smartos"
   )
 
 end
