@@ -1,7 +1,7 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Author:: Daniel DeLeo (<dan@opscode.com>)
-# Copyright:: Copyright (c) 2008, 2010 Opscode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Author:: Daniel DeLeo (<dan@chef.io>)
+# Copyright:: Copyright 2008-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,53 +17,70 @@
 # limitations under the License.
 #
 
-require 'rubygems'
-require 'rake'
+require "rubygems"
+require "rake"
 
 CHEF_ROOT = File.join(File.dirname(__FILE__), "..")
 
 begin
-  require 'rspec/core/rake_task'
+  require "rspec/core/rake_task"
+
+  desc "Run specs for Chef's Components"
+  task :component_specs do
+    Dir.chdir("chef-config") do
+      Bundler.with_clean_env do
+        sh("bundle install")
+        sh("bundle exec rake spec")
+      end
+    end
+  end
 
   task :default => :spec
 
+  task :spec => :component_specs
+
   desc "Run standard specs (minus long running specs)"
   RSpec::Core::RakeTask.new(:spec) do |t|
+    t.rspec_opts = %w{--profile}
     # right now this just limits to functional + unit, but could also remove
     # individual tests marked long-running
-    t.pattern = FileList['spec/{functional,unit}/**/*_spec.rb']
+    t.pattern = FileList["spec/**/*_spec.rb"]
   end
 
   namespace :spec do
     desc "Run all specs in spec directory with RCov"
     RSpec::Core::RakeTask.new(:rcov) do |t|
-      t.pattern = FileList['spec/**/*_spec.rb']
+      t.rspec_opts = %w{--profile}
+      t.pattern = FileList["spec/**/*_spec.rb"]
       t.rcov = true
       t.rcov_opts = lambda do
-        IO.readlines("#{CHEF_ROOT}/spec/rcov.opts").map {|l| l.chomp.split " "}.flatten
+        IO.readlines("#{CHEF_ROOT}/spec/rcov.opts").map { |l| l.chomp.split " " }.flatten
       end
     end
 
     desc "Run all specs in spec directory"
     RSpec::Core::RakeTask.new(:all) do |t|
-      t.pattern = FileList['spec/**/*_spec.rb']
+      t.rspec_opts = %w{--profile}
+      t.pattern = FileList["spec/**/*_spec.rb"]
     end
 
     desc "Print Specdoc for all specs"
     RSpec::Core::RakeTask.new(:doc) do |t|
-      t.rspec_opts = ["--format", "specdoc", "--dry-run"]
-      t.pattern = FileList['spec/**/*_spec.rb']
+      t.rspec_opts = %w{--format specdoc --dry-run --profile}
+      t.pattern = FileList["spec/**/*_spec.rb"]
     end
 
     desc "Run the specs under spec/unit with activesupport loaded"
     RSpec::Core::RakeTask.new(:activesupport) do |t|
-      t.rspec_opts = ["--require active_support/core_ext"]
-      t.pattern = FileList['spec/unit/**/*_spec.rb']
+      t.rspec_opts = %w{--require active_support/core_ext --profile}
+      # Only node_spec and role_spec specifically have issues, target those tests
+      t.pattern = FileList["spec/unit/node_spec.rb", "spec/unit/role_spec.rb"]
     end
 
     [:unit, :functional, :integration, :stress].each do |sub|
       desc "Run the specs under spec/#{sub}"
       RSpec::Core::RakeTask.new(sub) do |t|
+        t.rspec_opts = %w{--profile}
         t.pattern = FileList["spec/#{sub}/**/*_spec.rb"]
       end
     end
